@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestHistogram2D.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkChartHistogram2D.h"
 #include "vtkColorTransferFunction.h"
@@ -29,7 +17,7 @@
 #include "vtkTable.h"
 #include "vtkVector.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int TestHistogram2D(int, char*[])
 {
   // Set up a 2D scene, add an XY chart to it
@@ -66,7 +54,7 @@ int TestHistogram2D(int, char*[])
 
   vtkPlotLine* plot = vtkPlotLine::SafeDownCast(chart->AddPlot(vtkChart::LINE));
   plot->SetInputData(table, 0, 1);
-  plot->SetColor(1.0, 0.0, 0.0);
+  plot->SetColorF(1.0, 0.0, 0.0);
   plot->SetWidth(5);
 
   vtkContextMouseEvent mouseEvent;
