@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkCompositeControlPointsItem.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 /**
  * @class   vtkCompositeControlPointsItem
@@ -25,23 +13,25 @@
  * vtkColorTransferControlPointsItem
  * vtkCompositeTransferFunctionItem
  * vtkPiecewisePointHandleItem
-*/
+ */
 
 #ifndef vtkCompositeControlPointsItem_h
 #define vtkCompositeControlPointsItem_h
 
 #include "vtkChartsCoreModule.h" // For export macro
 #include "vtkColorTransferControlPointsItem.h"
+#include "vtkWrappingHints.h" // For VTK_MARSHALAUTO
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkPiecewiseFunction;
 class vtkPiecewisePointHandleItem;
 
-class VTKCHARTSCORE_EXPORT vtkCompositeControlPointsItem:
-  public vtkColorTransferControlPointsItem
+class VTKCHARTSCORE_EXPORT VTK_MARSHALAUTO vtkCompositeControlPointsItem
+  : public vtkColorTransferControlPointsItem
 {
 public:
   vtkTypeMacro(vtkCompositeControlPointsItem, vtkColorTransferControlPointsItem);
-  virtual void PrintSelf(ostream &os, vtkIndent indent);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   /**
    * Creates a piecewise control points object
@@ -53,22 +43,24 @@ public:
    */
   virtual void SetColorTransferFunction(vtkColorTransferFunction* function);
 
-  //@{
+  ///@{
   /**
    * Utility function that calls SetPiecewiseFunction()
    */
   void SetOpacityFunction(vtkPiecewiseFunction* opacity);
   vtkGetObjectMacro(OpacityFunction, vtkPiecewiseFunction);
-  //@}
+  ///@}
 
-  enum PointsFunctionType{
+  enum PointsFunctionType
+  {
     ColorPointsFunction = 1,
     OpacityPointsFunction = 2,
     ColorAndOpacityPointsFunction = 3
   };
-  //@{
+
+  ///@{
   /**
-   * PointsFunction controls wether the points represent the
+   * PointsFunction controls whether the points represent the
    * ColorTransferFunction, OpacityTransferFunction or both.
    * If ColorPointsFunction, only the points of the ColorTransfer function are
    * used.
@@ -81,23 +73,24 @@ public:
    */
   vtkSetMacro(PointsFunction, int);
   vtkGetMacro(PointsFunction, int);
-  //@}
+  ///@}
 
   /**
    * Add a point to the function. Returns the index of the point (0 based),
    * or -1 on error.
    * Subclasses should reimplement this function to do the actual work.
    */
-  virtual vtkIdType AddPoint(double* newPos);
+  vtkIdType AddPoint(double* newPos) override;
 
+  using Superclass::RemovePoint;
   /**
    * Remove a point of the function. Returns the index of the point (0 based),
    * or -1 on error.
    * Subclasses should reimplement this function to do the actual work.
    */
-  virtual vtkIdType RemovePoint(double* pos);
+  vtkIdType RemovePoint(double* pos) override;
 
-  //@{
+  ///@{
   /**
    * If UseOpacityPointHandles is true, when the current point is
    * double clicked, a vtkPiecewisePointHandleItem will show up so
@@ -107,49 +100,64 @@ public:
    */
   vtkSetMacro(UseOpacityPointHandles, bool);
   vtkGetMacro(UseOpacityPointHandles, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Mouse move event. To take care of some special Key stroke
    */
-  virtual bool MouseMoveEvent(const vtkContextMouseEvent &mouse);
-  virtual bool MouseDoubleClickEvent(const vtkContextMouseEvent &mouse);
-  virtual bool MouseButtonPressEvent(const vtkContextMouseEvent &mouse);
-  //@}
+  bool MouseMoveEvent(const vtkContextMouseEvent& mouse) override;
+  bool MouseDoubleClickEvent(const vtkContextMouseEvent& mouse) override;
+  bool MouseButtonPressEvent(const vtkContextMouseEvent& mouse) override;
+  ///@}
+
+  /**
+   * Returns the total number of points, either from
+   * using the superclass implementation or the opacity function
+   * when available
+   */
+  vtkIdType GetNumberOfPoints() const override;
+
+  /**
+   * Returns the x and y coordinates as well as the midpoint and sharpness
+   * of the control point corresponding to the index.
+   * point must be a double array of size 4.
+   * The values will be recovered from the opacity function when available.
+   */
+  void GetControlPoint(vtkIdType index, double point[4]) const override;
+
+  /**
+   * Sets the x and y coordinates as well as the midpoint and sharpness,
+   * of the control point corresponding to the index, either using the superclass
+   * implementation or the opacity function when available.
+   * The provided point should be a double array of size 4.
+   */
+  void SetControlPoint(vtkIdType index, double* point) override;
 
 protected:
   vtkCompositeControlPointsItem();
-  virtual ~vtkCompositeControlPointsItem();
+  ~vtkCompositeControlPointsItem() override;
 
-  /**
-   * Returns true if control points are to be rendered in log-space. This is
-   * true when vtkScalarsToColors is using log-scale, for example.
-   */
-  virtual bool UsingLogScale();
+  void emitEvent(unsigned long event, void* params) override;
 
-  virtual void emitEvent(unsigned long event, void* params);
+  vtkMTimeType GetControlPointsMTime() override;
 
-  virtual vtkMTimeType GetControlPointsMTime();
-
-  virtual vtkIdType GetNumberOfPoints()const;
-  virtual void DrawPoint(vtkContext2D* painter, vtkIdType index);
-  virtual void GetControlPoint(vtkIdType index, double* pos)const;
-  virtual void SetControlPoint(vtkIdType index, double *point);
-  virtual void EditPoint(float tX, float tY);
+  void DrawPoint(vtkContext2D* painter, vtkIdType index) override;
+  void EditPoint(float tX, float tY) override;
   virtual void EditPointCurve(vtkIdType idx);
 
   void MergeTransferFunctions();
   void SilentMergeTransferFunctions();
 
-  int                   PointsFunction;
-  vtkPiecewiseFunction* OpacityFunction;
-  vtkPiecewisePointHandleItem* OpacityPointHandle;
-  bool UseOpacityPointHandles;
+  int PointsFunction = vtkCompositeControlPointsItem::ColorAndOpacityPointsFunction;
+  vtkPiecewiseFunction* OpacityFunction = nullptr;
+  vtkPiecewisePointHandleItem* OpacityPointHandle = nullptr;
+  bool UseOpacityPointHandles = false;
 
 private:
-  vtkCompositeControlPointsItem(const vtkCompositeControlPointsItem &) VTK_DELETE_FUNCTION;
-  void operator=(const vtkCompositeControlPointsItem &) VTK_DELETE_FUNCTION;
+  vtkCompositeControlPointsItem(const vtkCompositeControlPointsItem&) = delete;
+  void operator=(const vtkCompositeControlPointsItem&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
