@@ -1,23 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    ArrayBool.cxx
-
--------------------------------------------------------------------------
-  Copyright 2008 Sandia Corporation.
-  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
-  the U.S. Government retains certain rights in this software.
--------------------------------------------------------------------------
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2008 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 
 #include <vtkDenseArray.h>
 #include <vtkSmartPointer.h>
@@ -28,6 +11,7 @@
 #include <stdexcept>
 
 #define test_expression(expression)                                                                \
+  do                                                                                               \
   {                                                                                                \
     if (!(expression))                                                                             \
     {                                                                                              \
@@ -35,14 +19,14 @@
       buffer << "Expression failed at line " << __LINE__ << ": " << #expression;                   \
       throw std::runtime_error(buffer.str());                                                      \
     }                                                                                              \
-  }
+  } while (false)
 
 int TestArrayBool(int vtkNotUsed(argc), char* vtkNotUsed(argv)[])
 {
   try
   {
     // Confirm that we can work with dense arrays of bool values
-    vtkSmartPointer<vtkDenseArray<char> > dense = vtkSmartPointer<vtkDenseArray<char> >::New();
+    vtkSmartPointer<vtkDenseArray<char>> dense = vtkSmartPointer<vtkDenseArray<char>>::New();
     vtkDenseArray<char>& dense_ref = *dense;
     dense->Resize(2, 2);
     dense->Fill(0);
@@ -58,7 +42,7 @@ int TestArrayBool(int vtkNotUsed(argc), char* vtkNotUsed(argv)[])
     test_expression(dense->GetValue(0, 1) == 1);
 
     // Confirm that we can work with sparse arrays of bool values
-    vtkSmartPointer<vtkSparseArray<char> > sparse = vtkSmartPointer<vtkSparseArray<char> >::New();
+    vtkSmartPointer<vtkSparseArray<char>> sparse = vtkSmartPointer<vtkSparseArray<char>>::New();
     sparse->Resize(2, 2);
 
     test_expression(sparse->GetValue(1, 1) == 0);
