@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkCollection.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkCollection
  * @brief   create and manipulate ordered lists of objects
@@ -33,7 +21,9 @@
 
 #include "vtkCommonCoreModule.h" // For export macro
 #include "vtkObject.h"
+#include "vtkWrappingHints.h" // For VTK_MARSHALAUTO
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCollectionElement //;prevents pick-up by man page generator
 {
 public:
@@ -49,7 +39,7 @@ typedef void* vtkCollectionSimpleIterator;
 
 class vtkCollectionIterator;
 
-class VTKCOMMONCORE_EXPORT vtkCollection : public vtkObject
+class VTKCOMMONCORE_EXPORT VTK_MARSHALAUTO vtkCollection : public vtkObject
 {
 public:
   vtkTypeMacro(vtkCollection, vtkObject);
@@ -102,12 +92,19 @@ public:
    * 0, the object was not found. If the object was found, the location is
    * the return value-1.
    */
-  int IsItemPresent(vtkObject* a);
+  int IsItemPresent(vtkObject* a) VTK_FUTURE_CONST;
+
+  /**
+   * Search for an object and return location in list. If the return value is
+   * -1, the object was not found. If the object was found, the location is
+   * at the returned (0-based) index.
+   */
+  int IndexOfFirstOccurence(vtkObject* a) VTK_FUTURE_CONST;
 
   /**
    * Return the number of objects in the list.
    */
-  int GetNumberOfItems() { return this->NumberOfItems; }
+  int GetNumberOfItems() VTK_FUTURE_CONST { return this->NumberOfItems; }
 
   /**
    * Initialize the traversal of the collection. This means the data pointer
@@ -134,26 +131,25 @@ public:
    * Get the i'th item in the collection. nullptr is returned if i is out
    * of range
    */
-  vtkObject* GetItemAsObject(int i);
+  vtkObject* GetItemAsObject(int i) VTK_FUTURE_CONST;
 
   /**
    * A reentrant safe way to get the next object as a collection. Just pass the
    * same cookie back and forth.
    */
-  vtkObject* GetNextItemAsObject(vtkCollectionSimpleIterator& cookie);
+  vtkObject* GetNextItemAsObject(vtkCollectionSimpleIterator& cookie) VTK_FUTURE_CONST;
 
   /**
    * Get an iterator to traverse the objects in this collection.
    */
   VTK_NEWINSTANCE vtkCollectionIterator* NewIterator();
 
-  //@{
+  ///@{
   /**
    * Participate in garbage collection.
    */
-  void Register(vtkObjectBase* o) override;
-  void UnRegister(vtkObjectBase* o) override;
-  //@}
+  bool UsesGarbageCollector() const override { return true; }
+  ///@}
 
 protected:
   vtkCollection();
@@ -191,7 +187,7 @@ inline vtkObject* vtkCollection::GetNextItemAsObject()
   }
 }
 
-inline vtkObject* vtkCollection::GetNextItemAsObject(void*& cookie)
+inline vtkObject* vtkCollection::GetNextItemAsObject(void*& cookie) VTK_FUTURE_CONST
 {
   vtkCollectionElement* elem = static_cast<vtkCollectionElement*>(cookie);
 
@@ -206,4 +202,5 @@ inline vtkObject* vtkCollection::GetNextItemAsObject(void*& cookie)
   }
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
