@@ -1,23 +1,16 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkFileOutputWindow.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkFileOutputWindow.h"
 #include "vtkObjectFactory.h"
 #include "vtksys/FStream.hxx"
 
+#include <mutex>
+
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkFileOutputWindow);
 
+static std::mutex vtkFileOutputWindowMutex;
+
 vtkFileOutputWindow::vtkFileOutputWindow()
 {
   this->OStream = nullptr;
@@ -48,6 +41,7 @@ void vtkFileOutputWindow::Initialize()
 
 void vtkFileOutputWindow::DisplayText(const char* text)
 {
+  std::lock_guard<std::mutex> lock(vtkFileOutputWindowMutex);
   if (!text)
   {
     return;
@@ -73,3 +67,4 @@ void vtkFileOutputWindow::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Append: " << (this->Append ? "On" : "Off") << endl;
   os << indent << "Flush: " << (this->Flush ? "On" : "Off") << endl;
 }
+VTK_ABI_NAMESPACE_END
