@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkCompositeDataSet.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkCompositeDataSet
  * @brief   abstract superclass for composite
@@ -35,14 +23,19 @@
 
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkDataObject.h"
+#include "vtkWrappingHints.h" // For VTK_MARSHALAUTO
 
+#include <vector> // For GetDataSets
+
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeDataIterator;
 class vtkCompositeDataSetInternals;
+class vtkDataSet;
 class vtkInformation;
 class vtkInformationStringKey;
 class vtkInformationIntegerKey;
 
-class VTKCOMMONDATAMODEL_EXPORT vtkCompositeDataSet : public vtkDataObject
+class VTKCOMMONDATAMODEL_EXPORT VTK_MARSHALAUTO vtkCompositeDataSet : public vtkDataObject
 {
 public:
   vtkTypeMacro(vtkCompositeDataSet, vtkDataObject);
@@ -57,57 +50,68 @@ public:
    * Return class name of data type (see vtkType.h for
    * definitions).
    */
-  int GetDataObjectType() override { return VTK_COMPOSITE_DATA_SET; }
+  int GetDataObjectType() VTK_FUTURE_CONST override { return VTK_COMPOSITE_DATA_SET; }
 
   /**
    * Copies the tree structure from the input. All pointers to non-composite
    * data objects are initialized to nullptr. This also shallow copies the meta data
    * associated with all the nodes.
    */
-  virtual void CopyStructure(vtkCompositeDataSet* input) = 0;
+  virtual void CopyStructure(vtkCompositeDataSet* input);
 
   /**
    * Sets the data set at the location pointed by the iterator.
    * The iterator does not need to be iterating over this dataset itself. It can
-   * be any composite datasite with similar structure (achieved by using
+   * be any composite dataset with similar structure (achieved by using
    * CopyStructure).
    */
   virtual void SetDataSet(vtkCompositeDataIterator* iter, vtkDataObject* dataObj) = 0;
 
   /**
-   * Returns the dataset located at the positiong pointed by the iterator.
+   * Returns the dataset located at the position pointed by the iterator.
    * The iterator does not need to be iterating over this dataset itself. It can
    * be an iterator for composite dataset with similar structure (achieved by
    * using CopyStructure).
    */
   virtual vtkDataObject* GetDataSet(vtkCompositeDataIterator* iter) = 0;
 
+  /**
+   * Returns the dataset located at the position pointed by the flatIndex.
+   * If no dataset has the same flat index, nullptr is returned.
+   *
+   * It should be noted that this function should be used ONLY when you already know the flat index.
+   * It should NOT be used when you are iterating over the composite dataset (in that case, prefer
+   * the vtkCompositeDataIterator).
+   */
+  virtual vtkDataObject* GetDataSet(unsigned int flatIndex);
+
   /**
    * Return the actual size of the data in kibibytes (1024 bytes). This number
    * is valid only after the pipeline has updated.
    */
   unsigned long GetActualMemorySize() override;
 
-  //@{
+  ///@{
   /**
    * Retrieve an instance of this class from an information object.
    */
   static vtkCompositeDataSet* GetData(vtkInformation* info);
   static vtkCompositeDataSet* GetData(vtkInformationVector* v, int i = 0);
-  //@}
+  ///@}
 
   /**
    * Restore data object to initial state,
    */
   void Initialize() override;
 
-  //@{
   /**
-   * Shallow and Deep copy.
+   * The goal of the method is to copy the data up to the dataset pointers only.
+   * The implementation is delegated to the differenent subclasses.
+   * If you want to copy up to array pointers, @see vtkDataObject::ShallowCopy.
+   *
+   * This method just calls vtkDataObject::ShallowCopy.
    */
-  void ShallowCopy(vtkDataObject* src) override;
-  void DeepCopy(vtkDataObject* src) override;
-  //@}
+  virtual void CompositeShallowCopy(vtkCompositeDataSet* src);
 
   /**
    * Returns the total number of points of all blocks. This will
@@ -153,6 +157,24 @@ public:
    */
   static vtkInformationIntegerKey* CURRENT_PROCESS_CAN_LOAD_BLOCK();
 
+  /**
+   * Extract datasets from the given data object. This method returns a vector
+   * of DataSetT* from the `dobj`. If dobj is a DataSetT, the returned
+   * vector will have just 1 DataSetT. If dobj is a vtkCompositeDataSet, then
+   * we iterate over it and add all non-null leaf nodes to the returned vector.
+   *
+   * If `preserveNull` is true (defaults to false), then `nullptr` place holders
+   * are added as placeholders when leaf node dataset type does not match the
+   * requested or is nullptr to begin with.
+   */
+  template <class DataSetT = vtkDataSet>
+  static std::vector<DataSetT*> GetDataSets(vtkDataObject* dobj, bool preserveNull = false);
+
+  /**
+   * Returns true for POINT or CELL, false otherwise
+   */
+  bool SupportsGhostArray(int type) override;
+
 protected:
   vtkCompositeDataSet();
   ~vtkCompositeDataSet() override;
@@ -162,4 +184,7 @@ private:
   void operator=(const vtkCompositeDataSet&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
+#include "vtkCompositeDataSet.txx" // for template implementations
+
 #endif
