@@ -46,6 +46,11 @@ vtkTypeBool vtkArrayDataAlgorithm::ProcessRequest(
     return this->RequestUpdateExtent(request, inputVector, outputVector);
   }
 
+  if (request->Has(vtkStreamingDemandDrivenPipeline::REQUEST_UPDATE_TIME()))
+  {
+    return this->RequestUpdateTime(request, inputVector, outputVector);
+  }
+
   // execute information
   if (request->Has(vtkDemandDrivenPipeline::REQUEST_INFORMATION()))
   {
@@ -107,6 +112,13 @@ int vtkArrayDataAlgorithm::RequestUpdateExtent(vtkInformation* vtkNotUsed(reques
   return 1;
 }
 
+//------------------------------------------------------------------------------
+int vtkArrayDataAlgorithm::RequestUpdateTime(
+  vtkInformation*, vtkInformationVector**, vtkInformationVector*)
+{
+  return 1;
+}
+
 //------------------------------------------------------------------------------
 // This is the superclasses style of Execute method.  Convert it into
 // an imaging style Execute method.
