@@ -1,23 +1,12 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkInformationIntegerRequestKey.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkInformationIntegerRequestKey.h"
 
 #include "vtkInformation.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkInformationIntegerRequestKey::vtkInformationIntegerRequestKey(
   const char* name, const char* location)
   : vtkInformationIntegerKey(name, location)
@@ -25,10 +14,10 @@ vtkInformationIntegerRequestKey::vtkInformationIntegerRequestKey(
   this->DataKey = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationIntegerRequestKey::~vtkInformationIntegerRequestKey() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformationIntegerRequestKey::CopyDefaultInformation(
   vtkInformation* request, vtkInformation* fromInfo, vtkInformation* toInfo)
 {
@@ -38,7 +27,7 @@ void vtkInformationIntegerRequestKey::CopyDefaultInformation(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkInformationIntegerRequestKey::NeedToExecute(
   vtkInformation* pipelineInfo, vtkInformation* dobjInfo)
 {
@@ -49,15 +38,16 @@ bool vtkInformationIntegerRequestKey::NeedToExecute(
   return false;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformationIntegerRequestKey::StoreMetaData(
   vtkInformation*, vtkInformation* pipelineInfo, vtkInformation* dobjInfo)
 {
   dobjInfo->Set(this->DataKey, pipelineInfo->Get(this));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformationIntegerRequestKey::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
