@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkSphereTree.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkSphereTree.h"
 
 #include "vtkCellData.h"
@@ -19,6 +7,7 @@
 #include "vtkDataSet.h"
 #include "vtkDebugLeaks.h"
 #include "vtkDoubleArray.h"
+#include "vtkGarbageCollector.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkLine.h"
@@ -35,6 +24,7 @@
 
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSphereTree);
 vtkCxxSetObjectMacro(vtkSphereTree, DataSet, vtkDataSet);
 
@@ -55,9 +45,9 @@ vtkCxxSetObjectMacro(vtkSphereTree, DataSet, vtkDataSet);
 // performance.
 
 // Type of sphere tree hierarchy generated
-#define VTK_SPHERE_TREE_HIERARCHY_NONE 0
-#define VTK_SPHERE_TREE_HIERARCHY_STRUCTURED 1
-#define VTK_SPHERE_TREE_HIERARCHY_UNSTRUCTURED 2
+constexpr int VTK_SPHERE_TREE_HIERARCHY_NONE = 0;
+constexpr int VTK_SPHERE_TREE_HIERARCHY_STRUCTURED = 1;
+constexpr int VTK_SPHERE_TREE_HIERARCHY_UNSTRUCTURED = 2;
 
 // Different types of sphere tree hierarchies can be created. These are
 // basically data structures for different types of dataset (structured
@@ -154,11 +144,11 @@ struct vtkUnstructuredHierarchy : public vtkSphereTreeHierarchy
 };
 
 // Threaded helper functions placed in anonymous namespace
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 namespace
 {
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Compute bounds for each cell in any type of dataset
 struct DataSetSpheres
 {
@@ -341,7 +331,7 @@ struct DataSetSpheres
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Compute bounds for each cell in an unstructured grid
 struct UnstructuredSpheres : public DataSetSpheres
 {
@@ -358,7 +348,7 @@ struct UnstructuredSpheres : public DataSetSpheres
     vtkUnstructuredGrid* grid = static_cast<vtkUnstructuredGrid*>(this->DataSet);
     double cellPts[120], *p, r;
     vtkIdType ptNum;
-    const vtkIdType* cellIds;
+    vtkNew<vtkIdList> cellIds;
     vtkIdType numCellPts;
     double& radius = this->Radius.Local();
     vtkIdType& count = this->Count.Local();
@@ -371,12 +361,12 @@ struct UnstructuredSpheres : public DataSetSpheres
 
     for (; cellId < endCellId; ++cellId, sphere += 4)
     {
-      grid->GetCellPoints(cellId, numCellPts, cellIds);
-      numCellPts = (numCellPts < 40 ? numCellPts : 40);
+      grid->GetCellPoints(cellId, cellIds);
+      numCellPts = std::min(cellIds->GetNumberOfIds(), static_cast<vtkIdType>(40));
       p = cellPts;
       for (ptNum = 0; ptNum < numCellPts; ++ptNum, p += 3)
       {
-        grid->GetPoint(cellIds[ptNum], p);
+        grid->GetPoint(cellIds->GetId(ptNum), p);
       }
       vtkSphere::ComputeBoundingSphere(cellPts, numCellPts, sphere, nullptr);
 
@@ -416,7 +406,7 @@ struct UnstructuredSpheres : public DataSetSpheres
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Compute bounds for each cell in a structured grid
 struct StructuredSpheres : public DataSetSpheres
 {
@@ -482,7 +472,7 @@ struct StructuredSpheres : public DataSetSpheres
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Base class for selection of cells via geometric operations
 struct BaseCellSelect
 {
@@ -508,7 +498,6 @@ struct BaseCellSelect
 
   void Initialize()
   {
-    this->NumberOfCellsSelected = 0;
     vtkIdType& numSelected = this->NumberSelected.Local();
     numSelected = 0;
   }
@@ -525,7 +514,7 @@ struct BaseCellSelect
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Select cells from point based on leaf-level spheres (default)
 struct DefaultPointSelect : public BaseCellSelect
 {
@@ -676,7 +665,7 @@ struct StructuredPointSelect : public DefaultPointSelect
   void Reduce() { DefaultPointSelect::Reduce(); }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Select cells from line based on leaf-level spheres (default)
 struct DefaultLineSelect : public BaseCellSelect
 {
@@ -834,7 +823,7 @@ struct StructuredLineSelect : public DefaultLineSelect
   void Reduce() { DefaultLineSelect::Reduce(); }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Select cells from plane based on leaf-level spheres (default)
 struct DefaultPlaneSelect : public BaseCellSelect
 {
@@ -996,7 +985,7 @@ struct StructuredPlaneSelect : public DefaultPlaneSelect
 } // anonymous namespace
 
 //================================Sphere Tree class proper===================
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct object.
 vtkSphereTree::vtkSphereTree()
 {
@@ -1007,14 +996,14 @@ vtkSphereTree::vtkSphereTree()
   this->NumberOfLevels = 0;
   this->Tree = nullptr;
   this->Hierarchy = nullptr;
-  this->BuildHierarchy = 1;
+  this->BuildHierarchy = true;
   this->SphereTreeType = VTK_SPHERE_TREE_HIERARCHY_NONE;
   this->AverageRadius = 0.0;
   this->SphereBounds[0] = this->SphereBounds[1] = this->SphereBounds[2] = 0.0;
   this->SphereBounds[3] = this->SphereBounds[4] = this->SphereBounds[5] = 0.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Destroy object.
 vtkSphereTree::~vtkSphereTree()
 {
@@ -1029,7 +1018,7 @@ vtkSphereTree::~vtkSphereTree()
 }
 
 //================General tree methods========================================
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSphereTree::Build()
 {
   if (!this->DataSet)
@@ -1042,7 +1031,7 @@ void vtkSphereTree::Build()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSphereTree::Build(vtkDataSet* input)
 {
   this->SetDataSet(input);
@@ -1063,7 +1052,7 @@ void vtkSphereTree::Build(vtkDataSet* input)
   this->BuildTime.Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Compute the sphere tree leafs (i.e., spheres around each cell)
 void vtkSphereTree::BuildTreeSpheres(vtkDataSet* input)
 {
@@ -1109,7 +1098,7 @@ void vtkSphereTree::BuildTreeSpheres(vtkDataSet* input)
   this->BuildTime.Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSphereTree::BuildTreeHierarchy(vtkDataSet* input)
 {
   if (input->GetDataObjectType() == VTK_STRUCTURED_GRID)
@@ -1132,7 +1121,7 @@ void vtkSphereTree::BuildTreeHierarchy(vtkDataSet* input)
 }
 
 //================Specialized methods for structured grids====================
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // From the leaf spheres, build a sphere tree. Use the structure of the grid
 // to control how the sphere tree hierarchy is constructed.
 void vtkSphereTree::BuildStructuredHierarchy(vtkStructuredGrid* input, double* tree)
@@ -1371,7 +1360,7 @@ void vtkSphereTree::BuildUnstructuredHierarchy(vtkDataSet* input, double* tree)
   }     // k
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Note that there is a long story behind these crude methods for selecting
 // cells based on a sphere tree. Initially there was a complex hierarchy of
 // iterators for different dataset types and geometric intersection entities
@@ -1422,7 +1411,7 @@ const unsigned char* vtkSphereTree::SelectPoint(double x[3], vtkIdType& numSelec
   return this->Selected;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Create selection mask based on intersection with an infinite line.
 const unsigned char* vtkSphereTree::SelectLine(
   double origin[3], double ray[3], vtkIdType& numSelected)
@@ -1466,7 +1455,7 @@ const unsigned char* vtkSphereTree::SelectLine(
   return this->Selected;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Create selection mask based on intersection with an infinite plane.
 const unsigned char* vtkSphereTree::SelectPlane(
   double origin[3], double normal[3], vtkIdType& numSelected)
@@ -1511,14 +1500,14 @@ const unsigned char* vtkSphereTree::SelectPlane(
   return this->Selected;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Simply return the leaf spheres
 const double* vtkSphereTree::GetCellSpheres()
 {
   return this->TreePtr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // The number of levels is this->NumberOfLevels, with
 // (this->NumberOfLevels-1) the cell (leaf) spheres, and level 0 the root
 // level.
@@ -1558,7 +1547,7 @@ const double* vtkSphereTree::GetTreeSpheres(int level, vtkIdType& numSpheres)
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSphereTree::SelectPoint(double point[3], vtkIdList* cellIds)
 {
   vtkIdType numSelected;
@@ -1566,7 +1555,7 @@ void vtkSphereTree::SelectPoint(double point[3], vtkIdList* cellIds)
   this->ExtractCellIds(selected, cellIds, numSelected);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSphereTree::SelectLine(double origin[3], double ray[3], vtkIdList* cellIds)
 {
   vtkIdType numSelected;
@@ -1574,7 +1563,7 @@ void vtkSphereTree::SelectLine(double origin[3], double ray[3], vtkIdList* cellI
   this->ExtractCellIds(selected, cellIds, numSelected);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSphereTree::SelectPlane(double origin[3], double normal[3], vtkIdList* cellIds)
 {
   vtkIdType numSelected;
@@ -1582,7 +1571,7 @@ void vtkSphereTree::SelectPlane(double origin[3], double normal[3], vtkIdList* c
   this->ExtractCellIds(selected, cellIds, numSelected);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSphereTree::ExtractCellIds(
   const unsigned char* selected, vtkIdList* cellIds, vtkIdType numSelected)
 {
@@ -1607,7 +1596,7 @@ void vtkSphereTree::ExtractCellIds(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSphereTree::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -1617,3 +1606,11 @@ void vtkSphereTree::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Maximum Number Of Levels: " << this->MaxLevel << "\n";
   os << indent << "Build Hierarchy: " << (this->BuildHierarchy ? "On\n" : "Off\n");
 }
+
+//------------------------------------------------------------------------------
+void vtkSphereTree::ReportReferences(vtkGarbageCollector* collector)
+{
+  this->Superclass::ReportReferences(collector);
+  vtkGarbageCollectorReport(collector, this->DataSet, "DataSet");
+}
+VTK_ABI_NAMESPACE_END
