@@ -375,7 +375,7 @@ struct SurfaceNets
   // connections to each of the cell's six face neighbors. The table consists
   // of: 1) the number of edge connections, and 2) 0/1 values indicating
   // which of the six edge are to be generated. The table of stencil cases was
-  // generated programatically (see GenerateStencils).
+  // generated programmatically (see GenerateStencils).
   static const unsigned char StencilFaceCases[64][7];
   static unsigned char GetNumberOfStencilFaceEdges(FaceCaseType caseNum)
   {
@@ -389,7 +389,7 @@ struct SurfaceNets
 
   // This smoothing stencil table is indexed by the voxel *edge* case. It
   // indexes into the face-case-based smoothing stenciles. This table is
-  // constructed programatically.
+  // constructed programmatically.
   unsigned char GetNumberOfStencilEdges(EdgeCaseType caseNum)
   {
     return SurfaceNets::StencilFaceCases[this->StencilTable[caseNum]][0];
@@ -402,7 +402,7 @@ struct SurfaceNets
 
   // Return whether a triad, and its associated voxel cell, requires the
   // generation of a point.
-  inline bool ProducesPoint(TriadType triad) { return (triad & SurfaceNets::ProducePoint) > 0; }
+  bool ProducesPoint(TriadType triad) { return (triad & SurfaceNets::ProducePoint) > 0; }
 
   // Input and output data.
   T* Scalars;                // input image scalars
@@ -773,7 +773,7 @@ struct SurfaceNets
   void GeneratePoint(vtkIdType ptId, vtkIdType i, vtkIdType j, vtkIdType k)
   {
     float* x = this->NewPts + 3 * ptId;
-    x[0] = this->Min0 + static_cast<float>(i) - 0.5,
+    x[0] = this->Min0 + static_cast<float>(i) - 0.5;
     x[1] = this->Min1 + static_cast<float>(j) - 0.5;
     x[2] = this->Min2 + static_cast<float>(k) - 0.5;
   }
@@ -1185,7 +1185,7 @@ void SurfaceNets<T>::ClassifyXEdges(
     else
     {
       // Processing triads which are associated with voxels.
-      s1 = static_cast<T>(inPtr[i * this->Inc0]);
+      s1 = inPtr[i * this->Inc0];
       isLV1 = (s0 == s1 ? isLV0 : lMap->IsLabelValue(s1));
     }
 
@@ -1396,8 +1396,9 @@ void SurfaceNets<T>::ConfigureOutput(
     // Edge groups consist of four neighboring volume x-edges (+/-y,+/-z). Process
     // in interleaving fashion (i.e., checkerboard) to avoid races (ProduceVoxelCases()
     // may write to the voxel classifications while they are being processed).
-    vtkSMPTools::For(
-      0, numGroups, [this, edgeNum, numRowPairs](vtkIdType group, vtkIdType endGroup) {
+    vtkSMPTools::For(0, numGroups,
+      [this, edgeNum, numRowPairs](vtkIdType group, vtkIdType endGroup)
+      {
         for (; group < endGroup; ++group)
         {
           this->ProduceVoxelCases(group, edgeNum, numRowPairs);
@@ -1741,18 +1742,20 @@ struct NetsWorker
     // which will likely by updated in pass1, pass2, or pass3.
     algo.NumberOfEdges = algo.TriadDims[1] * algo.TriadDims[2]; // y-z plane of edges
     algo.EdgeMetaData = new vtkIdType[algo.NumberOfEdges * algo.EdgeMetaDataSize]();
-    vtkSMPTools::For(0, algo.NumberOfEdges, [&](vtkIdType begin, vtkIdType end) {
-      for (vtkIdType eNum = begin; eNum < end; ++eNum)
+    vtkSMPTools::For(0, algo.NumberOfEdges,
+      [&](vtkIdType begin, vtkIdType end)
       {
-        vtkIdType* eMD = algo.EdgeMetaData + eNum * algo.EdgeMetaDataSize;
-        eMD[3] = algo.TriadDims[0];
-        eMD[4] = 0;
-      }
-    });
+        for (vtkIdType eNum = begin; eNum < end; ++eNum)
+        {
+          vtkIdType* eMD = algo.EdgeMetaData + eNum * algo.EdgeMetaDataSize;
+          eMD[3] = algo.TriadDims[0];
+          eMD[4] = 0;
+        }
+      });
 
     // Compute the starting offset location for scalar data.  We may be operating
     // on a part of the volume.
-    ValueType* scalars = static_cast<ValueType*>(static_cast<ST*>(scalarsArray)->GetPointer(0));
+    ValueType* scalars = static_cast<ValueType*>(scalarsArray->GetPointer(0));
     algo.Scalars = scalars + incs[0] * (updateExt[0] - ext[0]) + incs[1] * (updateExt[2] - ext[2]) +
       incs[2] * (updateExt[4] - ext[4]) + self->GetArrayComponent();
 
@@ -1813,7 +1816,7 @@ void ComputeSmoothingConstraints(
 void SmoothOutput(vtkPolyData* geomCache, vtkCellArray* stencils, vtkPolyData* output,
   vtkConstrainedSmoothingFilter* smoother)
 {
-  vtkLog(INFO, "Smoothing output");
+  vtkLog(TRACE, "Smoothing output");
 
   // Smooth the data and replace the output points.
   smoother->SetInputData(geomCache);
@@ -2024,12 +2027,12 @@ struct TransformMeshToTris : public TransformMesh
 void TransformMeshType(
   int outputMeshType, vtkPolyData* output, vtkDataArray* newScalars, int triStrategy)
 {
-  // Ensure that we have a specfic type, and that we are not requesting
+  // Ensure that we have a specific type, and that we are not requesting
   // quads which are already available.
   outputMeshType =
     (outputMeshType == vtkSurfaceNets3D::MESH_TYPE_DEFAULT ? vtkSurfaceNets3D::MESH_TYPE_TRIANGLES
                                                            : outputMeshType);
-  vtkLog(INFO, "Transforming output mesh type to: " << outputMeshType);
+  vtkLog(TRACE, "Transforming output mesh type to: " << outputMeshType);
 
   if (outputMeshType == vtkSurfaceNets3D::MESH_TYPE_QUADS)
   {
@@ -2138,8 +2141,8 @@ struct SelectWorker
     // Traverse all existing cells and mark those satisfying outputStyle
     // criterion for extraction.
     vtkSMPTools::For(0, numCells,
-      [&newScalars, outputStyle, &selectedCells, self, lMap](
-        vtkIdType cellId, vtkIdType endCellId) {
+      [&newScalars, outputStyle, &selectedCells, self, lMap](vtkIdType cellId, vtkIdType endCellId)
+      {
         const auto inTuples = vtk::DataArrayTupleRange<2>(newScalars);
         ValueType backgroundLabel = static_cast<ValueType>(self->GetBackgroundLabel());
         for (; cellId < endCellId; ++cellId)
@@ -2179,7 +2182,8 @@ struct SelectWorker
     vtkSMPThreadLocalObject<vtkIdList> tlIdList;
     vtkSMPTools::For(0, numCells,
       [newCells, &selectedCells, &outCells, cellSize, &tlIdList](
-        vtkIdType cellId, vtkIdType endCellId) {
+        vtkIdType cellId, vtkIdType endCellId)
+      {
         auto& idList = tlIdList.Local();
         vtkIdType npts;
         const vtkIdType* pts;
@@ -2201,7 +2205,8 @@ struct SelectWorker
     outScalars->SetNumberOfComponents(2);
     outScalars->SetNumberOfTuples(numOutCells);
     vtkSMPTools::For(0, numCells,
-      [&selectedCells, &newScalars, &outScalars](vtkIdType cellId, vtkIdType endCellId) {
+      [&selectedCells, &newScalars, &outScalars](vtkIdType cellId, vtkIdType endCellId)
+      {
         const auto inTuples = vtk::DataArrayTupleRange<2>(newScalars);
         auto outTuples = vtk::DataArrayTupleRange<2>(outScalars);
         for (; cellId < endCellId; ++cellId)
@@ -2319,7 +2324,7 @@ double vtkSurfaceNets3D::GetSelectedLabel(vtkIdType ithLabel)
 int vtkSurfaceNets3D::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
-  vtkLog(INFO, "Executing Surface Nets 3D");
+  vtkLog(TRACE, "Executing Surface Nets 3D");
 
   // Get the information objects
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
@@ -2391,7 +2396,7 @@ int vtkSurfaceNets3D::RequestData(vtkInformation* vtkNotUsed(request),
       return 1;
     }
 
-    vtkLog(INFO,
+    vtkLog(TRACE,
       "Extracted: " << newPts->GetNumberOfPoints() << " points, " << newQuads->GetNumberOfCells()
                     << " quads");
 
@@ -2444,7 +2449,7 @@ int vtkSurfaceNets3D::RequestData(vtkInformation* vtkNotUsed(request),
   {
     TransformMeshType(this->OutputMeshType, output, newScalars, this->TriangulationStrategy);
     cellSize = 3;
-    vtkLog(INFO, "Triangulated to produce: " << output->GetNumberOfCells() << " triangles");
+    vtkLog(TRACE, "Triangulated to produce: " << output->GetNumberOfCells() << " triangles");
   }
 
   // If the output style is other than default, then extra works needs
@@ -2457,7 +2462,7 @@ int vtkSurfaceNets3D::RequestData(vtkInformation* vtkNotUsed(request),
     SelectWorker selectWorker;
     SelectDispatch::Execute(output->GetCellData()->GetArray("BoundaryLabels"), selectWorker, output,
       this->OutputStyle, this, cellSize);
-    vtkLog(INFO, "Selected: " << output->GetNumberOfCells() << " cells");
+    vtkLog(TRACE, "Selected: " << output->GetNumberOfCells() << " cells");
   }
 
   // Flush the cache if caching is disabled.
