@@ -88,6 +88,8 @@ vtkStreamTracer::vtkStreamTracer()
   this->SerialExecution = false;
 
   this->UseLocalSeedSource = true;
+
+  this->InterpolatorType = vtkStreamTracer::INTERPOLATOR_WITH_DATASET_POINT_LOCATOR;
 }
 
 //------------------------------------------------------------------------------
@@ -156,20 +158,7 @@ void vtkStreamTracer::SetInterpolatorTypeToCellLocator()
 //------------------------------------------------------------------------------
 void vtkStreamTracer::SetInterpolatorType(int interpType)
 {
-  vtkNew<vtkCompositeInterpolatedVelocityField> cIVF;
-  if (interpType == INTERPOLATOR_WITH_CELL_LOCATOR)
-  {
-    // create an interpolator equipped with a cell locator
-    vtkNew<vtkCellLocatorStrategy> strategy;
-    cIVF->SetFindCellStrategy(strategy);
-  }
-  else
-  {
-    // create an interpolator equipped with a point locator (by default)
-    vtkNew<vtkClosestPointStrategy> strategy;
-    cIVF->SetFindCellStrategy(strategy);
-  }
-  this->SetInterpolatorPrototype(cIVF);
+  this->InterpolatorType = interpType;
 }
 
 //------------------------------------------------------------------------------
@@ -487,6 +476,44 @@ int vtkStreamTracer::RequestData(vtkInformation* vtkNotUsed(request),
       amr->GenerateParentChildInformation();
     }
 
+    // Set Interplation Type
+    if (vtkOverlappingAMR::SafeDownCast(this->InputData))
+    {
+      vtkNew<vtkAMRInterpolatedVelocityField> cIVF;
+      if (this->InterpolatorType == vtkStreamTracer::INTERPOLATOR_WITH_CELL_LOCATOR)
+      {
+        // create an interpolator equipped with a cell locator
+        vtkNew<vtkCellLocatorStrategy> strategy;
+        cIVF->SetFindCellStrategy(strategy);
+      }
+      else
+      {
+        // create an interpolator equipped with a point locator (by default)
+        vtkNew<vtkClosestPointStrategy> strategy;
+        cIVF->SetFindCellStrategy(strategy);
+      }
+
+      this->SetInterpolatorPrototype(cIVF);
+    }
+    else
+    {
+      vtkNew<vtkCompositeInterpolatedVelocityField> cIVF;
+      if (this->InterpolatorType == vtkStreamTracer::INTERPOLATOR_WITH_CELL_LOCATOR)
+      {
+        // create an interpolator equipped with a cell locator
+        vtkNew<vtkCellLocatorStrategy> strategy;
+        cIVF->SetFindCellStrategy(strategy);
+      }
+      else
+      {
+        // create an interpolator equipped with a point locator (by default)
+        vtkNew<vtkClosestPointStrategy> strategy;
+        cIVF->SetFindCellStrategy(strategy);
+      }
+
+      this->SetInterpolatorPrototype(cIVF);
+    }
+
     // The data that is interpolated comes from the "shape" of the input
     // point data.  This gets tricky when the data is composite, we need to
     // find a leaf dataset which defines the shape.
@@ -742,34 +769,16 @@ struct vtkLocalThreadOutput
   // doesn't work with smart pointers. The copy constructor is used to create
   // instances of vtkLocalThreadOutput for each thread.
   vtkLocalThreadOutput(const vtkLocalThreadOutput& other)
+    : vtkLocalThreadOutput()
   {
-    this->Cell.TakeReference(vtkGenericCell::New());
-    this->OutputPoints.TakeReference(vtkPoints::New());
-
-    this->Time.TakeReference(vtkDoubleArray::New());
-    this->Time->SetName("IntegrationTime");
-
-    this->VelocityVectors.TakeReference(vtkDoubleArray::New());
-
-    this->CellVectors.TakeReference(vtkDoubleArray::New());
-    this->CellVectors->SetNumberOfComponents(3);
-    this->CellVectors->Allocate(3 * VTK_CELL_SIZE);
-
-    this->Vorticity.TakeReference(vtkDoubleArray::New());
-    this->Vorticity->SetNumberOfComponents(3);
-    this->Vorticity->SetName("Vorticity");
-
-    this->Rotation.TakeReference(vtkDoubleArray::New());
-    this->Rotation->SetName("Rotation");
-
-    this->AngularVelocity.TakeReference(vtkDoubleArray::New());
-    this->AngularVelocity->SetName("AngularVelocity");
-
-    this->Output.TakeReference(vtkPolyData::New());
-    this->OutputPD = this->Output->GetPointData();
-
     this->LastUsedStepSize = other.LastUsedStepSize;
   }
+
+  vtkLocalThreadOutput& operator=(const vtkLocalThreadOutput& other)
+  {
+    this->LastUsedStepSize = other.LastUsedStepSize;
+    return *this;
+  };
 };
 
 // In order to ensure that the threaded output is the same as serial output,
@@ -1100,6 +1109,7 @@ struct TracerIntegrator
       {
         if (vecType == vtkDataObject::POINT)
         {
+          cellVectors->SetNumberOfTuples(cell->PointIds->GetNumberOfIds());
           inVectors->GetTuples(cell->PointIds, cellVectors);
           func->GetLastLocalCoordinates(pcoords);
           this->StreamTracer->CalculateVorticity(cell, pcoords, cellVectors, vort);
@@ -1275,6 +1285,7 @@ struct TracerIntegrator
           {
             if (vecType == vtkDataObject::POINT)
             {
+              cellVectors->SetNumberOfTuples(cell->PointIds->GetNumberOfIds());
               inVectors->GetTuples(cell->PointIds, cellVectors);
               func->GetLastLocalCoordinates(pcoords);
               this->StreamTracer->CalculateVorticity(cell, pcoords, cellVectors, vort);
@@ -1523,6 +1534,11 @@ struct TracerIntegrator
     vtkPointData* threadPD = this->LocalThreadOutput.begin()->OutputPD;
     vtkPointData* outputPD = this->Output->GetPointData();
     outputPD->CopyAllocate(threadPD, numPts);
+    // Threads will fight over array MaxId unless we set it beforehand
+    for (int i = 0; i < outputPD->GetNumberOfArrays(); ++i)
+    {
+      outputPD->GetArray(i)->SetNumberOfTuples(numPts);
+    }
 
     // Allocate streamer cell data: seed ids and streamer termination return
     // values. Only add this information if the number of output cells
@@ -1660,12 +1676,14 @@ void vtkStreamTracer::GenerateNormals(vtkPolyData* output, double* firstNormal,
   // Make sure the normals are initialized in case
   // GenerateSlidingNormals() fails and returns before
   // creating all normals
-  vtkSMPTools::For(0, numPts, [&](vtkIdType ptId, vtkIdType endPtId) {
-    for (; ptId < endPtId; ++ptId)
+  vtkSMPTools::For(0, numPts,
+    [&](vtkIdType ptId, vtkIdType endPtId)
     {
-      normals->SetTuple3(ptId, 1, 0, 0);
-    }
-  });
+      for (; ptId < endPtId; ++ptId)
+      {
+        normals->SetTuple3(ptId, 1, 0, 0);
+      }
+    });
 
   // Generate the orientation normals. This will be threaded since none of the
   // lines "reuse" points from another line.
@@ -1682,33 +1700,35 @@ void vtkStreamTracer::GenerateNormals(vtkPolyData* output, double* firstNormal,
   }
 
   // Thread the final normal generation
-  vtkSMPTools::For(0, numPts, [&](vtkIdType ptId, vtkIdType endPtId) {
-    double normal[3], local1[3], local2[3], theta, costheta, sintheta, length;
-    double velocity[3];
-    for (; ptId < endPtId; ++ptId)
+  vtkSMPTools::For(0, numPts,
+    [&](vtkIdType ptId, vtkIdType endPtId)
     {
-      normals->GetTuple(ptId, normal);
-      newVectors->GetTuple(ptId, velocity);
-      // obtain two unit orthogonal vectors on the plane perpendicular to
-      // the streamline
-      for (auto j = 0; j < 3; j++)
+      double normal[3], local1[3], local2[3], theta, costheta, sintheta, length;
+      double velocity[3];
+      for (; ptId < endPtId; ++ptId)
       {
-        local1[j] = normal[j];
+        normals->GetTuple(ptId, normal);
+        newVectors->GetTuple(ptId, velocity);
+        // obtain two unit orthogonal vectors on the plane perpendicular to
+        // the streamline
+        for (auto j = 0; j < 3; j++)
+        {
+          local1[j] = normal[j];
+        }
+        length = vtkMath::Normalize(local1);
+        vtkMath::Cross(local1, velocity, local2);
+        vtkMath::Normalize(local2);
+        // Rotate the normal with theta
+        rotation->GetTuple(ptId, &theta);
+        costheta = std::cos(theta);
+        sintheta = std::sin(theta);
+        for (auto j = 0; j < 3; j++)
+        {
+          normal[j] = length * (costheta * local1[j] + sintheta * local2[j]);
+        }
+        normals->SetTuple(ptId, normal);
       }
-      length = vtkMath::Normalize(local1);
-      vtkMath::Cross(local1, velocity, local2);
-      vtkMath::Normalize(local2);
-      // Rotate the normal with theta
-      rotation->GetTuple(ptId, &theta);
-      costheta = std::cos(theta);
-      sintheta = std::sin(theta);
-      for (auto j = 0; j < 3; j++)
-      {
-        normal[j] = length * (costheta * local1[j] + sintheta * local2[j]);
-      }
-      normals->SetTuple(ptId, normal);
-    }
-  }); // lambda
+    }); // lambda
 
   // Associate normals with the output
   outputPD->AddArray(normals);
