@@ -66,9 +66,17 @@ protected:
   virtual int MergeDataObjectFields(vtkDataObject* input, int inputIndex, vtkDataObject* output);
   ///@}
 
-  // see algorithm for more info
+  /**
+   * Make sure that this filter can take a dynamic number of input.
+   */
   int FillInputPortInformation(int port, vtkInformation* info) override;
 
+  /**
+   * Gets the metadata from input information and aggregates time information to the output.
+   */
+  int RequestInformation(vtkInformation* request, vtkInformationVector** inputVector,
+    vtkInformationVector* outputVector) override;
+
   int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
 private:
