@@ -240,7 +240,7 @@ int TestHyperTreeGridTernary2DFullMaterialBits(int argc, char* argv[])
   renderer->AddActor(actor2);
   renderer->AddActor(actor3);
   renderer->AddActor(actor4);
-  renderer->AddActor2D(scalarBar);
+  renderer->AddViewProp(scalarBar);
 
   // Render window
   vtkNew<vtkRenderWindow> renWin;
@@ -255,7 +255,7 @@ int TestHyperTreeGridTernary2DFullMaterialBits(int argc, char* argv[])
   // Render and test
   renWin->Render();
 
-  int retVal = vtkRegressionTestImageThreshold(renWin, 70);
+  int retVal = vtkRegressionTestImageThreshold(renWin, 0.05);
   if (retVal == vtkRegressionTester::DO_INTERACTOR)
   {
     iren->Start();
