@@ -119,7 +119,7 @@ int TestHyperTreeGridTernary3DAxisReflectionXCenterMaterial(int argc, char* argv
   // Render and test
   renWin->Render();
 
-  int retVal = vtkRegressionTestImageThreshold(renWin, 110);
+  int retVal = vtkRegressionTestImageThreshold(renWin, 0.05);
   if (retVal == vtkRegressionTester::DO_INTERACTOR)
   {
     iren->Start();
