@@ -1,23 +1,10 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkHyperTreeGridToUnstructuredGrid.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkHyperTreeGridToUnstructuredGrid
  * @brief   Convert hyper tree grid to
  * unstructured grid.
  *
- JB Primal mesh
  * Make explicit all leaves of a hyper tree grid by converting them to cells
  * of an unstructured grid.
  * Produces segments in 1D, rectangles in 2D, right hexahedra in 3D.
@@ -35,7 +22,7 @@
  * This class was corriged (used orientation) by Jacques-Bernard Lekien, 2018
  * This work was supported by Commissariat a l'Energie Atomique
  * CEA, DAM, DIF, F-91297 Arpajon, France.
-*/
+ */
 
 #ifndef vtkHyperTreeGridToUnstructuredGrid_h
 #define vtkHyperTreeGridToUnstructuredGrid_h
@@ -43,9 +30,11 @@
 #include "vtkFiltersHyperTreeModule.h" // For export macro
 #include "vtkHyperTreeGridAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkBitArray;
 class vtkCellArray;
 class vtkHyperTreeGrid;
+class vtkIdTypeArray;
 class vtkPoints;
 class vtkUnstructuredGrid;
 class vtkHyperTreeGridNonOrientedGeometryCursor;
@@ -56,7 +45,16 @@ class VTKFILTERSHYPERTREE_EXPORT vtkHyperTreeGridToUnstructuredGrid
 public:
   static vtkHyperTreeGridToUnstructuredGrid* New();
   vtkTypeMacro(vtkHyperTreeGridToUnstructuredGrid, vtkHyperTreeGridAlgorithm);
-  void PrintSelf(ostream&, vtkIndent) override;
+  void PrintSelf(ostream& os, vtkIndent indent) override;
+
+  ///@{
+  /**
+   * Add a cell array with original HTG ids
+   */
+  vtkGetMacro(AddOriginalIds, bool);
+  vtkSetMacro(AddOriginalIds, bool);
+  vtkBooleanMacro(AddOriginalIds, bool);
+  ///@}
 
 protected:
   vtkHyperTreeGridToUnstructuredGrid();
@@ -99,9 +97,13 @@ protected:
   unsigned int Orientation;
   const unsigned int* Axes;
 
+  bool AddOriginalIds;
+  vtkIdTypeArray* OriginalIds;
+
 private:
   vtkHyperTreeGridToUnstructuredGrid(const vtkHyperTreeGridToUnstructuredGrid&) = delete;
   void operator=(const vtkHyperTreeGridToUnstructuredGrid&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif /* vtkHyperTreeGridToUnstructuredGrid_h */
