@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkCollectPolyData.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkCollectPolyData
  * @brief   Collect distributed polydata.
@@ -26,6 +14,7 @@
 #include "vtkFiltersParallelModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMultiProcessController;
 class vtkSocketController;
 
@@ -36,16 +25,16 @@ public:
   vtkTypeMacro(vtkCollectPolyData, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * By default this filter uses the global controller,
    * but this method can be used to set another instead.
    */
   virtual void SetController(vtkMultiProcessController*);
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When this filter is being used in client-server mode,
    * this is the controller used to communicate between
@@ -53,16 +42,16 @@ public:
    */
   virtual void SetSocketController(vtkSocketController*);
   vtkGetObjectMacro(SocketController, vtkSocketController);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * To collect or just copy input to output. Off (collect) by default.
    */
   vtkSetMacro(PassThrough, vtkTypeBool);
   vtkGetMacro(PassThrough, vtkTypeBool);
   vtkBooleanMacro(PassThrough, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkCollectPolyData();
@@ -82,4 +71,5 @@ private:
   void operator=(const vtkCollectPolyData&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
