@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPYoungsMaterialInterface.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkPYoungsMaterialInterface
  * @brief   parallel reconstruction of material interfaces
@@ -36,6 +24,7 @@
 #include "vtkFiltersParallelModule.h" // For export macro
 #include "vtkYoungsMaterialInterface.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMultiProcessController;
 
 class VTKFILTERSPARALLEL_EXPORT vtkPYoungsMaterialInterface : public vtkYoungsMaterialInterface
@@ -50,14 +39,14 @@ public:
    */
   void Aggregate(int, int*) override;
 
-  //@{
+  ///@{
   /**
    * Get/Set the multiprocess controller. If no controller is set,
    * single process is assumed.
    */
   virtual void SetController(vtkMultiProcessController*);
   vtkGetObjectMacro(Controller, vtkMultiProcessController);
-  //@}
+  ///@}
 
 protected:
   vtkPYoungsMaterialInterface();
@@ -70,4 +59,5 @@ private:
   void operator=(const vtkPYoungsMaterialInterface&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif /* VTK_PYOUNGS_MATERIAL_INTERFACE_H */
