@@ -1,25 +1,6 @@
-/*=========================================================================
-
-Program:   Visualization Toolkit
-Module:    TestRandomPOrderStatisticsMPI.cxx
-
-Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-All rights reserved.
-See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*
- * Copyright 2011 Sandia Corporation.
- * Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
- * license for use of this work by or on behalf of the
- * U.S. Government. Redistribution and use in source and binary forms, with
- * or without modification, are permitted provided that this Notice and any
- * statement of authorship are reproduced on all copies.
- */
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2011 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 // .SECTION Thanks
 // Thanks to Philippe Pebay for implementing this test.
 
@@ -33,7 +14,6 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkMPIController.h"
 #include "vtkMath.h"
 #include "vtkMultiBlockDataSet.h"
-#include "vtkStdString.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
 #include "vtkTimerLog.h"
@@ -76,7 +56,7 @@ void RandomOrderStatistics(vtkMultiProcessController* controller, void* arg)
   // Generate an input table that contains samples of:
   // 1. A truncated Gaussian pseudo-random variable (vtkIntArray)
   // 2. A uniform pseudo-random variable of characters (vtkStringArray)
-  vtkStdString columnNames[] = { "Rounded Normal Integer", "Uniform Character" };
+  std::string columnNames[] = { "Rounded Normal Integer", "Uniform Character" };
 
   // Infer number and type of generated variables based on command line options
   int nVariables = 0;
@@ -95,12 +75,12 @@ void RandomOrderStatistics(vtkMultiProcessController* controller, void* arg)
   // Prepare column of integers
   vtkIntArray* intArray = vtkIntArray::New();
   intArray->SetNumberOfComponents(1);
-  intArray->SetName(columnNames[0]);
+  intArray->SetName(columnNames[0].c_str());
 
   // Prepare column of strings
   vtkStringArray* strArray = vtkStringArray::New();
   strArray->SetNumberOfComponents(1);
-  strArray->SetName(columnNames[1]);
+  strArray->SetName(columnNames[1].c_str());
 
   // Storage for pseudo-random values and local extrema
   int* v = new int[nVariables];
@@ -123,7 +103,7 @@ void RandomOrderStatistics(vtkMultiProcessController* controller, void* arg)
   {
     v[idx] = 96 + vtkMath::Ceil(vtkMath::Random() * 26);
     char c = static_cast<char>(v[idx]);
-    vtkStdString s(&c, 1);
+    std::string s(&c, 1);
     strArray->InsertNextValue(s);
   }
 
@@ -153,7 +133,7 @@ void RandomOrderStatistics(vtkMultiProcessController* controller, void* arg)
     {
       v[idx] = 96 + vtkMath::Ceil(vtkMath::Random() * 26);
       char c = static_cast<char>(v[idx]);
-      vtkStdString s(&c, 1);
+      std::string s(&c, 1);
       strArray->InsertNextValue(s);
     }
 
@@ -232,11 +212,11 @@ void RandomOrderStatistics(vtkMultiProcessController* controller, void* arg)
   // Select columns of interest depending on command line choices
   if (!args->skipInt)
   {
-    pos->AddColumn(columnNames[0]);
+    pos->AddColumn(columnNames[0].c_str());
   }
   if (!args->skipString)
   {
-    pos->AddColumn(columnNames[1]);
+    pos->AddColumn(columnNames[1].c_str());
   }
 
   // Test (in parallel) with Learn, Derive, and Assess options turned on
@@ -331,10 +311,10 @@ void RandomOrderStatistics(vtkMultiProcessController* controller, void* arg)
       if (min_c.IsString())
       {
         char c = static_cast<char>(min_g[i]);
-        if (min_c.ToString() != vtkStdString(&c, 1))
+        if (min_c.ToString() != std::string(&c, 1))
         {
           vtkGenericWarningMacro("Incorrect calculated minimum for variable "
-            << columnNames[i] << ": " << min_c.ToString() << " <> " << vtkStdString(&c, 1));
+            << columnNames[i] << ": " << min_c.ToString() << " <> " << std::string(&c, 1));
           *(args->retVal) = 1;
         }
       } // if ( min_c.IsString() )
@@ -352,10 +332,10 @@ void RandomOrderStatistics(vtkMultiProcessController* controller, void* arg)
       if (max_c.IsString())
       {
         char c = static_cast<char>(max_g[i]);
-        if (max_c.ToString() != vtkStdString(&c, 1))
+        if (max_c.ToString() != std::string(&c, 1))
         {
           vtkGenericWarningMacro("Incorrect calculated maximum for variable "
-            << columnNames[i] << ": " << max_c.ToString() << " <> " << vtkStdString(&c, 1));
+            << columnNames[i] << ": " << max_c.ToString() << " <> " << std::string(&c, 1));
           *(args->retVal) = 1;
         }
       }
@@ -382,7 +362,7 @@ void RandomOrderStatistics(vtkMultiProcessController* controller, void* arg)
 
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int TestRandomPOrderStatisticsMPI(int argc, char* argv[])
 {
   // **************************** MPI Initialization ***************************
