@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkRegularPolygonSource.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkRegularPolygonSource
  * @brief   create a regular, n-sided polygon and/or polyline
@@ -30,37 +18,38 @@
 #include "vtkFiltersSourcesModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSSOURCES_EXPORT vtkRegularPolygonSource : public vtkPolyDataAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for instantiation, obtaining type and printing instance values.
    */
   static vtkRegularPolygonSource* New();
   vtkTypeMacro(vtkRegularPolygonSource, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the number of sides of the polygon. By default, the number of sides
    * is set to six.
    */
   vtkSetClampMacro(NumberOfSides, int, 3, VTK_INT_MAX);
   vtkGetMacro(NumberOfSides, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the center of the polygon. By default, the center is set at the
    * origin (0,0,0).
    */
   vtkSetVector3Macro(Center, double);
   vtkGetVectorMacro(Center, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the normal to the polygon. The ordering of the polygon will be
    * counter-clockwise around the normal (i.e., using the right-hand rule).
@@ -68,35 +57,35 @@ public:
    */
   vtkSetVector3Macro(Normal, double);
   vtkGetVectorMacro(Normal, double, 3);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the radius of the polygon. By default, the radius is set to 0.5.
    */
   vtkSetMacro(Radius, double);
   vtkGetMacro(Radius, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Control whether a polygon is produced. By default, GeneratePolygon is enabled.
    */
   vtkSetMacro(GeneratePolygon, vtkTypeBool);
   vtkGetMacro(GeneratePolygon, vtkTypeBool);
   vtkBooleanMacro(GeneratePolygon, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Control whether a polyline is produced. By default, GeneratePolyline is enabled.
    */
   vtkSetMacro(GeneratePolyline, vtkTypeBool);
   vtkGetMacro(GeneratePolyline, vtkTypeBool);
   vtkBooleanMacro(GeneratePolyline, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output points.
    * vtkAlgorithm::SINGLE_PRECISION - Output single-precision floating point.
@@ -104,11 +93,11 @@ public:
    */
   vtkSetMacro(OutputPointsPrecision, int);
   vtkGetMacro(OutputPointsPrecision, int);
-  //@}
+  ///@}
 
 protected:
   vtkRegularPolygonSource();
-  ~vtkRegularPolygonSource() override {}
+  ~vtkRegularPolygonSource() override = default;
 
   int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
@@ -125,4 +114,5 @@ private:
   void operator=(const vtkRegularPolygonSource&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
