@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkRIBProperty.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkRIBProperty
  * @brief   RIP Property
@@ -31,6 +19,7 @@
 #include "vtkIOExportModule.h" // For export macro
 #include "vtkProperty.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkRIBRenderer;
 
 class VTKIOEXPORT_EXPORT vtkRIBProperty : public vtkProperty
@@ -40,7 +29,7 @@ public:
   vtkTypeMacro(vtkRIBProperty, vtkProperty);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * If true (default) the surface shader uses the usual shader parameters:
    * Ka - Ambient amount
@@ -55,70 +44,70 @@ public:
   vtkSetMacro(SurfaceShaderUsesDefaultParameters, bool);
   vtkGetMacro(SurfaceShaderUsesDefaultParameters, bool);
   vtkBooleanMacro(SurfaceShaderUsesDefaultParameters, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the name of a surface shader.
    */
   vtkSetStringMacro(SurfaceShader);
   vtkGetStringMacro(SurfaceShader);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the name of a displacement shader.
    */
   vtkSetStringMacro(DisplacementShader);
   vtkGetStringMacro(DisplacementShader);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * Specify declarations for variables..
+   * Specify declarations for variables.
    */
   void SetVariable(const char* variable, const char* declaration);
   void AddVariable(const char* variable, const char* declaration);
-  //@}
+  ///@}
 
   /**
    * Get variable declarations
    */
   char* GetDeclarations();
 
-  //@{
+  ///@{
   /**
    * Specify parameter values for variables.
    * DEPRECATED: use (Set/Add)SurfaceShaderParameter instead.
    */
   void SetParameter(const char* parameter, const char* value);
   void AddParameter(const char* parameter, const char* value);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify parameter values for surface shader parameters
    */
   void SetSurfaceShaderParameter(const char* parameter, const char* value);
   void AddSurfaceShaderParameter(const char* parameter, const char* value);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify parameter values for displacement shader parameters
    */
   void SetDisplacementShaderParameter(const char* parameter, const char* value);
   void AddDisplacementShaderParameter(const char* parameter, const char* value);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get parameters.
    */
   char* GetParameters(); // DEPRECATED: use GetSurfaceShaderParameters instead.
   char* GetSurfaceShaderParameters();
   char* GetDisplacementShaderParameters();
-  //@}
+  ///@}
 
 protected:
   vtkRIBProperty();
@@ -138,4 +127,5 @@ private:
   void operator=(const vtkRIBProperty&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
