@@ -1,17 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkX3DExporterFIWriter.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen, Kristian Sons
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Kristian Sons
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkX3DExporterFIWriter.h"
 
 #include "vtkCellArray.h"
@@ -27,11 +16,12 @@
 #include <sstream>
 #include <vector>
 
-//#define ENCODEASSTRING 1
+// #define ENCODEASSTRING 1
 
 using namespace vtkX3D;
 
 /*======================================================================== */
+VTK_ABI_NAMESPACE_BEGIN
 struct NodeInfo
 {
   NodeInfo(int _nodeId)
@@ -83,6 +73,9 @@ public:
   // Get stream info
   std::string GetStringStream(vtkIdType& size);
 
+  // Put bits for line feed.
+  void EncodeLineFeed();
+
 private:
   unsigned char Append(unsigned int value, unsigned char count);
   void TryFlush();
@@ -94,14 +87,14 @@ private:
   void operator=(const vtkX3DExporterFIByteWriter&) = delete;
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkX3DExporterFIByteWriter::~vtkX3DExporterFIByteWriter()
 {
   delete this->Stream;
   this->Stream = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkX3DExporterFIByteWriter::OpenFile(const char* file)
 {
   this->WriteToOutputString = 0;
@@ -121,7 +114,7 @@ int vtkX3DExporterFIByteWriter::OpenFile(const char* file)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkX3DExporterFIByteWriter::OpenStream()
 {
   this->WriteToOutputString = 1;
@@ -131,7 +124,7 @@ int vtkX3DExporterFIByteWriter::OpenStream()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::string vtkX3DExporterFIByteWriter::GetStringStream(vtkIdType& size)
 {
   if (this->WriteToOutputString && this->Stream)
@@ -143,30 +136,35 @@ std::string vtkX3DExporterFIByteWriter::GetStringStream(vtkIdType& size)
   }
 
   size = 0;
-  return nullptr;
+  return std::string();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIByteWriter::TryFlush()
 {
   if (this->CurrentBytePos == 8)
   {
     this->Stream->write((char*)(&(this->CurrentByte)), 1);
+#if defined(__GNUC__) && (__GNUC__ >= 7) && !defined(__clang__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wstringop-overflow"
     this->CurrentByte = 0;
+#pragma GCC diagnostic pop
+#endif
     this->CurrentBytePos = 0;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIByteWriter::FillByte()
 {
   while (this->CurrentBytePos != 0)
   {
-    this->PutBit(0);
+    this->PutBit(false);
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIByteWriter::PutBit(bool on)
 {
   assert(this->CurrentBytePos < 8);
@@ -180,7 +178,7 @@ void vtkX3DExporterFIByteWriter::PutBit(bool on)
   TryFlush();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned char vtkX3DExporterFIByteWriter::Append(unsigned int value, unsigned char count)
 {
   assert(this->CurrentBytePos < 8);
@@ -200,7 +198,7 @@ unsigned char vtkX3DExporterFIByteWriter::Append(unsigned int value, unsigned ch
   return count;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIByteWriter::PutBytes(const char* bytes, size_t length)
 {
   if (this->CurrentBytePos == 0)
@@ -214,7 +212,7 @@ void vtkX3DExporterFIByteWriter::PutBytes(const char* bytes, size_t length)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIByteWriter::PutBits(unsigned int value, unsigned char count)
 {
   // Can be optimized
@@ -224,7 +222,7 @@ void vtkX3DExporterFIByteWriter::PutBits(unsigned int value, unsigned char count
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIByteWriter::PutBits(const std::string& bitstring)
 {
   std::string::const_iterator I = bitstring.begin();
@@ -235,11 +233,30 @@ void vtkX3DExporterFIByteWriter::PutBits(const std::string& bitstring)
   }
 }
 
+//------------------------------------------------------------------------------
+void vtkX3DExporterFIByteWriter::EncodeLineFeed()
+{
+  static bool firstTime = true;
+  this->FillByte();
+  if (firstTime)
+  {
+    this->PutBits("1001000000001010");
+    firstTime = false;
+  }
+  else
+  {
+    // cout << "Encode NOT the first time" << endl;
+    this->PutBits("10100000");
+  }
+}
+
+VTK_ABI_NAMESPACE_END
 #include "vtkX3DExporterFIWriterHelper.h"
 
 /* ------------------------------------------------------------------------- */
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkX3DExporterFIWriter);
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkX3DExporterFIWriter::~vtkX3DExporterFIWriter()
 {
   this->CloseFile();
@@ -247,7 +264,7 @@ vtkX3DExporterFIWriter::~vtkX3DExporterFIWriter()
   this->Compressor->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkX3DExporterFIWriter::vtkX3DExporterFIWriter()
 {
   this->InfoStack = new vtkX3DExporterFINodeInfoStack();
@@ -258,17 +275,16 @@ vtkX3DExporterFIWriter::vtkX3DExporterFIWriter()
   this->Fastest = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Fastest: " << this->Fastest << endl;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkX3DExporterFIWriter::OpenFile(const char* file)
 {
-  std::string t(file);
   this->CloseFile();
 
   // Delegate to vtkX3DExporterFIByteWriter
@@ -285,7 +301,7 @@ int vtkX3DExporterFIWriter::OpenStream()
   return this->Writer->OpenStream();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::CloseFile()
 {
   if (this->Writer != nullptr)
@@ -303,7 +319,7 @@ void vtkX3DExporterFIWriter::CloseFile()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::StartDocument()
 {
   const char* external_voc = "urn:external-vocabulary";
@@ -312,38 +328,38 @@ void vtkX3DExporterFIWriter::StartDocument()
   // ITU 12.7 / 12.9: Version of standard: 1 as 16bit
   this->Writer->PutBits("0000000000000001");
   // ITU 12.8: The bit '0' (padding) shall then be appended to the bit stream
-  this->Writer->PutBit(0);
+  this->Writer->PutBit(false);
   // ITU C.2.3
-  this->Writer->PutBit(0); // additional-data
-  this->Writer->PutBit(1); // initial-vocabulary
-  this->Writer->PutBit(0); // notations
-  this->Writer->PutBit(0); // unparsed-entities
-  this->Writer->PutBit(0); // character-encoding-scheme
-  this->Writer->PutBit(0); // standalone
-  this->Writer->PutBit(0); // and version
+  this->Writer->PutBit(false); // additional-data
+  this->Writer->PutBit(true);  // initial-vocabulary
+  this->Writer->PutBit(false); // notations
+  this->Writer->PutBit(false); // unparsed-entities
+  this->Writer->PutBit(false); // character-encoding-scheme
+  this->Writer->PutBit(false); // standalone
+  this->Writer->PutBit(false); // and version
   // ITU C.2.5: padding '000' for optional component initial-vocabulary
   this->Writer->PutBits("000");
   // ITU C.2.5.1: For each of the thirteen optional components:
   // presence ? 1 : 0
   this->Writer->PutBits("1000000000000"); // 'external-vocabulary'
   // ITU C.2.5.2: external-vocabulary is present
-  this->Writer->PutBit(0);
+  this->Writer->PutBit(false);
   // Write "urn:external-vocabulary"
   // ITU C.22.3.1: Length is < 65
-  this->Writer->PutBit(0);
+  this->Writer->PutBit(false);
   // Writer->PutBits("010110"); // = strlen(external_voc) - 1
   this->Writer->PutBits(static_cast<unsigned int>(strlen(external_voc) - 1), 6);
   this->Writer->PutBytes(external_voc, strlen(external_voc));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::EndDocument()
 {
   // ITU C.2.12: The four bits '1111' (termination) are appended
   this->Writer->PutBits("1111");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::StartNode(int elementID)
 {
   if (!this->InfoStack->empty())
@@ -351,7 +367,7 @@ void vtkX3DExporterFIWriter::StartNode(int elementID)
     this->CheckNode(false);
     if (this->IsLineFeedEncodingOn)
     {
-      vtkX3DExporterFIWriterHelper::EncodeLineFeed(this->Writer);
+      this->Writer->EncodeLineFeed();
     }
     this->Writer->FillByte();
   }
@@ -359,17 +375,17 @@ void vtkX3DExporterFIWriter::StartNode(int elementID)
   this->InfoStack->push_back(NodeInfo(elementID));
 
   // ITU C.3.7.2: element is present
-  this->Writer->PutBit(0);
+  this->Writer->PutBit(false);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::EndNode()
 {
   assert(!this->InfoStack->empty());
   this->CheckNode(false);
   if (this->IsLineFeedEncodingOn)
   {
-    vtkX3DExporterFIWriterHelper::EncodeLineFeed(this->Writer);
+    this->Writer->EncodeLineFeed();
   }
   if (!this->InfoStack->back().attributesTerminated)
   {
@@ -382,7 +398,7 @@ void vtkX3DExporterFIWriter::EndNode()
   this->InfoStack->pop_back();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::CheckNode(bool callerIsAttribute)
 {
   if (!this->InfoStack->back().isChecked)
@@ -390,13 +406,13 @@ void vtkX3DExporterFIWriter::CheckNode(bool callerIsAttribute)
     if (callerIsAttribute) // Element has attributes
     {
       // ITU C.3.3: then the bit '1' (presence) is appended
-      this->Writer->PutBit(1);
+      this->Writer->PutBit(true);
       this->InfoStack->back().attributesTerminated = false;
     }
     else // Element has no attributes
     {
       // ITU C.3.3: otherwise, the bit '0' (absence) is appended
-      this->Writer->PutBit(0);
+      this->Writer->PutBit(false);
     }
     // Write Node name (starting at third bit)
     // ITU: C.18.4 If the alternative name-surrogate-index is present,
@@ -413,12 +429,12 @@ void vtkX3DExporterFIWriter::CheckNode(bool callerIsAttribute)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::StartAttribute(int attributeID, bool literal, bool addToTable)
 {
   this->CheckNode();
   // ITU C.3.6.1: Start of attribute
-  this->Writer->PutBit(0);
+  this->Writer->PutBit(false);
   // ITU C.4.3 The value of qualified-name is encoded as described in C.17.
   vtkX3DExporterFIWriterHelper::EncodeInteger2(this->Writer, attributeID + 1);
 
@@ -426,7 +442,7 @@ void vtkX3DExporterFIWriter::StartAttribute(int attributeID, bool literal, bool
   // then the bit '0' (discriminant) is appended
   // ITU C.14.4: If the alternative string-index is present,
   // then the bit '1' (discriminant) is appended
-  this->Writer->PutBit(literal ? 0 : 1);
+  this->Writer->PutBit(!literal);
   if (literal)
   {
     // ITU C.14.3.1 If the value of the component add-to-table is TRUE,
@@ -435,10 +451,10 @@ void vtkX3DExporterFIWriter::StartAttribute(int attributeID, bool literal, bool
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::EndAttribute() {}
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, int type, const double* d)
 {
   this->StartAttribute(attributeID, true, false);
@@ -489,7 +505,7 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, int type, const double* d
 #endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, int type, vtkDataArray* a)
 {
   this->StartAttribute(attributeID, true, false);
@@ -549,7 +565,7 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, int type, vtkDataArray* a
 #endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, const double* values, size_t size)
 {
   this->StartAttribute(attributeID, true, false);
@@ -564,7 +580,7 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, const double* values, siz
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, const int* values, size_t size, bool image)
 {
   this->StartAttribute(attributeID, true, false);
@@ -578,7 +594,7 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, const int* values, size_t
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, int type, vtkCellArray* a)
 {
   vtkIdType npts = 0;
@@ -629,7 +645,7 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, int type, vtkCellArray* a
 #endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, int value)
 {
   std::ostringstream ss;
@@ -641,7 +657,7 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, int value)
   vtkX3DExporterFIWriterHelper::EncodeCharacterString3(this->Writer, ss.str());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, float value)
 {
   std::ostringstream ss;
@@ -654,35 +670,35 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, float value)
   vtkX3DExporterFIWriterHelper::EncodeCharacterString3(this->Writer, ss.str());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int vtkNotUsed(attributeID), double vtkNotUsed(value))
 {
   cout << "Function not implemented yet." << endl;
   assert(false);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, bool value)
 {
   this->StartAttribute(attributeID, false);
   vtkX3DExporterFIWriterHelper::EncodeInteger2(this->Writer, value ? 2 : 1);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::SetField(int attributeID, const char* value, bool vtkNotUsed(mfstring))
 {
   this->StartAttribute(attributeID, true, true);
   vtkX3DExporterFIWriterHelper::EncodeCharacterString3(this->Writer, std::string(value));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 /*void vtkX3DExporterFIWriter::SetField(int attributeID, const std::string &value)
   {
   this->StartAttribute(attributeID, true, true);
   vtkX3DExporterFIWriterHelper::EncodeCharacterString3(this->Writer, value);
   }*/
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 /*void vtkX3DExporterFIWriter::SetField(int attributeID, int type, std::string value)
   {
   assert(type == MFSTRING);
@@ -690,5 +706,6 @@ void vtkX3DExporterFIWriter::SetField(int attributeID, const char* value, bool v
   this->SetField(attributeID, value);
   }*/
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkX3DExporterFIWriter::Flush() {}
+VTK_ABI_NAMESPACE_END
