@@ -110,11 +110,12 @@ bool vtkGLTFDocumentLoaderInternals::LoadFileMetaData(nlohmann::json& gltfRoot)
   try
   {
     const auto& stream = this->Self->GetInternalModel()->Stream;
-    stream->Seek(0, vtkResourceStream::SeekDirection::Begin);
+    stream->Seek(this->Self->GetGLBStart(), vtkResourceStream::SeekDirection::Begin);
 
     // Determine the format
     std::string magic;
     magic.resize(4);
+    // NOLINTNEXTLINE(readability-container-data-pointer)
     stream->Read(&magic[0], magic.size());
 
     if (magic == "glTF")
@@ -122,7 +123,8 @@ bool vtkGLTFDocumentLoaderInternals::LoadFileMetaData(nlohmann::json& gltfRoot)
       std::uint32_t version;
       std::uint32_t fileLength;
       std::vector<vtkGLTFUtils::ChunkInfoType> chunkInfo;
-      if (vtkGLTFUtils::ExtractGLBFileInformation(stream, version, fileLength, chunkInfo))
+      if (vtkGLTFUtils::ExtractGLBFileInformation(
+            stream, version, fileLength, this->Self->GetGLBStart(), chunkInfo))
       {
         if (!vtkGLTFUtils::ValidateGLBFile(magic, version, fileLength, chunkInfo))
         {
@@ -134,7 +136,8 @@ bool vtkGLTFDocumentLoaderInternals::LoadFileMetaData(nlohmann::json& gltfRoot)
         vtkGLTFUtils::ChunkInfoType& JSONChunkInfo = chunkInfo[0];
 
         // Jump to chunk data start
-        stream->Seek(vtkGLTFUtils::GLBHeaderSize + vtkGLTFUtils::GLBChunkHeaderSize,
+        stream->Seek(this->Self->GetGLBStart() + vtkGLTFUtils::GLBHeaderSize +
+            vtkGLTFUtils::GLBChunkHeaderSize,
           vtkResourceStream::SeekDirection::Begin);
         // Read chunk data
         std::vector<char> JSONDataBuffer;
@@ -152,8 +155,8 @@ bool vtkGLTFDocumentLoaderInternals::LoadFileMetaData(nlohmann::json& gltfRoot)
     {
       // Text gltf
       stream->Seek(0, vtkResourceStream::SeekDirection::End);
-      const auto fileSize = static_cast<std::size_t>(stream->Tell());
-      stream->Seek(0, vtkResourceStream::SeekDirection::Begin);
+      const auto fileSize = static_cast<std::size_t>(stream->Tell()) - this->Self->GetGLBStart();
+      stream->Seek(this->Self->GetGLBStart(), vtkResourceStream::SeekDirection::Begin);
 
       std::vector<char> fileData;
       fileData.resize(fileSize);
@@ -292,7 +295,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadAccessorBounds(
   const nlohmann::json& root, vtkGLTFDocumentLoader::Accessor& accessor)
 {
   // min
-  const nlohmann::json& minArray = root["min"];
+  const nlohmann::json& minArray = root.value("min", nlohmann::json::array());
   if (!minArray.empty() && minArray.is_array())
   {
     if (minArray.size() != accessor.NumberOfComponents)
@@ -309,7 +312,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadAccessorBounds(
     }
   }
   // max
-  const nlohmann::json& maxArray = root["max"];
+  const nlohmann::json& maxArray = root.value("max", nlohmann::json::array());
   if (!maxArray.empty() && maxArray.is_array())
   {
     if (maxArray.size() != accessor.NumberOfComponents)
@@ -361,10 +364,11 @@ bool vtkGLTFDocumentLoaderInternals::LoadAnimation(
       return false;
     }
     channel.TargetNode = -1;
-    vtkGLTFUtils::GetIntValue(channelRoot["target"], "node", channel.TargetNode);
+    const auto& target = channelRoot.value("target", nlohmann::json::object());
+    vtkGLTFUtils::GetIntValue(target, "node", channel.TargetNode);
 
     std::string targetPathString;
-    if (!vtkGLTFUtils::GetStringValue(channelRoot["target"], "path", targetPathString))
+    if (!vtkGLTFUtils::GetStringValue(target, "path", targetPathString))
     {
       vtkErrorWithObjectMacro(
         this->Self, "Invalid animation.channel.target.path value for animation " << animation.Name);
@@ -397,7 +401,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadAnimation(
 
   float maxDuration = 0;
   // Load sampler metadata
-  for (const auto& samplerRoot : root["samplers"])
+  for (const auto& samplerRoot : root.value("samplers", nlohmann::json::array()))
   {
     vtkGLTFDocumentLoader::Animation::Sampler sampler;
     if (!vtkGLTFUtils::GetUIntValue(samplerRoot, "input", sampler.Input))
@@ -526,12 +530,12 @@ bool vtkGLTFDocumentLoaderInternals::LoadCamera(
 
   if (type == "orthographic")
   {
-    camRoot = root["orthographic"];
+    camRoot = root.value("orthographic", nlohmann::json::object());
     camera.IsPerspective = false;
   }
   else if (type == "perspective")
   {
-    camRoot = root["perspective"];
+    camRoot = root.value("perspective", nlohmann::json::object());
     camera.IsPerspective = true;
   }
   else
@@ -582,7 +586,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadCamera(
     {
       if (camera.AspectRatio <= 0)
       {
-        vtkErrorWithObjectMacro(this->Self, "Invalid camera.perpective.aspectRatio value");
+        vtkErrorWithObjectMacro(this->Self, "Invalid camera.perspective.aspectRatio value");
         return false;
       }
     }
@@ -616,13 +620,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadImage(
   {
     image.MimeType.clear();
   }
-  else if (image.MimeType != "image/jpeg" && image.MimeType != "image/png")
-  {
-    vtkErrorWithObjectMacro(this->Self,
-      "Invalid image.mimeType value. Must be either image/jpeg or image/png for image "
-        << image.Name);
-    return false;
-  }
+
   // Read the bufferView index value, if it exists.
   image.BufferView = -1;
   if (vtkGLTFUtils::GetIntValue(root, "bufferView", image.BufferView))
@@ -654,7 +652,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadMaterial(
   double metallicFactor = 1;
   double roughnessFactor = 1;
 
-  const auto& pbrRoot = root["pbrMetallicRoughness"];
+  const auto& pbrRoot = root.value("pbrMetallicRoughness", nlohmann::json::object());
   if (!pbrRoot.empty())
   {
     if (vtkGLTFUtils::GetDoubleValue(pbrRoot, "metallicFactor", metallicFactor))
@@ -780,7 +778,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadMesh(
   }
 
   // Load primitives
-  for (const auto& glTFPrimitive : root["primitives"])
+  for (const auto& glTFPrimitive : root.value("primitives", nlohmann::json::array()))
   {
     vtkGLTFDocumentLoader::Primitive primitive;
     if (this->LoadPrimitive(glTFPrimitive, primitive))
@@ -1065,7 +1063,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadPrimitive(
 
   primitive.IndicesId = -1;
   vtkGLTFUtils::GetIntValue(root, "indices", primitive.IndicesId);
-  const auto& glTFAttributes = root["attributes"];
+  const auto& glTFAttributes = root.value("attributes", nlohmann::json::object());
   if (!glTFAttributes.empty() && glTFAttributes.is_object())
   {
     for (const auto& glTFAttribute : glTFAttributes.items())
@@ -1097,6 +1095,34 @@ bool vtkGLTFDocumentLoaderInternals::LoadPrimitive(
     }
   }
 
+  // extensions
+  auto rootExtIt = root.find("extensions");
+
+  if (rootExtIt != root.end() && rootExtIt.value().is_object())
+  {
+    for (const auto& extension : rootExtIt.value().items())
+    {
+      if (extension.key() == "KHR_draco_mesh_compression")
+      {
+        auto& meshComp = primitive.ExtensionMetaData.KHRDracoMetaData;
+        vtkGLTFUtils::GetIntValue(extension.value(), "bufferView", meshComp.BufferView);
+
+        const auto& dracoAttributes = extension.value()["attributes"];
+        if (!dracoAttributes.empty() && dracoAttributes.is_object())
+        {
+          for (const auto& dracoAttr : dracoAttributes.items())
+          {
+            int indice;
+            if (vtkGLTFUtils::GetIntValue(dracoAttributes, dracoAttr.key(), indice))
+            {
+              meshComp.AttributeIndices[dracoAttr.key()] = indice;
+            }
+          }
+        }
+      }
+    }
+  }
+
   return true;
 }
 
@@ -1161,8 +1187,8 @@ bool vtkGLTFDocumentLoaderInternals::LoadSparse(
     vtkErrorWithObjectMacro(this->Self, "Invalid accessor.sparse.count value");
     return false;
   }
-  const nlohmann::json& indices = root["indices"];
-  const nlohmann::json& values = root["values"];
+  const nlohmann::json& indices = root.value("indices", nlohmann::json::object());
+  const nlohmann::json& values = root.value("values", nlohmann::json::object());
   if (indices.empty() || values.empty() || !indices.is_object() || !values.is_object())
   {
     vtkErrorWithObjectMacro(
@@ -1287,7 +1313,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadModelMetaData(
   }
 
   // Check for extensions
-  const auto& supportedExtensions = this->Self->GetSupportedExtensions();
+  auto supportedExtensions = this->Self->GetSupportedExtensions();
   for (const auto& extensionRequiredByModel : root["extensionsRequired"])
   {
     if (!extensionRequiredByModel.is_string())
@@ -1299,8 +1325,8 @@ bool vtkGLTFDocumentLoaderInternals::LoadModelMetaData(
     // This is only for warnings. extensionsRequired is a subset of extensionsUsed, which is what is
     // used to fill extensionsUsedByLoader.
     if (!std::any_of(supportedExtensions.begin(), supportedExtensions.end(),
-          [&extensionRequiredByModel](
-            const std::string& value) { return value == extensionRequiredByModel; }))
+          [&extensionRequiredByModel](const std::string& value)
+          { return value == extensionRequiredByModel; }))
     {
       vtkErrorWithObjectMacro(this->Self,
         "glTF extension "
@@ -1318,8 +1344,8 @@ bool vtkGLTFDocumentLoaderInternals::LoadModelMetaData(
       continue;
     }
     if (std::any_of(supportedExtensions.begin(), supportedExtensions.end(),
-          [&extensionUsedByModel](
-            const std::string& value) { return value == extensionUsedByModel; }))
+          [&extensionUsedByModel](const std::string& value)
+          { return value == extensionUsedByModel; }))
     {
       extensionsUsedByLoader.push_back(extensionUsedByModel);
     }
@@ -1447,6 +1473,12 @@ bool vtkGLTFDocumentLoaderInternals::LoadModelMetaData(
   if (!vtkGLTFUtils::GetIntValue(root, "scene", this->Self->GetInternalModel()->DefaultScene))
   {
     int nbScenes = static_cast<int>(this->Self->GetInternalModel()->Scenes.size());
+    if (nbScenes < 1)
+    {
+      // In case the file had no scenes, add an empty scene so that downstream code doesn't need to
+      // check that its default scene index is valid
+      this->Self->GetInternalModel()->Scenes.resize(1);
+    }
     if (this->Self->GetInternalModel()->DefaultScene < 0 ||
       this->Self->GetInternalModel()->DefaultScene >= nbScenes)
     {
@@ -1516,8 +1548,9 @@ bool vtkGLTFDocumentLoaderInternals::LoadKHRLightsPunctualNodeExtension(const nl
 bool vtkGLTFDocumentLoaderInternals::LoadKHRLightsPunctualExtension(
   const nlohmann::json& root, vtkGLTFDocumentLoader::Extensions::KHRLightsPunctual& lightsExtension)
 {
-  lightsExtension.Lights.reserve(root["lights"].size());
-  for (const auto& glTFLight : root["lights"])
+  const auto& lights = root.value("lights", nlohmann::json::array());
+  lightsExtension.Lights.reserve(lights.size());
+  for (const auto& glTFLight : lights)
   {
     vtkGLTFDocumentLoader::Extensions::KHRLightsPunctual::Light light;
     if (this->LoadKHRLightsPunctualExtensionLight(glTFLight, light))
@@ -1569,7 +1602,7 @@ bool vtkGLTFDocumentLoaderInternals::LoadKHRLightsPunctualExtensionLight(
   {
     light.Type = vtkGLTFDocumentLoader::Extensions::KHRLightsPunctual::Light::LightType::SPOT;
     // Load innerConeAngle and outerConeAngle
-    auto const& glTFSpot = root["spot"];
+    auto const& glTFSpot = root.value("spot", nlohmann::json());
     if (glTFSpot.is_null() || !glTFSpot.is_object())
     {
       vtkErrorWithObjectMacro(
