@@ -17,7 +17,7 @@ renWin.AddRenderer(ren1)
 importer = vtkVRMLImporter()
 importer.SetRenderWindow(renWin)
 importer.SetFileName(VTK_DATA_ROOT + "/Data/bot2.wrl")
-importer.Read()
+importer.Update()
 iren = vtkRenderWindowInteractor()
 iren.SetRenderWindow(renWin)
 importer.GetRenderer().SetBackground(0.1,0.2,0.4)
