@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkVRMLImporter.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkVRMLImporter
  * @brief   imports VRML 2.0 files.
@@ -19,6 +7,10 @@
  *
  * vtkVRMLImporter imports VRML 2.0 files into VTK.
  *
+ * This importer doesn't support scene hierarchy API
+ *
+ * This importer supports the collection API
+ *
  * @warning
  * These nodes are currently supported:
  *      Appearance                              IndexedFaceSet
@@ -57,6 +49,7 @@
 #include "vtkIOImportModule.h" // For export macro
 #include "vtkImporter.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkActor;
 class vtkAlgorithm;
 class vtkProperty;
@@ -79,22 +72,22 @@ public:
   vtkTypeMacro(vtkVRMLImporter, vtkImporter);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify the name of the file to read.
    */
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-  //@}
+  vtkSetFilePathMacro(FileName);
+  vtkGetFilePathMacro(FileName);
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the resolution for Sphere, Cone and Cylinder shape sources.
    * Default is 12.
    */
   vtkSetMacro(ShapeResolution, int);
   vtkGetMacro(ShapeResolution, int);
-  //@}
+  ///@}
 
   /**
    * In the VRML spec you can DEF and USE nodes (name them),
@@ -123,7 +116,7 @@ protected:
   void ImportLights(vtkRenderer*) override {}
   void ImportProperties(vtkRenderer*) override {}
 
-  //@{
+  ///@{
   /**
    * Needed by the yacc/lex grammar used
    */
@@ -132,7 +125,7 @@ protected:
   virtual void enterField(const char*);
   virtual void exitField();
   virtual void useNode(const char*);
-  //@}
+  ///@}
 
   /**
    * Return the file pointer to the open file.
@@ -168,9 +161,9 @@ private:
   vtkFloatArray* CurrentScalars;
   vtkPolyDataMapper* CurrentMapper;
 
-private:
   vtkVRMLImporter(const vtkVRMLImporter&) = delete;
   void operator=(const vtkVRMLImporter&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
