@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkGraphReader.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkGraphReader.h"
 
 #include "vtkByteSwap.h"
@@ -27,31 +16,32 @@
 #include "vtkSmartPointer.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGraphReader);
 
 #ifdef read
 #undef read
 #endif
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGraphReader::vtkGraphReader() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGraphReader::~vtkGraphReader() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGraph* vtkGraphReader::GetOutput()
 {
   return this->GetOutput(0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGraph* vtkGraphReader::GetOutput(int idx)
 {
   return vtkGraph::SafeDownCast(this->GetOutputDataObject(idx));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGraphReader::ReadMeshSimple(const std::string& fname, vtkDataObject* doOutput)
 {
   vtkDebugMacro(<< "Reading vtk graph ...");
@@ -93,7 +83,7 @@ int vtkGraphReader::ReadMeshSimple(const std::string& fname, vtkDataObject* doOu
   vtkVector3d lattice_a;
   vtkVector3d lattice_b;
   vtkVector3d lattice_c;
-  vtkVector3d lattice_origin;
+  vtkVector3d lattice_origin(0, 0, 0);
 
   while (true)
   {
@@ -324,7 +314,7 @@ int vtkGraphReader::ReadMeshSimple(const std::string& fname, vtkDataObject* doOu
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGraphReader::ReadGraphType(const char* fname, GraphType& type)
 {
   type = UnknownGraph;
@@ -343,7 +333,7 @@ int vtkGraphReader::ReadGraphType(const char* fname, GraphType& type)
     return 0;
   }
 
-  if (strncmp(this->LowerCase(line), "dataset", (unsigned long)7))
+  if (strncmp(this->LowerCase(line), "dataset", 7) != 0)
   {
     vtkErrorMacro(<< "Unrecognized keyword: " << line);
     this->CloseVTKFile();
@@ -378,14 +368,14 @@ int vtkGraphReader::ReadGraphType(const char* fname, GraphType& type)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGraphReader::FillOutputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkGraph");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataObject* vtkGraphReader::CreateOutput(vtkDataObject* currentOutput)
 {
   GraphType graphType;
@@ -426,8 +416,9 @@ vtkDataObject* vtkGraphReader::CreateOutput(vtkDataObject* currentOutput)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGraphReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
