@@ -1,17 +1,6 @@
-/*=========================================================================
-
-  Program:   ParaView
-  Module:    vtkXMLCompositeDataReader.h
-
-  Copyright (c) Kitware, Inc.
-  All rights reserved.
-  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Kitware, Inc.
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkXMLCompositeDataReader
  * @brief   Reader for multi-group datasets
@@ -32,12 +21,17 @@
 #include "vtkIOXMLModule.h" // For export macro
 #include "vtkXMLReader.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCompositeDataSet;
 class vtkInformationIntegerKey;
 class vtkInformationIntegerVectorKey;
-
 struct vtkXMLCompositeDataReaderInternals;
 
+VTK_ABI_NAMESPACE_END
+#include <set>    // for std::set
+#include <string> // for std::string
+
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIOXML_EXPORT vtkXMLCompositeDataReader : public vtkXMLReader
 {
 public:
@@ -66,13 +60,15 @@ public:
   vtkGetMacro(PieceDistribution, int);
   /**@}*/
 
-  //@{
+  ///@{
   /**
    * Get the output data object for a port on this algorithm.
    */
   vtkCompositeDataSet* GetOutput();
   vtkCompositeDataSet* GetOutput(int);
-  //@}
+  ///@}
+
+  void SetFileName(VTK_FILEPATH const char*) override;
 
 protected:
   vtkXMLCompositeDataReader();
@@ -124,25 +120,48 @@ protected:
   // Read the vtkDataObject (a leaf) in the composite dataset.
   virtual vtkDataObject* ReadDataObject(vtkXMLDataElement* xmlElem, const char* filePath);
 
-  // Counts "DataSet" elements in the subtree.
-  unsigned int CountLeaves(vtkXMLDataElement* elem);
-
   /**
    * Given the inorder index for a leaf node, this method tells if the current
    * process should read the dataset.
+   *
+   * For a dataset that is part of a vtkParititionedDataSet or a
+   * vtkMultiPieceDataset, valid `pieceIndex` and `numPieces` should be specified such that
+   * `pieceIndex < numPieces`. When provided, this method can use the
+   * `PieceDistribution` selection to distribute each vtkMultiPieceDataset and
+   * vtkParititionedDataSet across ranks.
+   *
    */
-  int ShouldReadDataSet(unsigned int datasetIndex);
-
-  bool DataSetIsValidForBlockStrategy(unsigned int datasetIndex);
-  bool DataSetIsValidForInterleaveStrategy(unsigned int datasetIndex);
+  int ShouldReadDataSet(
+    unsigned int datasetIndex, unsigned int pieceIndex = 0, unsigned int numPieces = 0);
 
+#ifndef __VTK_WRAP__
+  /**
+   * Convenience method to count all nested elements with the given tag name.
+   * In addition, one can specify a list of tags to skip traversing into.
+   */
+  static unsigned int CountNestedElements(vtkXMLDataElement* element, const std::string& tagName,
+    const std::set<std::string>& exclusions = std::set<std::string>());
+#endif
 private:
   vtkXMLCompositeDataReader(const vtkXMLCompositeDataReader&) = delete;
   void operator=(const vtkXMLCompositeDataReader&) = delete;
 
+  ///@{
+  /**
+   * Given the number of datasets (@a numDatasets) and number of pieces (@a numPieces),
+   * return the piece number of a dataset at the chosen index (@a datasetIndex)
+   * based on the assignment strategy.
+   */
+  static int GetPieceAssignmentForBlockStrategy(
+    unsigned int datasetIndex, unsigned int numDatasets, int numPieces);
+  static int GetPieceAssignmentForInterleaveStrategy(
+    unsigned int datasetIndex, unsigned int numDatasets, int numPieces);
+  ///@}
+
   int PieceDistribution;
 
   vtkXMLCompositeDataReaderInternals* Internal;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
