@@ -1,27 +1,18 @@
-/*=========================================================================
-
-  Program:   ParaView
-  Module:    vtkXMLCompositeDataWriter.cxx
-
-  Copyright (c) Kitware, Inc.
-  All rights reserved.
-  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Kitware, Inc.
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkXMLCompositeDataWriter.h"
 
 #include "vtkCallbackCommand.h"
 #include "vtkCompositeDataPipeline.h"
 #include "vtkCompositeDataSet.h"
 #include "vtkDataObjectTreeIterator.h"
+#include "vtkDoubleArray.h"
 #include "vtkErrorCode.h"
 #include "vtkExecutive.h"
+#include "vtkFieldData.h"
 #include "vtkGarbageCollector.h"
-#include "vtkHierarchicalBoxDataSet.h"
+#include "vtkHyperTreeGrid.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
@@ -29,47 +20,48 @@
 #include "vtkPolyData.h"
 #include "vtkRectilinearGrid.h"
 #include "vtkSmartPointer.h"
-#include "vtkSmartPointer.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkStructuredGrid.h"
+#include "vtkTable.h"
 #include "vtkUnstructuredGrid.h"
 #include "vtkXMLDataElement.h"
-#include "vtkXMLDataSetWriter.h"
+#include "vtkXMLDataObjectWriter.h"
 
-#include <vtksys/SystemTools.hxx>
 #include <map>
 #include <sstream>
 #include <string>
 #include <vector>
+#include <vtksys/SystemTools.hxx>
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkXMLCompositeDataWriterInternals
 {
   // These are used to by GetDefaultFileExtension(). This helps us avoid
   // creating new instances repeatedly for the same dataset type.
-  std::map<int, vtkSmartPointer<vtkXMLWriter> > TmpWriters;
+  std::map<int, vtkSmartPointer<vtkXMLWriter>> TmpWriters;
 
 public:
-  std::vector< vtkSmartPointer<vtkXMLWriter> > Writers;
+  std::vector<vtkSmartPointer<vtkXMLWriter>> Writers;
   std::string FilePath;
   std::string FilePrefix;
   vtkSmartPointer<vtkXMLDataElement> Root;
   std::vector<int> DataTypes;
 
-  // Get the default extension for the dataset_type. Will return NULL if an
+  // Get the default extension for the dataset_type. Will return nullptr if an
   // extension cannot be determined.
   const char* GetDefaultFileExtensionForDataSet(int dataset_type)
   {
-    std::map<int, vtkSmartPointer<vtkXMLWriter> >::iterator iter
-      = this->TmpWriters.find(dataset_type);
+    std::map<int, vtkSmartPointer<vtkXMLWriter>>::iterator iter =
+      this->TmpWriters.find(dataset_type);
     if (iter == this->TmpWriters.end())
     {
       vtkSmartPointer<vtkXMLWriter> writer;
-      writer.TakeReference(vtkXMLDataSetWriter::NewWriter(dataset_type));
+      writer.TakeReference(vtkXMLDataObjectWriter::NewWriter(dataset_type));
       if (writer)
       {
-        std::pair<int, vtkSmartPointer<vtkXMLWriter> > pair(dataset_type, writer);
+        std::pair<int, vtkSmartPointer<vtkXMLWriter>> pair(dataset_type, writer);
         iter = this->TmpWriters.insert(pair).first;
       }
     }
@@ -77,11 +69,11 @@ public:
     {
       return iter->second->GetDefaultFileExtension();
     }
-    return NULL;
+    return nullptr;
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLCompositeDataWriter::vtkXMLCompositeDataWriter()
 {
   this->Internal = new vtkXMLCompositeDataWriterInternals;
@@ -89,51 +81,49 @@ vtkXMLCompositeDataWriter::vtkXMLCompositeDataWriter()
   this->WriteMetaFile = 1;
 
   // Setup a callback for the internal writers to report progress.
-  this->ProgressObserver = vtkCallbackCommand::New();
-  this->ProgressObserver->SetCallback(&vtkXMLCompositeDataWriter::ProgressCallbackFunction);
-  this->ProgressObserver->SetClientData(this);
+  this->InternalProgressObserver = vtkCallbackCommand::New();
+  this->InternalProgressObserver->SetCallback(&vtkXMLCompositeDataWriter::ProgressCallbackFunction);
+  this->InternalProgressObserver->SetClientData(this);
 
-  this->InputInformation = 0;
+  this->InputInformation = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLCompositeDataWriter::~vtkXMLCompositeDataWriter()
 {
-  this->ProgressObserver->Delete();
+  this->InternalProgressObserver->Delete();
   delete this->Internal;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLCompositeDataWriter::GetDefaultFileExtensionForDataSet(int dataset_type)
 {
   return this->Internal->GetDefaultFileExtensionForDataSet(dataset_type);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkXMLCompositeDataWriter::GetNumberOfDataTypes()
 {
   return static_cast<unsigned int>(this->Internal->DataTypes.size());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int* vtkXMLCompositeDataWriter::GetDataTypesPointer()
 {
-  return &this->Internal->DataTypes[0];
+  return this->Internal->DataTypes.data();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "GhostLevel: " << this->GhostLevel << endl;
-  os << indent << "WriteMetaFile: " << this->WriteMetaFile<< endl;
+  os << indent << "WriteMetaFile: " << this->WriteMetaFile << endl;
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLCompositeDataWriter::ProcessRequest(
-  vtkInformation* request,
-  vtkInformationVector** inputVector,
-  vtkInformationVector* outputVector)
+//------------------------------------------------------------------------------
+vtkTypeBool vtkXMLCompositeDataWriter::ProcessRequest(
+  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
   if (request->Has(vtkStreamingDemandDrivenPipeline::REQUEST_UPDATE_EXTENT()))
   {
@@ -147,7 +137,7 @@ int vtkXMLCompositeDataWriter::ProcessRequest(
   return this->Superclass::ProcessRequest(request, inputVector, outputVector);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::SetWriteMetaFile(int flag)
 {
   if (this->WriteMetaFile != flag)
@@ -157,34 +147,29 @@ void vtkXMLCompositeDataWriter::SetWriteMetaFile(int flag)
   }
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLCompositeDataWriter::RequestUpdateExtent(
-  vtkInformation* vtkNotUsed(request),
-  vtkInformationVector** inputVector,
-  vtkInformationVector* vtkNotUsed(outputVector))
+//------------------------------------------------------------------------------
+int vtkXMLCompositeDataWriter::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** inputVector, vtkInformationVector* vtkNotUsed(outputVector))
 {
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
-  inInfo->Set(
-    vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(),
-    this->GhostLevel);
+  inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), this->GhostLevel);
   return 1;
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLCompositeDataWriter::RequestData(vtkInformation*,
-                                           vtkInformationVector** inputVector,
-                                           vtkInformationVector*)
+//------------------------------------------------------------------------------
+int vtkXMLCompositeDataWriter::RequestData(
+  vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector*)
 {
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
 
   this->InputInformation = inInfo;
 
-  vtkCompositeDataSet *compositeData = vtkCompositeDataSet::SafeDownCast(
-    inInfo->Get(vtkDataObject::DATA_OBJECT()));
+  vtkCompositeDataSet* compositeData =
+    vtkCompositeDataSet::SafeDownCast(inInfo->Get(vtkDataObject::DATA_OBJECT()));
   if (!compositeData)
   {
     vtkErrorMacro("No hierarchical input has been provided. Cannot write");
-    this->InputInformation = 0;
+    this->InputInformation = nullptr;
     return 0;
   }
 
@@ -198,7 +183,7 @@ int vtkXMLCompositeDataWriter::RequestData(vtkInformation*,
   {
     vtkErrorMacro("Writer called with no FileName set.");
     this->SetErrorCode(vtkErrorCode::NoFileNameError);
-    this->InputInformation = 0;
+    this->InputInformation = nullptr;
     return 0;
   }
 
@@ -214,7 +199,7 @@ int vtkXMLCompositeDataWriter::RequestData(vtkInformation*,
   // Prepare file prefix for creation of internal file names.
   this->SplitFileName();
 
-  float progressRange[2] = { 0.f, 0.f};
+  float progressRange[2] = { 0.f, 0.f };
   this->GetProgressRange(progressRange);
 
   // Create the subdirectory for the internal files.
@@ -235,24 +220,22 @@ int vtkXMLCompositeDataWriter::RequestData(vtkInformation*,
   if (this->WriteMetaFile)
   {
     this->SetProgressRange(progressRange, this->GetNumberOfInputConnections(0),
-                           this->GetNumberOfInputConnections(0)
-                           + this->WriteMetaFile);
+      this->GetNumberOfInputConnections(0) + this->WriteMetaFile);
     int retVal = this->WriteMetaFileIfRequested();
-    this->InputInformation = 0;
+    this->InputInformation = nullptr;
     return retVal;
   }
 
   // We have finished writing.
   this->UpdateProgressDiscrete(1);
 
-  this->InputInformation = 0;
+  this->InputInformation = nullptr;
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLCompositeDataWriter::WriteNonCompositeData(
-  vtkDataObject* dObj, vtkXMLDataElement* datasetXML, int &writerIdx,
-  const char* fileName)
+  vtkDataObject* dObj, vtkXMLDataElement* datasetXML, int& writerIdx, const char* fileName)
 {
   // Write a leaf dataset.
   int myWriterIndex = writerIdx;
@@ -262,17 +245,18 @@ int vtkXMLCompositeDataWriter::WriteNonCompositeData(
   vtkXMLWriter* writer = this->GetWriter(myWriterIndex);
   if (!writer)
   {
-    return 0;
+    return 1;
   }
 
   vtkDataSet* curDS = vtkDataSet::SafeDownCast(dObj);
-  if (!curDS)
+  vtkTable* curTable = vtkTable::SafeDownCast(dObj);
+  vtkHyperTreeGrid* curHTG = vtkHyperTreeGrid::SafeDownCast(dObj);
+  if (!curDS && !curTable && !curHTG)
   {
     if (dObj)
     {
       vtkWarningMacro("This writer cannot handle sub-datasets of type: "
-        << dObj->GetClassName()
-        << " Dataset will be skipped.");
+        << dObj->GetClassName() << " Dataset will be skipped.");
     }
     return 0;
   }
@@ -296,9 +280,9 @@ int vtkXMLCompositeDataWriter::WriteNonCompositeData(
   writer->SetFileName(full.c_str());
 
   // Write the data.
-  writer->AddObserver(vtkCommand::ProgressEvent, this->ProgressObserver);
+  writer->AddObserver(vtkCommand::ProgressEvent, this->InternalProgressObserver);
   writer->Write();
-  writer->RemoveObserver(this->ProgressObserver);
+  writer->RemoveObserver(this->InternalProgressObserver);
 
   if (writer->GetErrorCode() == vtkErrorCode::OutOfDiskSpaceError)
   {
@@ -309,7 +293,7 @@ int vtkXMLCompositeDataWriter::WriteNonCompositeData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLCompositeDataWriter::WriteData()
 {
   // Write the collection file.
@@ -324,10 +308,39 @@ int vtkXMLCompositeDataWriter::WriteData()
     this->Internal->Root->PrintXML(os, indent);
   }
 
+  // We want to avoid using appended data mode as it
+  // is not supported in meta formats.
+  int dataMode = this->DataMode;
+  if (dataMode == vtkXMLWriter::Appended)
+  {
+    this->DataMode = vtkXMLWriter::Binary;
+  }
+
+  vtkDataObject* input = this->GetInput();
+  vtkFieldData* fieldData = input->GetFieldData();
+
+  vtkInformation* meta = input->GetInformation();
+  bool hasTime = meta->Has(vtkDataObject::DATA_TIME_STEP()) != 0;
+  if ((fieldData && fieldData->GetNumberOfArrays()) || (hasTime && this->GetWriteTimeValue()))
+  {
+    vtkNew<vtkFieldData> fieldDataCopy;
+    fieldDataCopy->ShallowCopy(fieldData);
+    if (hasTime && this->GetWriteTimeValue())
+    {
+      vtkNew<vtkDoubleArray> time;
+      time->SetNumberOfTuples(1);
+      time->SetTypedComponent(0, 0, meta->Get(vtkDataObject::DATA_TIME_STEP()));
+      time->SetName("TimeValue");
+      fieldDataCopy->AddArray(time);
+    }
+    this->WriteFieldDataInline(fieldDataCopy, indent);
+  }
+  this->DataMode = dataMode;
+
   return this->EndFile();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLCompositeDataWriter::WriteMetaFileIfRequested()
 {
   if (this->WriteMetaFile)
@@ -340,51 +353,49 @@ int vtkXMLCompositeDataWriter::WriteMetaFileIfRequested()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::MakeDirectory(const char* name)
 {
   if (!vtksys::SystemTools::MakeDirectory(name))
   {
-    vtkErrorMacro(<< "Sorry unable to create directory: " << name
-                   << endl << "Last systen error was: "
-                   << vtksys::SystemTools::GetLastSystemError().c_str());
+    vtkErrorMacro(<< "Sorry unable to create directory: " << name << endl
+                  << "Last system error was: " << vtksys::SystemTools::GetLastSystemError());
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::RemoveADirectory(const char* name)
 {
   if (!vtksys::SystemTools::RemoveADirectory(name))
   {
-    vtkErrorMacro(<< "Sorry unable to remove a directory: " << name
-                   << endl << "Last system error was: "
-                   << vtksys::SystemTools::GetLastSystemError().c_str());
+    vtkErrorMacro(<< "Sorry unable to remove a directory: " << name << endl
+                  << "Last system error was: " << vtksys::SystemTools::GetLastSystemError());
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLCompositeDataWriter::GetDefaultFileExtension()
 {
   return "vtm";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLCompositeDataWriter::GetDataSetName()
 {
   if (!this->InputInformation)
   {
     return "CompositeDataSet";
   }
-  vtkDataObject *hdInput = vtkDataObject::SafeDownCast(
-    this->InputInformation->Get(vtkDataObject::DATA_OBJECT()));
+  vtkDataObject* hdInput =
+    vtkDataObject::SafeDownCast(this->InputInformation->Get(vtkDataObject::DATA_OBJECT()));
   if (!hdInput)
   {
-    return 0;
+    return nullptr;
   }
   return hdInput->GetClassName();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::FillDataTypes(vtkCompositeDataSet* hdInput)
 {
   vtkSmartPointer<vtkCompositeDataIterator> iter;
@@ -400,13 +411,18 @@ void vtkXMLCompositeDataWriter::FillDataTypes(vtkCompositeDataSet* hdInput)
   this->Internal->DataTypes.clear();
   for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
   {
-    vtkDataSet* ds = vtkDataSet::SafeDownCast(iter->GetCurrentDataObject());
+    vtkDataObject* dataObject = iter->GetCurrentDataObject();
+    vtkDataSet* ds = vtkDataSet::SafeDownCast(dataObject);
     // BUG #0015942: Datasets with no cells or points are considered empty and
     // we'll skip then in our serialization code.
     if (ds && (ds->GetNumberOfPoints() > 0 || ds->GetNumberOfCells() > 0))
     {
       this->Internal->DataTypes.push_back(ds->GetDataObjectType());
     }
+    else if (!ds && dataObject)
+    {
+      this->Internal->DataTypes.push_back(dataObject->GetDataObjectType());
+    }
     else
     {
       this->Internal->DataTypes.push_back(-1);
@@ -414,7 +430,7 @@ void vtkXMLCompositeDataWriter::FillDataTypes(vtkCompositeDataSet* hdInput)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::CreateWriters(vtkCompositeDataSet* hdInput)
 {
   this->Internal->Writers.clear();
@@ -438,16 +454,18 @@ void vtkXMLCompositeDataWriter::CreateWriters(vtkCompositeDataSet* hdInput)
   {
     vtkSmartPointer<vtkXMLWriter>& writer = this->Internal->Writers[i];
     vtkDataSet* ds = vtkDataSet::SafeDownCast(iter->GetCurrentDataObject());
-    if (ds == NULL)
+    vtkTable* table = vtkTable::SafeDownCast(iter->GetCurrentDataObject());
+    vtkHyperTreeGrid* htg = vtkHyperTreeGrid::SafeDownCast(iter->GetCurrentDataObject());
+    if (ds == nullptr && table == nullptr && htg == nullptr)
     {
-      writer = NULL;
+      writer = nullptr;
       continue;
     }
 
     // Create a writer based on the type of this input. We just instantiate
-    // vtkXMLDataSetWriter. That internally creates the write type of writer
+    // vtkXMLDataObjectWriter. That internally creates the write type of writer
     // based on the data type.
-    writer.TakeReference(vtkXMLDataSetWriter::NewWriter(this->Internal->DataTypes[i]));
+    writer.TakeReference(vtkXMLDataObjectWriter::NewWriter(this->Internal->DataTypes[i]));
     if (writer)
     {
       // Copy settings to the writer.
@@ -459,25 +477,26 @@ void vtkXMLCompositeDataWriter::CreateWriters(vtkCompositeDataSet* hdInput)
       writer->SetEncodeAppendedData(this->GetEncodeAppendedData());
       writer->SetHeaderType(this->GetHeaderType());
       writer->SetIdType(this->GetIdType());
+      writer->SetWriteTimeValue(this->GetWriteTimeValue());
 
       // Pass input.
-      writer->SetInputDataObject(ds);
+      writer->SetInputDataObject(iter->GetCurrentDataObject());
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLWriter* vtkXMLCompositeDataWriter::GetWriter(int index)
 {
   int size = static_cast<int>(this->Internal->Writers.size());
   if (index >= 0 && index < size)
   {
-    return this->Internal->Writers[index].GetPointer();
+    return this->Internal->Writers[index];
   }
-  return 0;
+  return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::SplitFileName()
 {
   std::string fileName = this->FileName;
@@ -485,11 +504,11 @@ void vtkXMLCompositeDataWriter::SplitFileName()
 
   // Split the file name and extension from the path.
   std::string::size_type pos = fileName.find_last_of("/\\");
-  if (pos != fileName.npos)
+  if (pos != std::string::npos)
   {
     // Keep the slash in the file path.
-    this->Internal->FilePath = fileName.substr(0, pos+1);
-    name = fileName.substr(pos+1);
+    this->Internal->FilePath = fileName.substr(0, pos + 1);
+    name = fileName.substr(pos + 1);
   }
   else
   {
@@ -498,8 +517,8 @@ void vtkXMLCompositeDataWriter::SplitFileName()
   }
 
   // Split the extension from the file name.
-  pos = name.find_last_of(".");
-  if (pos != name.npos)
+  pos = name.find_last_of('.');
+  if (pos != std::string::npos)
   {
     this->Internal->FilePrefix = name.substr(0, pos);
   }
@@ -513,23 +532,21 @@ void vtkXMLCompositeDataWriter::SplitFileName()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLCompositeDataWriter::GetFilePrefix()
 {
   return this->Internal->FilePrefix.c_str();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkXMLCompositeDataWriter::GetFilePath()
 {
   return this->Internal->FilePath.c_str();
 }
 
-//----------------------------------------------------------------------------
-void vtkXMLCompositeDataWriter::ProgressCallbackFunction(vtkObject* caller,
-                                                        unsigned long,
-                                                        void* clientdata,
-                                                        void*)
+//------------------------------------------------------------------------------
+void vtkXMLCompositeDataWriter::ProgressCallbackFunction(
+  vtkObject* caller, unsigned long, void* clientdata, void*)
 {
   vtkAlgorithm* w = vtkAlgorithm::SafeDownCast(caller);
   if (w)
@@ -538,12 +555,12 @@ void vtkXMLCompositeDataWriter::ProgressCallbackFunction(vtkObject* caller,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::ProgressCallback(vtkAlgorithm* w)
 {
   float width = this->ProgressRange[1] - this->ProgressRange[0];
   float internalProgress = w->GetProgress();
-  float progress = this->ProgressRange[0] + internalProgress*width;
+  float progress = this->ProgressRange[0] + internalProgress * width;
   this->UpdateProgressDiscrete(progress);
   if (this->AbortExecute)
   {
@@ -551,9 +568,8 @@ void vtkXMLCompositeDataWriter::ProgressCallback(vtkAlgorithm* w)
   }
 }
 
-//----------------------------------------------------------------------------
-vtkStdString vtkXMLCompositeDataWriter::CreatePieceFileName(
-  int piece)
+//------------------------------------------------------------------------------
+vtkStdString vtkXMLCompositeDataWriter::CreatePieceFileName(int piece)
 {
   if (this->Internal->DataTypes[piece] < 0)
   {
@@ -561,33 +577,30 @@ vtkStdString vtkXMLCompositeDataWriter::CreatePieceFileName(
   }
 
   std::ostringstream stream;
-  stream << this->Internal->FilePrefix.c_str() << "/"
-         << this->Internal->FilePrefix.c_str()
-         << "_" << piece << ".";
-  const char* ext = this->GetDefaultFileExtensionForDataSet(
-    this->Internal->DataTypes[piece]);
-  stream << (ext? ext : "");
+  stream << this->Internal->FilePrefix << "/" << this->Internal->FilePrefix << "_" << piece << ".";
+  const char* ext = this->GetDefaultFileExtensionForDataSet(this->Internal->DataTypes[piece]);
+  stream << (ext ? ext : "");
   return stream.str();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkExecutive* vtkXMLCompositeDataWriter::CreateDefaultExecutive()
 {
   return vtkCompositeDataPipeline::New();
 }
 
-//----------------------------------------------------------------------------
-int vtkXMLCompositeDataWriter::FillInputPortInformation(
-  int vtkNotUsed(port), vtkInformation* info)
+//------------------------------------------------------------------------------
+int vtkXMLCompositeDataWriter::FillInputPortInformation(int vtkNotUsed(port), vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkCompositeDataSet");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLCompositeDataWriter::RemoveWrittenFiles(const char* SubDirectory)
 {
   this->RemoveADirectory(SubDirectory);
   this->DeleteAFile();
-  this->InputInformation = 0;
+  this->InputInformation = nullptr;
 }
+VTK_ABI_NAMESPACE_END
