@@ -5,11 +5,13 @@
 #include "vtkArrayIteratorIncludes.h"
 #include "vtkBitArray.h"
 #include "vtkCallbackCommand.h"
+#include "vtkCharArray.h"
 #include "vtkDataArray.h"
 #include "vtkDataArraySelection.h"
 #include "vtkDataCompressor.h"
 #include "vtkDataSet.h"
 #include "vtkDataSetAttributes.h"
+#include "vtkErrorCode.h"
 #include "vtkInformation.h"
 #include "vtkInformationDoubleKey.h"
 #include "vtkInformationDoubleVectorKey.h"
@@ -120,6 +122,9 @@ static void ReadStringVersion(const char* version, int& major, int& minor)
     }
   }
 }
+
+vtkCxxSetObjectMacro(vtkXMLReader, InputArray, vtkCharArray);
+
 //------------------------------------------------------------------------------
 vtkXMLReader::vtkXMLReader()
 {
@@ -129,6 +134,7 @@ vtkXMLReader::vtkXMLReader()
   this->StringStream = nullptr;
   this->ReadFromInputString = 0;
   this->InputString = "";
+  this->InputArray = nullptr;
   this->XMLParser = nullptr;
   this->ReaderErrorObserver = nullptr;
   this->ParserErrorObserver = nullptr;
@@ -196,6 +202,7 @@ vtkXMLReader::~vtkXMLReader()
   this->ColumnArraySelection->Delete();
   this->TimeDataStringArray->Delete();
   this->SetActiveTimeDataArrayName(nullptr);
+  this->SetInputArray(nullptr);
   if (this->ReaderErrorObserver)
   {
     this->ReaderErrorObserver->Delete();
@@ -253,6 +260,46 @@ int vtkXMLReader::CanReadFileVersion(int major, int vtkNotUsed(minor))
   return (major > vtkXMLReaderMajorVersion) ? 0 : 1;
 }
 
+//------------------------------------------------------------------------------
+void vtkXMLReader::SetInputString(const char* in)
+{
+  int len = 0;
+  if (in != nullptr)
+  {
+    len = static_cast<int>(strlen(in));
+  }
+  this->SetInputString(in, len);
+}
+
+//------------------------------------------------------------------------------
+void vtkXMLReader::SetBinaryInputString(const char* in, int len)
+{
+  this->SetInputString(in, len);
+}
+
+//------------------------------------------------------------------------------
+void vtkXMLReader::SetInputString(const char* in, int len)
+{
+  if (this->Debug)
+  {
+    vtkDebugMacro(<< "SetInputString len: " << len << " in: " << (in ? in : "(null)"));
+  }
+
+  if (!this->InputString.empty() && in && strncmp(in, this->InputString.c_str(), len) == 0)
+  {
+    return;
+  }
+
+  this->InputString.clear();
+
+  if (in && len > 0)
+  {
+    this->InputString.assign(in, len);
+  }
+
+  this->Modified();
+}
+
 //------------------------------------------------------------------------------
 int vtkXMLReader::OpenStream()
 {
@@ -324,7 +371,8 @@ int vtkXMLReader::OpenVTKString()
     return 1;
   }
 
-  if (!this->Stream && this->InputString.empty())
+  if (!this->Stream && this->InputString.empty() &&
+    (this->InputArray == nullptr || this->InputArray->GetNumberOfValues() == 0))
   {
     vtkErrorMacro("Input string not specified");
     return 0;
@@ -337,13 +385,32 @@ int vtkXMLReader::OpenVTKString()
   }
 
   // Open the string stream
-  this->StringStream = new std::istringstream(this->InputString);
-  if (!this->StringStream || !(*this->StringStream))
+  if (this->InputArray)
   {
-    vtkErrorMacro("Error opening string stream");
-    delete this->StringStream;
-    this->StringStream = nullptr;
-    return 0;
+    vtkDebugMacro(<< "Reading from InputArray");
+    std::string str(this->InputArray->GetPointer(0),
+      static_cast<size_t>(
+        this->InputArray->GetNumberOfTuples() * this->InputArray->GetNumberOfComponents()));
+    this->StringStream = new std::istringstream(str);
+    if (!this->StringStream || !(*this->StringStream))
+    {
+      vtkErrorMacro("Error opening string stream");
+      delete this->StringStream;
+      this->StringStream = nullptr;
+      return 0;
+    }
+  }
+  else if (!this->InputString.empty())
+  {
+    vtkDebugMacro(<< "Reading from InputString");
+    this->StringStream = new std::istringstream(this->InputString);
+    if (!this->StringStream || !(*this->StringStream))
+    {
+      vtkErrorMacro("Error opening string stream");
+      delete this->StringStream;
+      this->StringStream = nullptr;
+      return 0;
+    }
   }
 
   // Use the string stream.
@@ -689,6 +756,11 @@ int vtkXMLReader::RequestData(vtkInformation* vtkNotUsed(request),
     {
       this->SetupEmptyOutput();
     }
+    if (this->DataError)
+    {
+      // There was an error reading data, but it can be many things so we use unknown error code.
+      this->SetErrorCode(vtkErrorCode::UnknownError);
+    }
   }
   else
   {
@@ -1508,6 +1580,18 @@ int vtkXMLReader::CanReadFile(const char* name)
   }
 
   tester->Delete();
+  // sizeof(long) == 4 on _WIN32, check for Expat config that uses 'long long' instead
+  if (VTK_SIZEOF_LONG == 4 && result)
+  {
+    auto fileSize = fs.st_size;
+    if (fileSize > VTK_LONG_MAX && !vtkXMLParser::hasLargeOffsets())
+    {
+      vtkErrorMacro("Unable to read file, Expat must be configured with XML_LARGE_SIZE to read "
+                    "files > 2Gb: "
+        << name);
+      result = 0;
+    }
+  }
   return result;
 }
 
@@ -1537,12 +1621,12 @@ int vtkXMLReader::IntersectExtents(int* extent1, int* extent2, int* result)
   }
 
   // Get the intersection of the extents.
-  result[0] = this->Max(extent1[0], extent2[0]);
-  result[1] = this->Min(extent1[1], extent2[1]);
-  result[2] = this->Max(extent1[2], extent2[2]);
-  result[3] = this->Min(extent1[3], extent2[3]);
-  result[4] = this->Max(extent1[4], extent2[4]);
-  result[5] = this->Min(extent1[5], extent2[5]);
+  result[0] = std::max(extent1[0], extent2[0]);
+  result[1] = std::min(extent1[1], extent2[1]);
+  result[2] = std::max(extent1[2], extent2[2]);
+  result[3] = std::min(extent1[3], extent2[3]);
+  result[4] = std::max(extent1[4], extent2[4]);
+  result[5] = std::min(extent1[5], extent2[5]);
 
   return 1;
 }
@@ -1550,13 +1634,13 @@ int vtkXMLReader::IntersectExtents(int* extent1, int* extent2, int* result)
 //------------------------------------------------------------------------------
 int vtkXMLReader::Min(int a, int b)
 {
-  return (a < b) ? a : b;
+  return std::min(a, b);
 }
 
 //------------------------------------------------------------------------------
 int vtkXMLReader::Max(int a, int b)
 {
-  return (a > b) ? a : b;
+  return std::max(a, b);
 }
 
 //------------------------------------------------------------------------------
