@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkAbstractImageInterpolator.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkAbstractImageInterpolator
  * @brief   interpolate data values from images
@@ -33,10 +21,14 @@
 #include "vtkImagingCoreModule.h" // For export macro
 #include "vtkObject.h"
 
-#define VTK_IMAGE_BORDER_CLAMP 0
-#define VTK_IMAGE_BORDER_REPEAT 1
-#define VTK_IMAGE_BORDER_MIRROR 2
+enum vtkImageBorderMode : int
+{
+  VTK_IMAGE_BORDER_CLAMP = 0,
+  VTK_IMAGE_BORDER_REPEAT = 1,
+  VTK_IMAGE_BORDER_MIRROR = 2,
+};
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDataObject;
 class vtkImageData;
 class vtkDataArray;
@@ -70,7 +62,7 @@ public:
    * a Set method since Initialize() was called, you must call this method
    * to update the interpolator before you can use it.
    */
-  void Update();
+  virtual void Update();
 
   /**
    * Get the result of interpolating the specified component of the input
@@ -135,7 +127,7 @@ public:
    */
   int GetNumberOfComponents();
 
-  //@{
+  ///@{
   /**
    * A version of Interpolate that takes structured coords instead of data
    * coords.  Structured coords are the data coords after subtracting the
@@ -143,9 +135,9 @@ public:
    */
   void InterpolateIJK(const double point[3], double* value);
   void InterpolateIJK(const float point[3], float* value);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Check an x,y,z point to see if it is within the bounds for the
    * structured coords of the image.  This is meant to be called prior
@@ -154,9 +146,9 @@ public:
    */
   bool CheckBoundsIJK(const double x[3]);
   bool CheckBoundsIJK(const float x[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The border mode (default: clamp).  This controls how out-of-bounds
    * lookups are handled, i.e. how data will be extrapolated beyond the
@@ -164,13 +156,13 @@ public:
    * bounds.  The other modes wrap around to the opposite boundary, or
    * mirror the image at the boundary.
    */
-  void SetBorderMode(int mode);
+  void SetBorderMode(vtkImageBorderMode mode);
   void SetBorderModeToClamp() { this->SetBorderMode(VTK_IMAGE_BORDER_CLAMP); }
   void SetBorderModeToRepeat() { this->SetBorderMode(VTK_IMAGE_BORDER_REPEAT); }
   void SetBorderModeToMirror() { this->SetBorderMode(VTK_IMAGE_BORDER_MIRROR); }
-  int GetBorderMode() { return this->BorderMode; }
+  vtkImageBorderMode GetBorderMode() { return this->BorderMode; }
   const char* GetBorderModeAsString();
-  //@}
+  ///@}
 
   /**
    * Enable sliding window for separable kernels.
@@ -200,7 +192,7 @@ public:
    */
   virtual bool IsSeparable() = 0;
 
-  //@{
+  ///@{
   /**
    * If the data is going to be sampled on a regular grid, then the
    * interpolation weights can be precomputed.  A matrix must be supplied
@@ -215,14 +207,14 @@ public:
     int checkExtent[6], vtkInterpolationWeights*& weights);
   virtual void PrecomputeWeightsForExtent(const float matrix[16], const int extent[6],
     int checkExtent[6], vtkInterpolationWeights*& weights);
-  //@}
+  ///@}
 
   /**
    * Free the weights that were provided by PrecomputeWeightsForExtent.
    */
   virtual void FreePrecomputedWeights(vtkInterpolationWeights*& weights);
 
-  //@{
+  ///@{
   /**
    * Get a row of samples, using the weights that were precomputed
    * by PrecomputeWeightsForExtent.  Note that each sample may have
@@ -233,37 +225,35 @@ public:
     vtkInterpolationWeights*& weights, int xIdx, int yIdx, int zIdx, double* value, int n);
   void InterpolateRow(
     vtkInterpolationWeights*& weights, int xIdx, int yIdx, int zIdx, float* value, int n);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the spacing of the data being interpolated.
    */
   vtkGetVector3Macro(Spacing, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Get the direction of the data being interpolated.
+   */
+  vtkGetVectorMacro(Direction, double, 9);
+  ///@}
+
+  ///@{
   /**
    * Get the origin of the data being interpolated.
    */
   vtkGetVector3Macro(Origin, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the extent of the data being interpolated.
    */
   vtkGetVector6Macro(Extent, int);
-  //@}
-
-  //@{
-  /**
-   * Get the whole extent of the data being interpolated, including
-   * parts of the data that are not currently in memory.
-   */
-  VTK_LEGACY(int* GetWholeExtent());
-  VTK_LEGACY(void GetWholeExtent(int extent[6]));
-  //@}
+  ///@}
 
 protected:
   vtkAbstractImageInterpolator();
@@ -279,7 +269,12 @@ protected:
    */
   virtual void InternalDeepCopy(vtkAbstractImageInterpolator* obj) = 0;
 
-  //@{
+  /**
+   * Convert XYZ coordinate to IJK continuous index
+   */
+  void CoordinateToIJK(const double point[3], double ijk[3]);
+
+  ///@{
   /**
    * Get the interpolation functions.
    */
@@ -287,9 +282,9 @@ protected:
     void (**doublefunc)(vtkInterpolationInfo*, const double[3], double*));
   virtual void GetInterpolationFunc(
     void (**floatfunc)(vtkInterpolationInfo*, const float[3], float*));
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the row interpolation functions.
    */
@@ -297,9 +292,9 @@ protected:
     void (**doublefunc)(vtkInterpolationWeights*, int, int, int, double*, int));
   virtual void GetRowInterpolationFunc(
     void (**floatfunc)(vtkInterpolationWeights*, int, int, int, float*, int));
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the sliding window interpolation functions.
    */
@@ -307,19 +302,22 @@ protected:
     void (**doublefunc)(vtkInterpolationWeights*, int, int, int, double*, int));
   virtual void GetSlidingWindowFunc(
     void (**floatfunc)(vtkInterpolationWeights*, int, int, int, float*, int));
-  //@}
+  ///@}
 
   vtkDataArray* Scalars;
   double StructuredBoundsDouble[6];
   float StructuredBoundsFloat[6];
   int Extent[6];
   double Spacing[3];
+  double Direction[9];
+  double InverseDirection[9];
   double Origin[3];
   double OutValue;
   double Tolerance;
-  int BorderMode;
+  vtkImageBorderMode BorderMode;
   int ComponentOffset;
   int ComponentCount;
+  bool UseDirection;
   bool SlidingWindow;
 
   // information needed by the interpolator funcs
@@ -375,4 +373,5 @@ inline void vtkAbstractImageInterpolator::InterpolateRow(
   this->RowInterpolationFuncFloat(weights, xIdx, yIdx, zIdx, value, n);
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
