@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkImageHybridMedian2D.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkImageHybridMedian2D.h"
 
 #include "vtkImageData.h"
@@ -23,9 +11,16 @@
 #include <numeric>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageHybridMedian2D);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+void vtkImageHybridMedian2D::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
+//------------------------------------------------------------------------------
 vtkImageHybridMedian2D::vtkImageHybridMedian2D()
 {
   this->KernelSize[0] = 5;
@@ -276,3 +271,4 @@ void vtkImageHybridMedian2D::ThreadedRequestData(vtkInformation* vtkNotUsed(requ
       return;
   }
 }
+VTK_ABI_NAMESPACE_END
