@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkAngleRepresentation.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkAngleRepresentation.h"
 #include "vtkActor2D.h"
 #include "vtkCoordinate.h"
@@ -25,9 +13,10 @@
 #include "vtkTextProperty.h"
 #include "vtkWindow.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkAngleRepresentation, HandleRepresentation, vtkHandleRepresentation);
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAngleRepresentation::vtkAngleRepresentation()
 {
   this->HandleRepresentation = nullptr;
@@ -35,7 +24,6 @@ vtkAngleRepresentation::vtkAngleRepresentation()
   this->CenterRepresentation = nullptr;
   this->Point2Representation = nullptr;
 
-  this->Tolerance = 5;
   this->Placed = 0;
 
   this->Ray1Visibility = 1;
@@ -46,7 +34,7 @@ vtkAngleRepresentation::vtkAngleRepresentation()
   snprintf(this->LabelFormat, 8, "%s", "%-#6.3g");
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAngleRepresentation::~vtkAngleRepresentation()
 {
   if (this->HandleRepresentation)
@@ -70,7 +58,7 @@ vtkAngleRepresentation::~vtkAngleRepresentation()
   this->LabelFormat = nullptr;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAngleRepresentation::InstantiateHandleRepresentation()
 {
   if (!this->Point1Representation)
@@ -92,7 +80,7 @@ void vtkAngleRepresentation::InstantiateHandleRepresentation()
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkAngleRepresentation::ComputeInteractionState(
   int vtkNotUsed(X), int vtkNotUsed(Y), int vtkNotUsed(modify))
 {
@@ -126,7 +114,7 @@ int vtkAngleRepresentation::ComputeInteractionState(
   return this->InteractionState;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAngleRepresentation::StartWidgetInteraction(double e[2])
 {
   double pos[3];
@@ -138,7 +126,7 @@ void vtkAngleRepresentation::StartWidgetInteraction(double e[2])
   this->SetPoint2DisplayPosition(pos);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAngleRepresentation::CenterWidgetInteraction(double e[2])
 {
   double pos[3];
@@ -149,7 +137,7 @@ void vtkAngleRepresentation::CenterWidgetInteraction(double e[2])
   this->SetPoint2DisplayPosition(pos);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAngleRepresentation::WidgetInteraction(double e[2])
 {
   double pos[3];
@@ -159,7 +147,31 @@ void vtkAngleRepresentation::WidgetInteraction(double e[2])
   this->SetPoint2DisplayPosition(pos);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
+void vtkAngleRepresentation::SetRenderer(vtkRenderer* ren)
+{
+  if (ren == this->Renderer)
+  {
+    return;
+  }
+
+  this->Superclass::SetRenderer(ren);
+  if (this->Point1Representation)
+  {
+    this->Point1Representation->SetRenderer(ren);
+  }
+  if (this->CenterRepresentation)
+  {
+    this->CenterRepresentation->SetRenderer(ren);
+  }
+  if (this->Point2Representation)
+  {
+    this->Point2Representation->SetRenderer(ren);
+  }
+  this->Modified();
+}
+
+//------------------------------------------------------------------------------
 void vtkAngleRepresentation::BuildRepresentation()
 {
   // Make sure that tolerance is consistent between handles and this representation
@@ -168,7 +180,7 @@ void vtkAngleRepresentation::BuildRepresentation()
   this->Point2Representation->SetTolerance(this->Tolerance);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAngleRepresentation::PrintSelf(ostream& os, vtkIndent indent)
 {
   // Superclass typedef defined in vtkTypeMacro() found in vtkSetGet.h
@@ -221,3 +233,4 @@ void vtkAngleRepresentation::PrintSelf(ostream& os, vtkIndent indent)
     os << "(none)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
