@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkSocketCommunicator.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkSocketCommunicator
  * @brief   Process communication using Sockets
@@ -35,6 +23,7 @@
 #define vtkSocketCommunicator_h
 
 #include "vtkCommunicator.h"
+#include "vtkEndian.h"             // for VTK_WORDS_BIGENDIAN
 #include "vtkParallelCoreModule.h" // For export macro
 
 #include "vtkByteSwap.h" // Needed for vtkSwap macros
@@ -51,6 +40,7 @@
 #define vtkSwap8Range vtkByteSwap::Swap8BERange
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkClientSocket;
 class vtkServerSocket;
 
@@ -61,14 +51,14 @@ public:
   vtkTypeMacro(vtkSocketCommunicator, vtkCommunicator);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Wait for connection on a given port.
    * These methods return 1 on success, 0 on error.
    */
   virtual int WaitForConnection(int port);
   virtual int WaitForConnection(vtkServerSocket* socket, unsigned long msec = 0);
-  //@}
+  ///@}
 
   /**
    * Close a connection.
@@ -80,12 +70,12 @@ public:
    */
   virtual int ConnectTo(const char* hostName, int port);
 
-  //@{
+  ///@{
   /**
    * Returns 1 if bytes must be swapped in received ints, floats, etc
    */
   vtkGetMacro(SwapBytesInReceivedData, int);
-  //@}
+  ///@}
 
   /**
    * Is the communicator connected?.
@@ -99,7 +89,7 @@ public:
 
   //------------------ Communication --------------------
 
-  //@{
+  ///@{
   /**
    * Performs the actual communication.  You will usually use the convenience
    * Send functions defined in the superclass.
@@ -107,7 +97,7 @@ public:
   int SendVoidArray(
     const void* data, vtkIdType length, int type, int remoteHandle, int tag) override;
   int ReceiveVoidArray(void* data, vtkIdType length, int type, int remoteHandle, int tag) override;
-  //@}
+  ///@}
 
   /**
    * This class foolishly breaks the conventions of the superclass, so this
@@ -115,7 +105,7 @@ public:
    */
   void Barrier() override;
 
-  //@{
+  ///@{
   /**
    * This class foolishly breaks the conventions of the superclass, so the
    * default implementations of these methods do not work.  These just give
@@ -142,9 +132,9 @@ public:
     const void* sendBuffer, void* recvBuffer, vtkIdType length, int type, int operation) override;
   int AllReduceVoidArray(const void* sendBuffer, void* recvBuffer, vtkIdType length, int type,
     Operation* operation) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set or get the PerformHandshake ivar. If it is on, the communicator
    * will try to perform a handshake when connected.
@@ -153,18 +143,18 @@ public:
   vtkSetClampMacro(PerformHandshake, vtkTypeBool, 0, 1);
   vtkBooleanMacro(PerformHandshake, vtkTypeBool);
   vtkGetMacro(PerformHandshake, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the output stream to which communications should be
    * logged.  This is intended as a debugging feature.
    */
   virtual void SetLogStream(ostream* stream);
   virtual ostream* GetLogStream();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Log messages to the given file.  The file is truncated unless the
    * second argument is non-zero (default is to truncate).  If the
@@ -173,23 +163,23 @@ public:
    */
   virtual int LogToFile(const char* name);
   virtual int LogToFile(const char* name, int append);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If ReportErrors if false, all vtkErrorMacros are suppressed.
    */
   vtkSetMacro(ReportErrors, int);
   vtkGetMacro(ReportErrors, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get/Set the actual socket used for communication.
    */
   vtkGetObjectMacro(Socket, vtkClientSocket);
   void SetSocket(vtkClientSocket*);
-  //@}
+  ///@}
 
   /**
    * Performs handshake. This uses vtkClientSocket::ConnectingSide to decide
@@ -211,13 +201,13 @@ public:
    */
   int ClientSideHandshake();
 
-  //@{
+  ///@{
   /**
    * Returns true if this side of the socket is the server.  The result
    * is invalid if the socket is not connected.
    */
   vtkGetMacro(IsServer, int);
-  //@}
+  ///@}
 
   /**
    * Uniquely identifies the version of this class.  If the versions match,
@@ -299,4 +289,5 @@ private:
   vtkMessageBuffer* ReceivedMessageBuffer;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
