@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPropItem.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkPropItem.h"
 
@@ -21,6 +9,7 @@
 #include "vtkProp3D.h"
 #include "vtkRenderer.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkPropItem);
 vtkCxxSetObjectMacro(vtkPropItem, PropObject, vtkProp);
 
@@ -96,3 +85,4 @@ void vtkPropItem::PrintSelf(std::ostream& os, vtkIndent indent)
     os << "(nullptr)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
