@@ -1,7 +1,17 @@
 #!/usr/bin/env python
 import sys
-import vtk
-from vtk.test import Testing
+from vtkmodules.vtkFiltersSources import vtkSphereSource
+from vtkmodules.vtkRenderingCore import (
+    vtkActor,
+    vtkColorTransferFunction,
+    vtkPolyDataMapper,
+    vtkRenderWindow,
+    vtkRenderWindowInteractor,
+    vtkRenderer,
+)
+import vtkmodules.vtkInteractionStyle
+import vtkmodules.vtkRenderingFreeType
+import vtkmodules.vtkRenderingOpenGL2
 
 useBelowRangeColor = 0
 if sys.argv.count("--useBelowRangeColor") > 0:
@@ -11,7 +21,7 @@ if sys.argv.count("--useAboveRangeColor") > 0:
     useAboveRangeColor = 1
 
 
-cmap = vtk.vtkColorTransferFunction()
+cmap = vtkColorTransferFunction()
 cmap.AddRGBPoint(-.4, 0.8, 0.8, 0.8)
 cmap.AddRGBPoint(0.4, 1, 0, 0)
 cmap.SetUseBelowRangeColor(useBelowRangeColor)
@@ -19,7 +29,7 @@ cmap.SetBelowRangeColor(0.0, 1.0, 0.0)
 cmap.SetUseAboveRangeColor(useAboveRangeColor)
 cmap.SetAboveRangeColor(1.0, 1.0, 0.0)
 
-sphere = vtk.vtkSphereSource()
+sphere = vtkSphereSource()
 sphere.SetPhiResolution(32)
 sphere.SetThetaResolution(32)
 sphere.Update()
@@ -28,7 +38,7 @@ pd = sphere.GetOutput().GetPointData()
 for i in range(pd.GetNumberOfArrays()):
     print(pd.GetArray(i).GetName())
 
-mapper = vtk.vtkPolyDataMapper()
+mapper = vtkPolyDataMapper()
 mapper.SetInputConnection(sphere.GetOutputPort())
 mapper.SetScalarModeToUsePointFieldData()
 mapper.SelectColorArray("Normals")
@@ -37,18 +47,18 @@ mapper.SetLookupTable(cmap)
 mapper.UseLookupTableScalarRangeOn()
 mapper.InterpolateScalarsBeforeMappingOn()
 
-actor = vtk.vtkActor()
+actor = vtkActor()
 actor.SetMapper(mapper)
 
-renderer = vtk.vtkRenderer()
+renderer = vtkRenderer()
 renderer.AddActor(actor)
 renderer.ResetCamera()
 renderer.ResetCameraClippingRange()
 
-renWin = vtk.vtkRenderWindow()
+renWin = vtkRenderWindow()
 renWin.AddRenderer(renderer)
 
-iren = vtk.vtkRenderWindowInteractor()
+iren = vtkRenderWindowInteractor()
 iren.SetRenderWindow(renWin)
 iren.Initialize()
 renWin.Render()
