@@ -1,31 +1,66 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-'''
-=========================================================================
 
-  Program:   Visualization Toolkit
-  Module:    TestNamedColorsIntegration.py
 
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================
-'''
-
-import tempfile
 import os
-import vtk
-import vtk.test.Testing
-from vtk.util.misc import vtkGetDataRoot
+from vtkmodules.vtkCommonCore import (
+    vtkFloatArray,
+    vtkPoints,
+)
+from vtkmodules.vtkCommonDataModel import (
+    vtkHexagonalPrism,
+    vtkHexahedron,
+    vtkLine,
+    vtkPentagonalPrism,
+    vtkPixel,
+    vtkPolyLine,
+    vtkPolyVertex,
+    vtkPolygon,
+    vtkPyramid,
+    vtkQuad,
+    vtkTetra,
+    vtkTriangle,
+    vtkTriangleStrip,
+    vtkUnstructuredGrid,
+    vtkVertex,
+    vtkVoxel,
+    vtkWedge,
+)
+from vtkmodules.vtkIOImage import vtkBMPReader
+from vtkmodules.vtkRenderingCore import (
+    vtkActor,
+    vtkDataSetMapper,
+    vtkLight,
+    vtkProperty,
+    vtkRenderWindow,
+    vtkRenderWindowInteractor,
+    vtkRenderer,
+    vtkTexture,
+)
+import vtkmodules.vtkInteractionStyle
+import vtkmodules.vtkRenderingFreeType
+import vtkmodules.vtkRenderingOpenGL2
+import vtkmodules.test.Testing
+from vtkmodules.util.misc import vtkGetDataRoot,vtkGetTempDir
 VTK_DATA_ROOT = vtkGetDataRoot()
+VTK_TEMP_DIR = vtkGetTempDir()
 
-class cells(vtk.test.Testing.vtkTest):
+if 'vtkIOExport' in vtkmodules.__all__:
+    from vtkmodules.vtkIOExport import (
+        vtkIVExporter,
+        vtkOBJExporter,
+        vtkOOGLExporter,
+        vtkRIBExporter,
+        vtkRIBLight,
+        vtkRIBProperty,
+        vtkVRMLExporter,
+    )
+    vtk_has_IOExport = True
+else:
+    vtk_has_IOExport = False
+
+class cells(vtkmodules.test.Testing.vtkTest):
 
     def testCells(self):
 
@@ -34,21 +69,21 @@ class cells(vtk.test.Testing.vtkTest):
         # NOTE: the use of NewInstance/DeepCopy is included to increase
         # regression coverage.  It is not required in most applications.
 
-        ren = vtk.vtkRenderer()
+        ren = vtkRenderer()
         # turn off all cullers
         ren.GetCullers().RemoveAllItems()
 
-        renWin = vtk.vtkRenderWindow()
+        renWin = vtkRenderWindow()
         renWin.AddRenderer(ren)
         renWin.SetSize(300, 150)
-        iRen = vtk.vtkRenderWindowInteractor()
+        iRen = vtkRenderWindowInteractor()
         iRen.SetRenderWindow(renWin);
 
         # create a scene with one of each cell type
 
         # Voxel
 
-        voxelPoints = vtk.vtkPoints()
+        voxelPoints = vtkPoints()
         voxelPoints.SetNumberOfPoints(8)
         voxelPoints.InsertPoint(0, 0, 0, 0)
         voxelPoints.InsertPoint(1, 1, 0, 0)
@@ -59,7 +94,7 @@ class cells(vtk.test.Testing.vtkTest):
         voxelPoints.InsertPoint(6, 0, 1, 1)
         voxelPoints.InsertPoint(7, 1, 1, 1)
 
-        aVoxel = vtk.vtkVoxel()
+        aVoxel = vtkVoxel()
         aVoxel.GetPointIds().SetId(0, 0)
         aVoxel.GetPointIds().SetId(1, 1)
         aVoxel.GetPointIds().SetId(2, 2)
@@ -72,21 +107,21 @@ class cells(vtk.test.Testing.vtkTest):
         bVoxel = aVoxel.NewInstance()
         bVoxel.DeepCopy(aVoxel)
 
-        aVoxelGrid = vtk.vtkUnstructuredGrid()
+        aVoxelGrid = vtkUnstructuredGrid()
         aVoxelGrid.Allocate(1, 1)
         aVoxelGrid.InsertNextCell(aVoxel.GetCellType(), aVoxel.GetPointIds())
         aVoxelGrid.SetPoints(voxelPoints)
 
-        aVoxelMapper = vtk.vtkDataSetMapper()
+        aVoxelMapper = vtkDataSetMapper()
         aVoxelMapper.SetInputData(aVoxelGrid)
 
-        aVoxelActor = vtk.vtkActor()
+        aVoxelActor = vtkActor()
         aVoxelActor.SetMapper(aVoxelMapper)
         aVoxelActor.GetProperty().BackfaceCullingOn()
 
         # Hexahedron
 
-        hexahedronPoints = vtk.vtkPoints()
+        hexahedronPoints = vtkPoints()
         hexahedronPoints.SetNumberOfPoints(8)
         hexahedronPoints.InsertPoint(0, 0, 0, 0)
         hexahedronPoints.InsertPoint(1, 1, 0, 0)
@@ -97,7 +132,7 @@ class cells(vtk.test.Testing.vtkTest):
         hexahedronPoints.InsertPoint(6, 1, 1, 1)
         hexahedronPoints.InsertPoint(7, 0, 1, 1)
 
-        aHexahedron = vtk.vtkHexahedron()
+        aHexahedron = vtkHexahedron()
         aHexahedron.GetPointIds().SetId(0, 0)
         aHexahedron.GetPointIds().SetId(1, 1)
         aHexahedron.GetPointIds().SetId(2, 2)
@@ -110,29 +145,29 @@ class cells(vtk.test.Testing.vtkTest):
         bHexahedron = aHexahedron.NewInstance()
         bHexahedron.DeepCopy(aHexahedron)
 
-        aHexahedronGrid = vtk.vtkUnstructuredGrid()
+        aHexahedronGrid = vtkUnstructuredGrid()
         aHexahedronGrid.Allocate(1, 1)
         aHexahedronGrid.InsertNextCell(aHexahedron.GetCellType(), aHexahedron.GetPointIds())
         aHexahedronGrid.SetPoints(hexahedronPoints)
 
-        aHexahedronMapper = vtk.vtkDataSetMapper()
+        aHexahedronMapper = vtkDataSetMapper()
         aHexahedronMapper.SetInputData(aHexahedronGrid)
 
-        aHexahedronActor = vtk.vtkActor()
+        aHexahedronActor = vtkActor()
         aHexahedronActor.SetMapper(aHexahedronMapper)
         aHexahedronActor.AddPosition(2, 0, 0)
         aHexahedronActor.GetProperty().BackfaceCullingOn()
 
         # Tetra
 
-        tetraPoints = vtk.vtkPoints()
+        tetraPoints = vtkPoints()
         tetraPoints.SetNumberOfPoints(4)
         tetraPoints.InsertPoint(0, 0, 0, 0)
         tetraPoints.InsertPoint(1, 1, 0, 0)
         tetraPoints.InsertPoint(2, .5, 1, 0)
         tetraPoints.InsertPoint(3, .5, .5, 1)
 
-        aTetra = vtk.vtkTetra()
+        aTetra = vtkTetra()
         aTetra.GetPointIds().SetId(0, 0)
         aTetra.GetPointIds().SetId(1, 1)
         aTetra.GetPointIds().SetId(2, 2)
@@ -141,25 +176,25 @@ class cells(vtk.test.Testing.vtkTest):
         bTetra = aTetra.NewInstance()
         bTetra.DeepCopy(aTetra)
 
-        aTetraGrid = vtk.vtkUnstructuredGrid()
+        aTetraGrid = vtkUnstructuredGrid()
         aTetraGrid.Allocate(1, 1)
         aTetraGrid.InsertNextCell(aTetra.GetCellType(), aTetra.GetPointIds())
         aTetraGrid.SetPoints(tetraPoints)
 
-        aTetraCopy = vtk.vtkUnstructuredGrid()
+        aTetraCopy = vtkUnstructuredGrid()
         aTetraCopy.ShallowCopy(aTetraGrid)
 
-        aTetraMapper = vtk.vtkDataSetMapper()
+        aTetraMapper = vtkDataSetMapper()
         aTetraMapper.SetInputData(aTetraCopy)
 
-        aTetraActor = vtk.vtkActor()
+        aTetraActor = vtkActor()
         aTetraActor.SetMapper(aTetraMapper)
         aTetraActor.AddPosition(4, 0, 0)
         aTetraActor.GetProperty().BackfaceCullingOn()
 
         # Wedge
 
-        wedgePoints = vtk.vtkPoints()
+        wedgePoints = vtkPoints()
         wedgePoints.SetNumberOfPoints(6)
         wedgePoints.InsertPoint(0, 0, 1, 0)
         wedgePoints.InsertPoint(1, 0, 0, 0)
@@ -168,7 +203,7 @@ class cells(vtk.test.Testing.vtkTest):
         wedgePoints.InsertPoint(4, 1, 0, 0)
         wedgePoints.InsertPoint(5, 1, .5, .5)
 
-        aWedge = vtk.vtkWedge()
+        aWedge = vtkWedge()
         aWedge.GetPointIds().SetId(0, 0)
         aWedge.GetPointIds().SetId(1, 1)
         aWedge.GetPointIds().SetId(2, 2)
@@ -179,25 +214,25 @@ class cells(vtk.test.Testing.vtkTest):
         bWedge = aWedge.NewInstance()
         bWedge.DeepCopy(aWedge)
 
-        aWedgeGrid = vtk.vtkUnstructuredGrid()
+        aWedgeGrid = vtkUnstructuredGrid()
         aWedgeGrid.Allocate(1, 1)
         aWedgeGrid.InsertNextCell(aWedge.GetCellType(), aWedge.GetPointIds())
         aWedgeGrid.SetPoints(wedgePoints)
 
-        aWedgeCopy = vtk.vtkUnstructuredGrid()
+        aWedgeCopy = vtkUnstructuredGrid()
         aWedgeCopy.DeepCopy(aWedgeGrid)
 
-        aWedgeMapper = vtk.vtkDataSetMapper()
+        aWedgeMapper = vtkDataSetMapper()
         aWedgeMapper.SetInputData(aWedgeCopy)
 
-        aWedgeActor = vtk.vtkActor()
+        aWedgeActor = vtkActor()
         aWedgeActor.SetMapper(aWedgeMapper)
         aWedgeActor.AddPosition(6, 0, 0)
         aWedgeActor.GetProperty().BackfaceCullingOn()
 
         # Pyramid
 
-        pyramidPoints = vtk.vtkPoints()
+        pyramidPoints = vtkPoints()
         pyramidPoints.SetNumberOfPoints(5)
         pyramidPoints.InsertPoint(0, 0, 0, 0)
         pyramidPoints.InsertPoint(1, 1, 0, 0)
@@ -205,7 +240,7 @@ class cells(vtk.test.Testing.vtkTest):
         pyramidPoints.InsertPoint(3, 0, 1, 0)
         pyramidPoints.InsertPoint(4, .5, .5, 1)
 
-        aPyramid = vtk.vtkPyramid()
+        aPyramid = vtkPyramid()
         aPyramid.GetPointIds().SetId(0, 0)
         aPyramid.GetPointIds().SetId(1, 1)
         aPyramid.GetPointIds().SetId(2, 2)
@@ -215,29 +250,29 @@ class cells(vtk.test.Testing.vtkTest):
         bPyramid = aPyramid.NewInstance()
         bPyramid.DeepCopy(aPyramid)
 
-        aPyramidGrid = vtk.vtkUnstructuredGrid()
+        aPyramidGrid = vtkUnstructuredGrid()
         aPyramidGrid.Allocate(1, 1)
         aPyramidGrid.InsertNextCell(aPyramid.GetCellType(), aPyramid.GetPointIds())
         aPyramidGrid.SetPoints(pyramidPoints)
 
-        aPyramidMapper = vtk.vtkDataSetMapper()
+        aPyramidMapper = vtkDataSetMapper()
         aPyramidMapper.SetInputData(aPyramidGrid)
 
-        aPyramidActor = vtk.vtkActor()
+        aPyramidActor = vtkActor()
         aPyramidActor.SetMapper(aPyramidMapper)
         aPyramidActor.AddPosition(8, 0, 0)
         aPyramidActor.GetProperty().BackfaceCullingOn()
 
         # Pixel
 
-        pixelPoints = vtk.vtkPoints()
+        pixelPoints = vtkPoints()
         pixelPoints.SetNumberOfPoints(4)
         pixelPoints.InsertPoint(0, 0, 0, 0)
         pixelPoints.InsertPoint(1, 1, 0, 0)
         pixelPoints.InsertPoint(2, 0, 1, 0)
         pixelPoints.InsertPoint(3, 1, 1, 0)
 
-        aPixel = vtk.vtkPixel()
+        aPixel = vtkPixel()
         aPixel.GetPointIds().SetId(0, 0)
         aPixel.GetPointIds().SetId(1, 1)
         aPixel.GetPointIds().SetId(2, 2)
@@ -246,29 +281,29 @@ class cells(vtk.test.Testing.vtkTest):
         bPixel = aPixel.NewInstance()
         bPixel.DeepCopy(aPixel)
 
-        aPixelGrid = vtk.vtkUnstructuredGrid()
+        aPixelGrid = vtkUnstructuredGrid()
         aPixelGrid.Allocate(1, 1)
         aPixelGrid.InsertNextCell(aPixel.GetCellType(), aPixel.GetPointIds())
         aPixelGrid.SetPoints(pixelPoints)
 
-        aPixelMapper = vtk.vtkDataSetMapper()
+        aPixelMapper = vtkDataSetMapper()
         aPixelMapper.SetInputData(aPixelGrid)
 
-        aPixelActor = vtk.vtkActor()
+        aPixelActor = vtkActor()
         aPixelActor.SetMapper(aPixelMapper)
         aPixelActor.AddPosition(0, 0, 2)
         aPixelActor.GetProperty().BackfaceCullingOn()
 
         # Quad
 
-        quadPoints = vtk.vtkPoints()
+        quadPoints = vtkPoints()
         quadPoints.SetNumberOfPoints(4)
         quadPoints.InsertPoint(0, 0, 0, 0)
         quadPoints.InsertPoint(1, 1, 0, 0)
         quadPoints.InsertPoint(2, 1, 1, 0)
         quadPoints.InsertPoint(3, 0, 1, 0)
 
-        aQuad = vtk.vtkQuad()
+        aQuad = vtkQuad()
         aQuad.GetPointIds().SetId(0, 0)
         aQuad.GetPointIds().SetId(1, 1)
         aQuad.GetPointIds().SetId(2, 2)
@@ -277,35 +312,35 @@ class cells(vtk.test.Testing.vtkTest):
         bQuad = aQuad.NewInstance()
         bQuad.DeepCopy(aQuad)
 
-        aQuadGrid = vtk.vtkUnstructuredGrid()
+        aQuadGrid = vtkUnstructuredGrid()
         aQuadGrid.Allocate(1, 1)
         aQuadGrid.InsertNextCell(aQuad.GetCellType(), aQuad.GetPointIds())
         aQuadGrid.SetPoints(quadPoints)
 
-        aQuadMapper = vtk.vtkDataSetMapper()
+        aQuadMapper = vtkDataSetMapper()
         aQuadMapper.SetInputData(aQuadGrid)
 
-        aQuadActor = vtk.vtkActor()
+        aQuadActor = vtkActor()
         aQuadActor.SetMapper(aQuadMapper)
         aQuadActor.AddPosition(2, 0, 2)
         aQuadActor.GetProperty().BackfaceCullingOn()
 
         # Triangle
 
-        trianglePoints = vtk.vtkPoints()
+        trianglePoints = vtkPoints()
         trianglePoints.SetNumberOfPoints(3)
         trianglePoints.InsertPoint(0, 0, 0, 0)
         trianglePoints.InsertPoint(1, 1, 0, 0)
         trianglePoints.InsertPoint(2, .5, .5, 0)
 
-        triangleTCoords = vtk.vtkFloatArray()
+        triangleTCoords = vtkFloatArray()
         triangleTCoords.SetNumberOfComponents(2)
         triangleTCoords.SetNumberOfTuples(3)
         triangleTCoords.InsertTuple2(0, 1, 1)
         triangleTCoords.InsertTuple2(1, 2, 2)
         triangleTCoords.InsertTuple2(2, 3, 3)
 
-        aTriangle = vtk.vtkTriangle()
+        aTriangle = vtkTriangle()
         aTriangle.GetPointIds().SetId(0, 0)
         aTriangle.GetPointIds().SetId(1, 1)
         aTriangle.GetPointIds().SetId(2, 2)
@@ -313,30 +348,30 @@ class cells(vtk.test.Testing.vtkTest):
         bTriangle = aTriangle.NewInstance()
         bTriangle.DeepCopy(aTriangle)
 
-        aTriangleGrid = vtk.vtkUnstructuredGrid()
+        aTriangleGrid = vtkUnstructuredGrid()
         aTriangleGrid.Allocate(1, 1)
         aTriangleGrid.InsertNextCell(aTriangle.GetCellType(), aTriangle.GetPointIds())
         aTriangleGrid.SetPoints(trianglePoints)
         aTriangleGrid.GetPointData().SetTCoords(triangleTCoords)
 
-        aTriangleMapper = vtk.vtkDataSetMapper()
+        aTriangleMapper = vtkDataSetMapper()
         aTriangleMapper.SetInputData(aTriangleGrid)
 
-        aTriangleActor = vtk.vtkActor()
+        aTriangleActor = vtkActor()
         aTriangleActor.SetMapper(aTriangleMapper)
         aTriangleActor.AddPosition(4, 0, 2)
         aTriangleActor.GetProperty().BackfaceCullingOn()
 
         # Polygon
 
-        polygonPoints = vtk.vtkPoints()
+        polygonPoints = vtkPoints()
         polygonPoints.SetNumberOfPoints(4)
         polygonPoints.InsertPoint(0, 0, 0, 0)
         polygonPoints.InsertPoint(1, 1, 0, 0)
         polygonPoints.InsertPoint(2, 1, 1, 0)
         polygonPoints.InsertPoint(3, 0, 1, 0)
 
-        aPolygon = vtk.vtkPolygon()
+        aPolygon = vtkPolygon()
         aPolygon.GetPointIds().SetNumberOfIds(4)
         aPolygon.GetPointIds().SetId(0, 0)
         aPolygon.GetPointIds().SetId(1, 1)
@@ -346,22 +381,22 @@ class cells(vtk.test.Testing.vtkTest):
         bPolygon = aPolygon.NewInstance()
         bPolygon.DeepCopy(aPolygon)
 
-        aPolygonGrid = vtk.vtkUnstructuredGrid()
+        aPolygonGrid = vtkUnstructuredGrid()
         aPolygonGrid.Allocate(1, 1)
         aPolygonGrid.InsertNextCell(aPolygon.GetCellType(), aPolygon.GetPointIds())
         aPolygonGrid.SetPoints(polygonPoints)
 
-        aPolygonMapper = vtk.vtkDataSetMapper()
+        aPolygonMapper = vtkDataSetMapper()
         aPolygonMapper.SetInputData(aPolygonGrid)
 
-        aPolygonActor = vtk.vtkActor()
+        aPolygonActor = vtkActor()
         aPolygonActor.SetMapper(aPolygonMapper)
         aPolygonActor.AddPosition(6, 0, 2)
         aPolygonActor.GetProperty().BackfaceCullingOn()
 
         # Triangle Strip
 
-        triangleStripPoints = vtk.vtkPoints()
+        triangleStripPoints = vtkPoints()
         triangleStripPoints.SetNumberOfPoints(5)
         triangleStripPoints.InsertPoint(0, 0, 1, 0)
         triangleStripPoints.InsertPoint(1, 0, 0, 0)
@@ -369,7 +404,7 @@ class cells(vtk.test.Testing.vtkTest):
         triangleStripPoints.InsertPoint(3, 1, 0, 0)
         triangleStripPoints.InsertPoint(4, 2, 1, 0)
 
-        triangleStripTCoords = vtk.vtkFloatArray()
+        triangleStripTCoords = vtkFloatArray()
         triangleStripTCoords.SetNumberOfComponents(2)
         triangleStripTCoords.SetNumberOfTuples(3)
         triangleStripTCoords.InsertTuple2(0, 1, 1)
@@ -378,7 +413,7 @@ class cells(vtk.test.Testing.vtkTest):
         triangleStripTCoords.InsertTuple2(3, 4, 4)
         triangleStripTCoords.InsertTuple2(4, 5, 5)
 
-        aTriangleStrip = vtk.vtkTriangleStrip()
+        aTriangleStrip = vtkTriangleStrip()
         aTriangleStrip.GetPointIds().SetNumberOfIds(5)
         aTriangleStrip.GetPointIds().SetId(0, 0)
         aTriangleStrip.GetPointIds().SetId(1, 1)
@@ -389,56 +424,56 @@ class cells(vtk.test.Testing.vtkTest):
         bTriangleStrip = aTriangleStrip.NewInstance()
         bTriangleStrip.DeepCopy(aTriangleStrip)
 
-        aTriangleStripGrid = vtk.vtkUnstructuredGrid()
+        aTriangleStripGrid = vtkUnstructuredGrid()
         aTriangleStripGrid.Allocate(1, 1)
         aTriangleStripGrid.InsertNextCell(aTriangleStrip.GetCellType(), aTriangleStrip.GetPointIds())
         aTriangleStripGrid.SetPoints(triangleStripPoints)
         aTriangleStripGrid.GetPointData().SetTCoords(triangleStripTCoords)
 
-        aTriangleStripMapper = vtk.vtkDataSetMapper()
+        aTriangleStripMapper = vtkDataSetMapper()
         aTriangleStripMapper.SetInputData(aTriangleStripGrid)
 
-        aTriangleStripActor = vtk.vtkActor()
+        aTriangleStripActor = vtkActor()
         aTriangleStripActor.SetMapper(aTriangleStripMapper)
         aTriangleStripActor.AddPosition(8, 0, 2)
         aTriangleStripActor.GetProperty().BackfaceCullingOn()
 
         # Line
 
-        linePoints = vtk.vtkPoints()
+        linePoints = vtkPoints()
         linePoints.SetNumberOfPoints(2)
         linePoints.InsertPoint(0, 0, 0, 0)
         linePoints.InsertPoint(1, 1, 1, 0)
 
-        aLine = vtk.vtkLine()
+        aLine = vtkLine()
         aLine.GetPointIds().SetId(0, 0)
         aLine.GetPointIds().SetId(1, 1)
 
         bLine = aLine.NewInstance()
         bLine.DeepCopy(aLine)
 
-        aLineGrid = vtk.vtkUnstructuredGrid()
+        aLineGrid = vtkUnstructuredGrid()
         aLineGrid.Allocate(1, 1)
         aLineGrid.InsertNextCell(aLine.GetCellType(), aLine.GetPointIds())
         aLineGrid.SetPoints(linePoints)
 
-        aLineMapper = vtk.vtkDataSetMapper()
+        aLineMapper = vtkDataSetMapper()
         aLineMapper.SetInputData(aLineGrid)
 
-        aLineActor = vtk.vtkActor()
+        aLineActor = vtkActor()
         aLineActor.SetMapper(aLineMapper)
         aLineActor.AddPosition(0, 0, 4)
         aLineActor.GetProperty().BackfaceCullingOn()
 
         # Poly line
 
-        polyLinePoints = vtk.vtkPoints()
+        polyLinePoints = vtkPoints()
         polyLinePoints.SetNumberOfPoints(3)
         polyLinePoints.InsertPoint(0, 0, 0, 0)
         polyLinePoints.InsertPoint(1, 1, 1, 0)
         polyLinePoints.InsertPoint(2, 1, 0, 0)
 
-        aPolyLine = vtk.vtkPolyLine()
+        aPolyLine = vtkPolyLine()
         aPolyLine.GetPointIds().SetNumberOfIds(3)
         aPolyLine.GetPointIds().SetId(0, 0)
         aPolyLine.GetPointIds().SetId(1, 1)
@@ -447,53 +482,53 @@ class cells(vtk.test.Testing.vtkTest):
         bPolyLine = aPolyLine.NewInstance()
         bPolyLine.DeepCopy(aPolyLine)
 
-        aPolyLineGrid = vtk.vtkUnstructuredGrid()
+        aPolyLineGrid = vtkUnstructuredGrid()
         aPolyLineGrid.Allocate(1, 1)
         aPolyLineGrid.InsertNextCell(aPolyLine.GetCellType(), aPolyLine.GetPointIds())
         aPolyLineGrid.SetPoints(polyLinePoints)
 
-        aPolyLineMapper = vtk.vtkDataSetMapper()
+        aPolyLineMapper = vtkDataSetMapper()
         aPolyLineMapper.SetInputData(aPolyLineGrid)
 
-        aPolyLineActor = vtk.vtkActor()
+        aPolyLineActor = vtkActor()
         aPolyLineActor.SetMapper(aPolyLineMapper)
         aPolyLineActor.AddPosition(2, 0, 4)
         aPolyLineActor.GetProperty().BackfaceCullingOn()
 
         # Vertex
 
-        vertexPoints = vtk.vtkPoints()
+        vertexPoints = vtkPoints()
         vertexPoints.SetNumberOfPoints(1)
         vertexPoints.InsertPoint(0, 0, 0, 0)
 
-        aVertex = vtk.vtkVertex()
+        aVertex = vtkVertex()
         aVertex.GetPointIds().SetId(0, 0)
 
         bVertex = aVertex.NewInstance()
         bVertex.DeepCopy(aVertex)
 
-        aVertexGrid = vtk.vtkUnstructuredGrid()
+        aVertexGrid = vtkUnstructuredGrid()
         aVertexGrid.Allocate(1, 1)
         aVertexGrid.InsertNextCell(aVertex.GetCellType(), aVertex.GetPointIds())
         aVertexGrid.SetPoints(vertexPoints)
 
-        aVertexMapper = vtk.vtkDataSetMapper()
+        aVertexMapper = vtkDataSetMapper()
         aVertexMapper.SetInputData(aVertexGrid)
 
-        aVertexActor = vtk.vtkActor()
+        aVertexActor = vtkActor()
         aVertexActor.SetMapper(aVertexMapper)
         aVertexActor.AddPosition(0, 0, 6)
         aVertexActor.GetProperty().BackfaceCullingOn()
 
         # Poly Vertex
 
-        polyVertexPoints = vtk.vtkPoints()
+        polyVertexPoints = vtkPoints()
         polyVertexPoints.SetNumberOfPoints(3)
         polyVertexPoints.InsertPoint(0, 0, 0, 0)
         polyVertexPoints.InsertPoint(1, 1, 0, 0)
         polyVertexPoints.InsertPoint(2, 1, 1, 0)
 
-        aPolyVertex = vtk.vtkPolyVertex()
+        aPolyVertex = vtkPolyVertex()
         aPolyVertex.GetPointIds().SetNumberOfIds(3)
         aPolyVertex.GetPointIds().SetId(0, 0)
         aPolyVertex.GetPointIds().SetId(1, 1)
@@ -502,22 +537,22 @@ class cells(vtk.test.Testing.vtkTest):
         bPolyVertex = aPolyVertex.NewInstance()
         bPolyVertex.DeepCopy(aPolyVertex)
 
-        aPolyVertexGrid = vtk.vtkUnstructuredGrid()
+        aPolyVertexGrid = vtkUnstructuredGrid()
         aPolyVertexGrid.Allocate(1, 1)
         aPolyVertexGrid.InsertNextCell(aPolyVertex.GetCellType(), aPolyVertex.GetPointIds())
         aPolyVertexGrid.SetPoints(polyVertexPoints)
 
-        aPolyVertexMapper = vtk.vtkDataSetMapper()
+        aPolyVertexMapper = vtkDataSetMapper()
         aPolyVertexMapper.SetInputData(aPolyVertexGrid)
 
-        aPolyVertexActor = vtk.vtkActor()
+        aPolyVertexActor = vtkActor()
         aPolyVertexActor.SetMapper(aPolyVertexMapper)
         aPolyVertexActor.AddPosition(2, 0, 6)
         aPolyVertexActor.GetProperty().BackfaceCullingOn()
 
         # Pentagonal prism
 
-        pentaPoints = vtk.vtkPoints()
+        pentaPoints = vtkPoints()
         pentaPoints.SetNumberOfPoints(10)
         pentaPoints.InsertPoint(0, 0.25, 0.0, 0.0)
         pentaPoints.InsertPoint(1, 0.75, 0.0, 0.0)
@@ -530,7 +565,7 @@ class cells(vtk.test.Testing.vtkTest):
         pentaPoints.InsertPoint(8, 0.5, 1.0, 1.0)
         pentaPoints.InsertPoint(9, 0.0, 0.5, 1.0)
 
-        aPenta = vtk.vtkPentagonalPrism()
+        aPenta = vtkPentagonalPrism()
         aPenta.GetPointIds().SetId(0, 0)
         aPenta.GetPointIds().SetId(1, 1)
         aPenta.GetPointIds().SetId(2, 2)
@@ -545,25 +580,25 @@ class cells(vtk.test.Testing.vtkTest):
         bPenta = aPenta.NewInstance()
         bPenta.DeepCopy(aPenta)
 
-        aPentaGrid = vtk.vtkUnstructuredGrid()
+        aPentaGrid = vtkUnstructuredGrid()
         aPentaGrid.Allocate(1, 1)
         aPentaGrid.InsertNextCell(aPenta.GetCellType(), aPenta.GetPointIds())
         aPentaGrid.SetPoints(pentaPoints)
 
-        aPentaCopy = vtk.vtkUnstructuredGrid()
+        aPentaCopy = vtkUnstructuredGrid()
         aPentaCopy.DeepCopy(aPentaGrid)
 
-        aPentaMapper = vtk.vtkDataSetMapper()
+        aPentaMapper = vtkDataSetMapper()
         aPentaMapper.SetInputData(aPentaCopy)
 
-        aPentaActor = vtk.vtkActor()
+        aPentaActor = vtkActor()
         aPentaActor.SetMapper(aPentaMapper)
         aPentaActor.AddPosition(10, 0, 0)
         aPentaActor.GetProperty().BackfaceCullingOn()
 
         # Hexagonal prism
 
-        hexaPoints = vtk.vtkPoints()
+        hexaPoints = vtkPoints()
         hexaPoints.SetNumberOfPoints(12)
         hexaPoints.InsertPoint(0, 0.0, 0.0, 0.0)
         hexaPoints.InsertPoint(1, 0.5, 0.0, 0.0)
@@ -578,7 +613,7 @@ class cells(vtk.test.Testing.vtkTest):
         hexaPoints.InsertPoint(10, 0.5, 1.0, 1.0)
         hexaPoints.InsertPoint(11, 0.0, 0.5, 1.0)
 
-        aHexa = vtk.vtkHexagonalPrism()
+        aHexa = vtkHexagonalPrism()
         aHexa.GetPointIds().SetId(0, 0)
         aHexa.GetPointIds().SetId(1, 1)
         aHexa.GetPointIds().SetId(2, 2)
@@ -595,39 +630,40 @@ class cells(vtk.test.Testing.vtkTest):
         bHexa = aHexa.NewInstance()
         bHexa.DeepCopy(aHexa)
 
-        aHexaGrid = vtk.vtkUnstructuredGrid()
+        aHexaGrid = vtkUnstructuredGrid()
         aHexaGrid.Allocate(1, 1)
         aHexaGrid.InsertNextCell(aHexa.GetCellType(), aHexa.GetPointIds())
         aHexaGrid.SetPoints(hexaPoints)
 
-        aHexaCopy = vtk.vtkUnstructuredGrid()
+        aHexaCopy = vtkUnstructuredGrid()
         aHexaCopy.DeepCopy(aHexaGrid)
 
-        aHexaMapper = vtk.vtkDataSetMapper()
+        aHexaMapper = vtkDataSetMapper()
         aHexaMapper.SetInputData(aHexaCopy)
 
-        aHexaActor = vtk.vtkActor()
+        aHexaActor = vtkActor()
         aHexaActor.SetMapper(aHexaMapper)
         aHexaActor.AddPosition(12, 0, 0)
         aHexaActor.GetProperty().BackfaceCullingOn()
 
         # RIB property
-        if hasattr(vtk, 'vtkRIBProperty'):
-            aRIBProperty = vtk.vtkRIBProperty()
+        if vtk_has_IOExport:
+            aRIBProperty = vtkRIBProperty()
             aRIBProperty.SetVariable("Km", "float")
             aRIBProperty.SetSurfaceShader("LGVeinedmarble")
             aRIBProperty.SetVariable("veinfreq", "float")
             aRIBProperty.AddVariable("warpfreq", "float")
             aRIBProperty.AddVariable("veincolor", "color")
-            aRIBProperty.AddParameter("veinfreq", " 2")
-            aRIBProperty.AddParameter("veincolor", "1.0000 1.0000 0.9412")
-            bRIBProperty = vtk.vtkRIBProperty()
+            aRIBProperty.AddSurfaceShaderParameter("veinfreq", " 2")
+            aRIBProperty.AddSurfaceShaderParameter("veincolor", "1.0000 1.0000 0.9412")
+            bRIBProperty = vtkRIBProperty()
             bRIBProperty.SetVariable("Km", "float")
-            bRIBProperty.SetParameter("Km", "1.0")
+            bRIBProperty.SetSurfaceShaderParameter("Km", "1.0")
             bRIBProperty.SetDisplacementShader("dented")
             bRIBProperty.SetSurfaceShader("plastic")
-        aProperty = vtk.vtkProperty()
-        bProperty = vtk.vtkProperty()
+
+        aProperty = vtkProperty()
+        bProperty = vtkProperty()
 
         aTriangleActor.SetProperty(aProperty)
         aTriangleStripActor.SetProperty(bProperty)
@@ -651,14 +687,15 @@ class cells(vtk.test.Testing.vtkTest):
         ren.AddActor(aPentaActor);aPentaActor.GetProperty().SetDiffuseColor(.2, .4, .7)
         ren.AddActor(aHexaActor);aHexaActor.GetProperty().SetDiffuseColor(.7, .5, 1)
 
-        if hasattr(vtk, 'vtkRIBLight'):
-            aRIBLight = vtk.vtkRIBLight()
-            aRIBLight.ShadowsOn()
-        aLight = vtk.vtkLight()
+        aRIBLight = vtkRIBLight()
+        aRIBLight.SetIntensity(0.7)
+
+        ren.AddLight(aRIBLight)
+        aLight = vtkLight()
 
         aLight.PositionalOn()
-        aLight.SetConeAngle(25)
-
+        aLight.SetConeAngle(10.0)
+        aLight.SetIntensity(0.7)
         ren.AddLight(aLight)
 
         ren.ResetCamera()
@@ -667,42 +704,42 @@ class cells(vtk.test.Testing.vtkTest):
         ren.GetActiveCamera().Dolly(2.8)
         ren.ResetCameraClippingRange()
 
-        aLight.SetFocalPoint(ren.GetActiveCamera().GetFocalPoint())
-        aLight.SetPosition(ren.GetActiveCamera().GetPosition())
+        dir = VTK_TEMP_DIR
 
-        # write to the temp directory if possible, otherwise use .
-        dir = tempfile.gettempdir()
-
-        atext = vtk.vtkTexture()
-        pnmReader = vtk.vtkBMPReader()
+        atext = vtkTexture()
+        pnmReader = vtkBMPReader()
         pnmReader.SetFileName(VTK_DATA_ROOT + "/Data/masonry.bmp")
         atext.SetInputConnection(pnmReader.GetOutputPort())
         atext.InterpolateOff()
         aTriangleActor.SetTexture(atext)
 
-        # bascially have IO/Export ?
-        if hasattr(vtk, 'vtkRIBExporter'):
-            rib = vtk.vtkRIBExporter()
+        aRIBLight.SetFocalPoint(ren.GetActiveCamera().GetFocalPoint())
+        aRIBLight.SetPosition(ren.GetActiveCamera().GetPosition())
+        aLight.SetFocalPoint(ren.GetActiveCamera().GetFocalPoint())
+        aLight.SetPosition(ren.GetActiveCamera().GetPosition())
+
+        # basically have IO/Export ?
+        if vtk_has_IOExport:
+            rib = vtkRIBExporter()
             rib.SetInput(renWin)
             rib.SetFilePrefix(dir + '/cells')
             rib.SetTexturePrefix(dir + '/cells')
             rib.Write()
-            os.remove(dir + '/cells.rib')
 
-            iv = vtk.vtkIVExporter()
+            iv = vtkIVExporter()
             iv.SetInput(renWin)
             iv.SetFileName(dir + "/cells.iv")
             iv.Write()
             os.remove(dir + '/cells.iv')
 
-            obj = vtk.vtkOBJExporter()
+            obj = vtkOBJExporter()
             obj.SetInput(renWin)
             obj.SetFilePrefix(dir + "/cells")
             obj.Write()
             os.remove(dir + '/cells.obj')
             os.remove(dir + '/cells.mtl')
 
-            vrml = vtk.vtkVRMLExporter()
+            vrml = vtkVRMLExporter()
             vrml.SetInput(renWin)
             #vrml.SetStartWrite(vrml.SetFileName(dir + "/cells.wrl"))
             #vrml.SetEndWrite(vrml.SetFileName("/a/acells.wrl"))
@@ -711,7 +748,7 @@ class cells(vtk.test.Testing.vtkTest):
             vrml.Write()
             os.remove(dir + '/cells.wrl')
 
-            oogl = vtk.vtkOOGLExporter()
+            oogl = vtkOOGLExporter()
             oogl.SetInput(renWin)
             oogl.SetFileName(dir + "/cells.oogl")
             oogl.Write()
@@ -746,8 +783,8 @@ class cells(vtk.test.Testing.vtkTest):
         renWin.Render()
 
         img_file = "cells.png"
-        vtk.test.Testing.compareImage(iRen.GetRenderWindow(), vtk.test.Testing.getAbsImagePath(img_file), threshold=25)
-        vtk.test.Testing.interact()
+        vtkmodules.test.Testing.compareImage(iRen.GetRenderWindow(), vtkmodules.test.Testing.getAbsImagePath(img_file))
+        vtkmodules.test.Testing.interact()
 
 if __name__ == "__main__":
-     vtk.test.Testing.main([(cells, 'test')])
+     vtkmodules.test.Testing.main([(cells, 'test')])
