@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPolyDataMapper.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkPolyDataMapper.h"
 
 #include "vtkExecutive.h"
@@ -23,9 +11,10 @@
 #include "vtkRenderWindow.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkObjectFactoryNewMacro(vtkPolyDataMapper);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPolyDataMapper::vtkPolyDataMapper()
 {
   this->Piece = 0;
@@ -34,9 +23,24 @@ vtkPolyDataMapper::vtkPolyDataMapper()
   this->GhostLevel = 0;
   this->SeamlessU = false;
   this->SeamlessV = false;
+  this->PauseShiftScale = false;
+  this->ShiftScaleMethod = ShiftScaleMethodType::AUTO_SHIFT_SCALE;
+  this->SetPointIdArrayName(nullptr);
+  this->SetCellIdArrayName(nullptr);
+  this->SetCompositeIdArrayName(nullptr);
+  this->SetProcessIdArrayName(nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+vtkPolyDataMapper::~vtkPolyDataMapper()
+{
+  this->SetPointIdArrayName(nullptr);
+  this->SetCellIdArrayName(nullptr);
+  this->SetCompositeIdArrayName(nullptr);
+  this->SetProcessIdArrayName(nullptr);
+}
+
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::Render(vtkRenderer* ren, vtkActor* act)
 {
   if (this->Static)
@@ -66,20 +70,20 @@ void vtkPolyDataMapper::Render(vtkRenderer* ren, vtkActor* act)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::SetInputData(vtkPolyData* input)
 {
   this->SetInputDataInternal(0, input);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Specify the input data or filter.
 vtkPolyData* vtkPolyDataMapper::GetInput()
 {
   return vtkPolyData::SafeDownCast(this->GetExecutive()->GetInputData(0, 0));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkPolyDataMapper::ProcessRequest(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector*)
 {
@@ -96,7 +100,7 @@ vtkTypeBool vtkPolyDataMapper::ProcessRequest(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Get the bounds for the input of this mapper as
 // (Xmin,Xmax,Ymin,Ymax,Zmin,Zmax).
 double* vtkPolyDataMapper::GetBounds()
@@ -132,11 +136,16 @@ double* vtkPolyDataMapper::GetBounds()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::ComputeBounds()
 {
   vtkPolyData* input = this->GetInput();
-  if (input)
+  if (input && input->GetNumberOfCells())
+  {
+    input->GetCellsBounds(this->Bounds);
+  }
+  // We prefer cells bounds but if polydata has no cell defined, use classic bounds instead.
+  else if (input)
   {
     input->GetBounds(this->Bounds);
   }
@@ -146,7 +155,7 @@ void vtkPolyDataMapper::ComputeBounds()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::ShallowCopy(vtkAbstractMapper* mapper)
 {
   vtkPolyDataMapper* m = vtkPolyDataMapper::SafeDownCast(mapper);
@@ -158,13 +167,18 @@ void vtkPolyDataMapper::ShallowCopy(vtkAbstractMapper* mapper)
     this->SetNumberOfSubPieces(m->GetNumberOfSubPieces());
     this->SetSeamlessU(m->GetSeamlessU());
     this->SetSeamlessV(m->GetSeamlessV());
+    this->SetVBOShiftScaleMethod(m->GetVBOShiftScaleMethod());
+    this->SetPauseShiftScale(m->GetPauseShiftScale());
+    this->SetCellIdArrayName(m->GetCellIdArrayName());
+    this->SetPointIdArrayName(m->GetPointIdArrayName());
+    this->SetProcessIdArrayName(m->GetProcessIdArrayName());
   }
 
   // Now do superclass
   this->vtkMapper::ShallowCopy(mapper);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::MapDataArrayToVertexAttribute(const char* vtkNotUsed(vertexAttributeName),
   const char* vtkNotUsed(dataArrayName), int vtkNotUsed(fieldAssociation),
   int vtkNotUsed(componentno))
@@ -172,7 +186,7 @@ void vtkPolyDataMapper::MapDataArrayToVertexAttribute(const char* vtkNotUsed(ver
   vtkErrorMacro("Not implemented at this level...");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::MapDataArrayToMultiTextureAttribute(const char* vtkNotUsed(tname),
   const char* vtkNotUsed(dataArrayName), int vtkNotUsed(fieldAssociation),
   int vtkNotUsed(componentno))
@@ -180,19 +194,19 @@ void vtkPolyDataMapper::MapDataArrayToMultiTextureAttribute(const char* vtkNotUs
   vtkErrorMacro("Not implemented at this level...");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::RemoveVertexAttributeMapping(const char* vtkNotUsed(vertexAttributeName))
 {
   vtkErrorMacro("Not implemented at this level...");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::RemoveAllVertexAttributeMappings()
 {
   vtkErrorMacro("Not implemented at this level...");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -203,14 +217,14 @@ void vtkPolyDataMapper::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Number of sub pieces: " << this->NumberOfSubPieces << endl;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPolyDataMapper::FillInputPortInformation(int vtkNotUsed(port), vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkPolyData");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::Update(int port)
 {
   if (this->Static)
@@ -220,7 +234,7 @@ void vtkPolyDataMapper::Update(int port)
   this->Superclass::Update(port);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolyDataMapper::Update()
 {
   if (this->Static)
@@ -230,7 +244,7 @@ void vtkPolyDataMapper::Update()
   this->Superclass::Update();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkPolyDataMapper::Update(int port, vtkInformationVector* requests)
 {
   if (this->Static)
@@ -240,7 +254,7 @@ vtkTypeBool vtkPolyDataMapper::Update(int port, vtkInformationVector* requests)
   return this->Superclass::Update(port, requests);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkPolyDataMapper::Update(vtkInformation* requests)
 {
   if (this->Static)
@@ -249,3 +263,4 @@ vtkTypeBool vtkPolyDataMapper::Update(vtkInformation* requests)
   }
   return this->Superclass::Update(requests);
 }
+VTK_ABI_NAMESPACE_END
