@@ -54,7 +54,8 @@ bool vtkStereoCompositor::RedBlue(
   }
 
   vtkSMPTools::For(0, rgbLeftNResult->GetNumberOfTuples(),
-    [rgbLeftNResult, rgbRight](vtkIdType first, vtkIdType last) {
+    [rgbLeftNResult, rgbRight](vtkIdType first, vtkIdType last)
+    {
       unsigned char value[3];
       unsigned char output[3] = { 0, 0, 0 };
       for (auto cc = first; cc < last; ++cc)
@@ -95,44 +96,46 @@ bool vtkStereoCompositor::Anaglyph(vtkUnsignedCharArray* rgbLeftNResult,
     satcolor[x] = int(a * x);
   }
 
-  vtkSMPTools::For(0, rgbLeftNResult->GetNumberOfTuples(), [&](vtkIdType first, vtkIdType last) {
-    unsigned char inL[3], inR[3];
-    unsigned char out[3];
-    for (auto cc = first; cc < last; ++cc)
+  vtkSMPTools::For(0, rgbLeftNResult->GetNumberOfTuples(),
+    [&](vtkIdType first, vtkIdType last)
     {
-      rgbLeftNResult->GetTypedTuple(cc, inL);
-      rgbRight->GetTypedTuple(cc, inR);
+      unsigned char inL[3], inR[3];
+      unsigned char out[3];
+      for (auto cc = first; cc < last; ++cc)
+      {
+        rgbLeftNResult->GetTypedTuple(cc, inL);
+        rgbRight->GetTypedTuple(cc, inR);
 
-      auto ave0 = avecolor[inL[0]][0] + avecolor[inL[1]][1] + avecolor[inL[2]][2];
-      auto ave1 = avecolor[inR[0]][0] + avecolor[inR[1]][1] + avecolor[inR[2]][2];
+        auto ave0 = avecolor[inL[0]][0] + avecolor[inL[1]][1] + avecolor[inL[2]][2];
+        auto ave1 = avecolor[inR[0]][0] + avecolor[inR[1]][1] + avecolor[inR[2]][2];
 
-      if (m0 & 0x4)
-      {
-        out[0] = satcolor[inL[0]] + ave0;
+        if (m0 & 0x4)
+        {
+          out[0] = satcolor[inL[0]] + ave0;
+        }
+        if (m0 & 0x2)
+        {
+          out[1] = satcolor[inL[1]] + ave0;
+        }
+        if (m0 & 0x1)
+        {
+          out[2] = satcolor[inL[2]] + ave0;
+        }
+        if (m1 & 0x4)
+        {
+          out[0] = satcolor[inR[0]] + ave1;
+        }
+        if (m1 & 0x2)
+        {
+          out[1] = satcolor[inR[1]] + ave1;
+        }
+        if (m1 & 0x1)
+        {
+          out[2] = satcolor[inR[2]] + ave1;
+        }
+        rgbLeftNResult->SetTypedTuple(cc, out);
       }
-      if (m0 & 0x2)
-      {
-        out[1] = satcolor[inL[1]] + ave0;
-      }
-      if (m0 & 0x1)
-      {
-        out[2] = satcolor[inL[2]] + ave0;
-      }
-      if (m1 & 0x4)
-      {
-        out[0] = satcolor[inR[0]] + ave1;
-      }
-      if (m1 & 0x2)
-      {
-        out[1] = satcolor[inR[1]] + ave1;
-      }
-      if (m1 & 0x1)
-      {
-        out[2] = satcolor[inR[2]] + ave1;
-      }
-      rgbLeftNResult->SetTypedTuple(cc, out);
-    }
-  });
+    });
 
   return true;
 }
