@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestTextActorScaleModeProp.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkTextActor.h"
 
@@ -21,7 +9,7 @@
 #include "vtkRenderer.h"
 #include "vtkTextProperty.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int TestTextActorScaleModeProp(int, char*[])
 {
   // Test PROP scale mode actor with a text property that's instantiated first
@@ -55,7 +43,7 @@ int TestTextActorScaleModeProp(int, char*[])
   ren->SetBackground(0.1, 0.1, 0.1);
   win->SetSize(300, 300);
 
-  ren->AddActor2D(textActor);
+  ren->AddViewProp(textActor);
 
   win->SetMultiSamples(0);
   win->GetInteractor()->Initialize();
