@@ -102,7 +102,7 @@ int TestPointGaussianMapperOpacity(int argc, char* argv[])
 
   // since this shader only uses a radus of sqrt(2) we will adjust the mapper
   // to render a smaller area than the default radius of 3.0
-  mapper->SetTriangleScale(1.5);
+  mapper->SetBoundScale(1.5);
 
   vtkNew<vtkColorTransferFunction> ctf;
   ctf->AddHSVPoint(0.0, 0.1, 0.7, 1.0);
