@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkClearRGBPass.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkClearRGBPass
  * @brief   Paint in the color buffer.
@@ -27,10 +15,12 @@
 
 #include "vtkRenderPass.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
+#include "vtkWrappingHints.h"          // For VTK_MARSHALAUTO
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLRenderWindow;
 
-class VTKRENDERINGOPENGL2_EXPORT vtkClearRGBPass : public vtkRenderPass
+class VTKRENDERINGOPENGL2_EXPORT VTK_MARSHALAUTO vtkClearRGBPass : public vtkRenderPass
 {
 public:
   static vtkClearRGBPass* New();
@@ -42,14 +32,14 @@ public:
    */
   void Render(const vtkRenderState* s) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the background color of the rendering screen using an rgb color
    * specification.
    */
   vtkSetVector3Macro(Background, double);
   vtkGetVector3Macro(Background, double);
-  //@}
+  ///@}
 
 protected:
   /**
@@ -69,4 +59,5 @@ private:
   void operator=(const vtkClearRGBPass&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
