@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkEGLRenderWindow.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkEGLRenderWindow.h"
 
@@ -21,27 +9,27 @@
 #include "vtkOpenGLRenderer.h"
 #include "vtkRenderWindowInteractor.h"
 #include "vtkRendererCollection.h"
-#include "vtkToolkits.h"
 #include "vtkType.h"
-#include "vtk_glew.h"
 #include "vtksys/SystemTools.hxx"
 
-#include <EGL/egl.h>
+#include "vtk_glad.h"
+#include "vtkglad/include/glad/egl.h"
+
 #include <atomic>
 #include <cassert>
 #include <sstream>
 
-#ifdef ANDROID
+#if defined(__ANDROID__) || defined(ANDROID)
 #include <android/native_window.h>
+#include <vtkAndroidRenderWindowInteractor.h>
 #endif
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 typedef void* EGLDeviceEXT;
 typedef EGLBoolean (*EGLQueryDevicesType)(EGLint, EGLDeviceEXT*, EGLint*);
 typedef EGLDisplay (*EGLGetPlatformDisplayType)(EGLenum, void*, const EGLint*);
-const EGLenum EGL_PLATFORM_DEVICE_EXT = 0x313F;
-
 /**
  * EGLDisplay provided by eglGetDisplay() call can be same handle for multiple
  * instances of vtkEGLRenderWindow. In which case, while it's safe to call
@@ -51,7 +39,7 @@ const EGLenum EGL_PLATFORM_DEVICE_EXT = 0x313F;
  */
 class vtkEGLDisplayInitializationHelper
 {
-  static std::map<EGLDisplay, std::atomic<int64_t> > DisplayUsageCounts;
+  static std::map<EGLDisplay, std::atomic<int64_t>> DisplayUsageCounts;
 
 public:
   static EGLBoolean Initialize(EGLDisplay dpy, EGLint* major, EGLint* minor)
@@ -69,9 +57,12 @@ public:
     }
     return EGL_TRUE;
   }
+
+  static int DefaultDeviceIndex;
 };
 
-std::map<EGLDisplay, std::atomic<int64_t> > vtkEGLDisplayInitializationHelper::DisplayUsageCounts;
+std::map<EGLDisplay, std::atomic<int64_t>> vtkEGLDisplayInitializationHelper::DisplayUsageCounts;
+int vtkEGLDisplayInitializationHelper::DefaultDeviceIndex = VTK_DEFAULT_EGL_DEVICE_INDEX;
 
 struct vtkEGLDeviceExtensions
 {
@@ -121,32 +112,41 @@ private:
 
 vtkStandardNewMacro(vtkEGLRenderWindow);
 
-struct vtkEGLRenderWindow::vtkInternals
+class vtkEGLRenderWindow::vtkInternals
 {
+public:
   EGLNativeWindowType Window;
   EGLDisplay Display;
   EGLSurface Surface;
   EGLContext Context;
+  bool EGLInitialized; // When set, it means methods from EGL 1.4 and higher are accessible.
   vtkInternals()
     : Window((EGLNativeWindowType)0)
     , Display(EGL_NO_DISPLAY)
     , Surface(EGL_NO_SURFACE)
     , Context(EGL_NO_CONTEXT)
+    , EGLInitialized(false)
   {
+#if defined(__ANDROID__) || defined(ANDROID)
+    // On Android platform, unconditionally load the EGL functions with EGL_NO_DISPLAY
+    // because the EGL library is always available.
+    gladLoaderLoadEGL(this->Display);
+    this->EGLInitialized = true;
+#endif
   }
 };
 
 vtkEGLRenderWindow::vtkEGLRenderWindow()
 {
   this->Internals = new vtkInternals();
-  this->OwnWindow = 1;
+  this->OwnWindow = true;
   this->ScreenSize[0] = 1920;
   this->ScreenSize[1] = 1080;
 
   // this is initialized in vtkRenderWindow
   // so we don't need to initialize on else
-#ifdef VTK_USE_OFFSCREEN_EGL
-  this->DeviceIndex = VTK_DEFAULT_EGL_DEVICE_INDEX;
+  this->DeviceIndex = -1;
+#if !defined(__ANDROID__) && !defined(ANDROID)
   this->ShowWindow = false;
 #endif
 
@@ -154,11 +154,33 @@ vtkEGLRenderWindow::vtkEGLRenderWindow()
   char* EGLDefaultDeviceIndexEnv = std::getenv("VTK_DEFAULT_EGL_DEVICE_INDEX");
   if (EGLDefaultDeviceIndexEnv)
   {
-    // If parsing the environment variable fails and throws an exception we
-    // can safely ignore it since a default is already set above.
     try
     {
-      this->DeviceIndex = atoi(EGLDefaultDeviceIndexEnv);
+      int index = atoi(EGLDefaultDeviceIndexEnv);
+      if (index >= 0)
+      {
+        vtkEGLDisplayInitializationHelper::DefaultDeviceIndex = index;
+      }
+    }
+    catch (const std::out_of_range&)
+    {
+    }
+    catch (const std::invalid_argument&)
+    {
+    }
+  }
+
+  // If the device index is explicitly set then we need to use it.
+  char* EGLDeviceIndexEnv = std::getenv("VTK_EGL_DEVICE_INDEX");
+  if (EGLDeviceIndexEnv)
+  {
+    try
+    {
+      int index = atoi(EGLDeviceIndexEnv);
+      if (index >= 0)
+      {
+        this->DeviceIndex = index;
+      }
     }
     catch (const std::out_of_range&)
     {
@@ -170,6 +192,16 @@ vtkEGLRenderWindow::vtkEGLRenderWindow()
 
   this->IsPointSpriteBugTested = false;
   this->IsPointSpriteBugPresent_ = false;
+
+  auto loadFunc = [](void*, const char* name) -> VTKOpenGLAPIProc
+  {
+    if (name)
+    {
+      return eglGetProcAddress(name);
+    }
+    return nullptr;
+  };
+  this->SetOpenGLSymbolLoader(loadFunc, nullptr);
 }
 
 // free up memory & close the window
@@ -282,10 +314,13 @@ int vtkEGLRenderWindow::GetNumberOfDevices()
   return 0;
 }
 
-void vtkEGLRenderWindow::SetDeviceAsDisplay(int deviceIndex)
+bool vtkEGLRenderWindow::SetDeviceAsDisplay(int deviceIndex)
 {
   vtkInternals* impl = this->Internals;
   vtkEGLDeviceExtensions* ext = vtkEGLDeviceExtensions::GetInstance();
+  bool foundWorkingDisplay = false;
+  EGLint major = 0, minor = 0;
+
   if (ext->Available())
   {
     EGLint num_devices = 0;
@@ -295,37 +330,103 @@ void vtkEGLRenderWindow::SetDeviceAsDisplay(int deviceIndex)
       vtkWarningMacro("EGL device index: " << deviceIndex
                                            << " is greater than "
                                               "the number of supported deviced in the system: "
-                                           << num_devices << ". Using device 0 ...");
-      return;
+                                           << num_devices);
+    }
+
+    std::vector<EGLDeviceEXT> devices(num_devices);
+    ext->eglQueryDevices(num_devices, devices.data(), &num_devices);
+
+    if (deviceIndex >= 0)
+    {
+      impl->Display =
+        ext->eglGetPlatformDisplay(EGL_PLATFORM_DEVICE_EXT, devices[deviceIndex], nullptr);
+
+      if (vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor) == EGL_FALSE)
+      {
+        vtkWarningMacro(
+          "EGL device index: " << deviceIndex << " could not be initialized. Exiting...");
+      }
+
+      foundWorkingDisplay = true;
+    }
+    else
+    {
+      impl->Display = ext->eglGetPlatformDisplay(EGL_PLATFORM_DEVICE_EXT,
+        devices[vtkEGLDisplayInitializationHelper::DefaultDeviceIndex], nullptr);
+
+      if (vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor) == EGL_FALSE)
+      {
+        vtkWarningMacro(
+          "EGL device index: " << vtkEGLDisplayInitializationHelper::DefaultDeviceIndex
+                               << " could not be initialized. Trying other devices...");
+
+        for (int i = 0; i < num_devices; i++)
+        {
+          // Don't check DefaultDeviceIndex again
+          if (i == vtkEGLDisplayInitializationHelper::DefaultDeviceIndex)
+          {
+            continue;
+          }
+
+          impl->Display = ext->eglGetPlatformDisplay(EGL_PLATFORM_DEVICE_EXT, devices[i], nullptr);
+          if (vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor) ==
+            EGL_TRUE)
+          {
+            foundWorkingDisplay = true;
+            break;
+          }
+        }
+      }
+      else
+      {
+        foundWorkingDisplay = true;
+      }
     }
-    EGLDeviceEXT* devices = new EGLDeviceEXT[num_devices];
-    ext->eglQueryDevices(num_devices, devices, &num_devices);
-    impl->Display =
-      ext->eglGetPlatformDisplay(EGL_PLATFORM_DEVICE_EXT, devices[deviceIndex], nullptr);
-    delete[] devices;
-    return;
   }
-  vtkWarningMacro("Setting an EGL display to device index: "
-    << deviceIndex
-    << " require "
-       "EGL_EXT_device_base EGL_EXT_platform_device EGL_EXT_platform_base extensions");
+
+  if (!foundWorkingDisplay)
+  {
+    // eglGetDisplay(EGL_DEFAULT_DISPLAY) does not seem to work
+    // if there are several cards on a system.
+    vtkWarningMacro("Setting an EGL display to device index: "
+      << deviceIndex
+      << " require "
+         "EGL_EXT_device_base EGL_EXT_platform_device EGL_EXT_platform_base extensions");
+
+    vtkWarningMacro("Attempting to use EGL_DEFAULT_DISPLAY...");
+    impl->Display = eglGetDisplay(EGL_DEFAULT_DISPLAY);
+
+    if (vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor) == EGL_FALSE)
+    {
+      vtkWarningMacro("Could not initialize a device. Exiting...");
+      return false;
+    }
+  }
+#if !defined(__ANDROID__) && !defined(ANDROID)
+  if (major <= 1 && minor < 4)
+  {
+    vtkWarningMacro("Only EGL 1.4 and greater allows OpenGL as client API. "
+                    "See eglBindAPI for more information.");
+    return false;
+  }
+  // Loads EGL functions that are supported by this display.
+  gladLoaderLoadEGL(impl->Display);
+  impl->EGLInitialized = true;
+  eglBindAPI(EGL_OPENGL_API);
+#endif
+
+  return true;
 }
 
 void vtkEGLRenderWindow::SetShowWindow(bool val)
 {
-  if (val == this->ShowWindow)
+#if !defined(__ANDROID__) && !defined(ANDROID)
+  if (val)
   {
-    return;
+    vtkWarningMacro("vtkEGLRenderWindow does not support showing the window onscreen");
   }
-
-#if defined(VTK_USE_OFFSCREEN_EGL)
-  if (!val)
-  {
-    this->Superclass::SetShowWindow(val);
-  }
-#else
-  this->Superclass::SetShowWindow(val);
 #endif
+  this->Superclass::SetShowWindow(val);
 }
 
 void vtkEGLRenderWindow::ResizeWindow(int width, int height)
@@ -338,7 +439,7 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
    */
   EGLint surfaceType, clientAPI;
   const EGLint* contextAttribs;
-#ifdef ANDROID
+#if defined(__ANDROID__) || defined(ANDROID)
   surfaceType = EGL_WINDOW_BIT;
   clientAPI = EGL_OPENGL_ES2_BIT;
   const EGLint contextES2[] = { EGL_CONTEXT_CLIENT_VERSION, 2, EGL_NONE };
@@ -354,7 +455,7 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
     EGL_RED_SIZE, 8, EGL_ALPHA_SIZE, 8, EGL_DEPTH_SIZE, 8, EGL_RENDERABLE_TYPE, clientAPI,
     EGL_NONE };
 
-#if !defined(ANDROID)
+#if !defined(__ANDROID__) && !defined(ANDROID)
   const EGLint surface_attribs[] = { EGL_WIDTH, width, EGL_HEIGHT, height, EGL_NONE };
 #endif
 
@@ -363,27 +464,10 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
 
   if (impl->Display == EGL_NO_DISPLAY)
   {
-    // eglGetDisplay(EGL_DEFAULT_DISPLAY) does not seem to work
-    // if there are several cards on a system.
-    this->SetDeviceAsDisplay(this->DeviceIndex);
-
-    // try to use the default display
-    if (impl->Display == EGL_NO_DISPLAY)
+    if (!this->SetDeviceAsDisplay(this->DeviceIndex))
     {
-      impl->Display = eglGetDisplay(EGL_DEFAULT_DISPLAY);
-    }
-
-    EGLint major = 0, minor = 0;
-    vtkEGLDisplayInitializationHelper::Initialize(impl->Display, &major, &minor);
-#if !defined(ANDROID)
-    if (major <= 1 && minor < 4)
-    {
-      vtkErrorMacro("Only EGL 1.4 and greater allows OpenGL as client API. "
-                    "See eglBindAPI for more information.");
       return;
     }
-    eglBindAPI(EGL_OPENGL_API);
-#endif
   }
 
   /* Here, the application chooses the configuration it desires. In this
@@ -392,11 +476,11 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
   eglChooseConfig(impl->Display, configs, &config, 1, &numConfigs);
   if (numConfigs == 0)
   {
-    vtkErrorMacro("No matching EGL configuration found.");
+    vtkWarningMacro("No matching EGL configuration found.");
     return;
   }
 
-#ifdef ANDROID
+#if defined(__ANDROID__) || defined(ANDROID)
   EGLint format = 0;
   /* EGL_NATIVE_VISUAL_ID is an attribute of the EGLConfig that is
    * guaranteed to be accepted by ANativeWindow_setBuffersGeometry().
@@ -417,13 +501,22 @@ void vtkEGLRenderWindow::ResizeWindow(int width, int height)
     eglDestroySurface(impl->Display, impl->Surface);
   }
 
-#ifdef ANDROID
+#if defined(__ANDROID__) || defined(ANDROID)
   impl->Surface = eglCreateWindowSurface(impl->Display, config, impl->Window, nullptr);
 #else
   impl->Surface = eglCreatePbufferSurface(impl->Display, config, surface_attribs);
 #endif
   this->Mapped = this->ShowWindow;
-  this->OwnWindow = 1;
+  this->OwnWindow = true;
+
+#if defined(__ANDROID__) || defined(ANDROID)
+  vtkAndroidRenderWindowInteractor* interactor =
+    vtkAndroidRenderWindowInteractor::SafeDownCast(this->Interactor);
+  if (interactor)
+  {
+    interactor->SetOwnWindow(this->OwnWindow);
+  }
+#endif
 
   this->MakeCurrent();
 
@@ -455,11 +548,12 @@ void vtkEGLRenderWindow::DestroyWindow()
     }
     vtkEGLDisplayInitializationHelper::Terminate(impl->Display);
     impl->Display = EGL_NO_DISPLAY;
+    impl->EGLInitialized = false;
   }
 }
 
 // Initialize the window for rendering.
-void vtkEGLRenderWindow::WindowInitialize(void)
+void vtkEGLRenderWindow::WindowInitialize()
 {
   vtkInternals* impl = this->Internals;
   if (this->OwnWindow)
@@ -478,30 +572,41 @@ void vtkEGLRenderWindow::WindowInitialize(void)
   vtkRenderer* ren;
   for (this->Renderers->InitTraversal(); (ren = this->Renderers->GetNextItem());)
   {
-    ren->SetRenderWindow(0);
+    ren->SetRenderWindow(nullptr);
     ren->SetRenderWindow(this);
   }
 
   this->OpenGLInit();
 
   // for offscreen EGL always turn on point sprites
-#if !defined(ANDROID) && defined(GL_POINT_SPRITE)
-  glEnable(GL_POINT_SPRITE);
+#if !defined(__ANDROID__) && !defined(ANDROID) && defined(GL_POINT_SPRITE)
+  if (this->Initialized)
+  {
+    glEnable(GL_POINT_SPRITE);
+  }
+#endif
+
+#if defined(__ANDROID__) || defined(ANDROID)
+  vtkAndroidRenderWindowInteractor* interactor =
+    vtkAndroidRenderWindowInteractor::SafeDownCast(this->Interactor);
+  if (interactor)
+  {
+    interactor->SetOwnWindow(this->OwnWindow);
+  }
 #endif
 }
 
 // Initialize the rendering window.
-void vtkEGLRenderWindow::Initialize(void)
+void vtkEGLRenderWindow::Initialize()
 {
   vtkInternals* impl = this->Internals;
   if (impl->Context == EGL_NO_CONTEXT)
   {
     this->WindowInitialize();
   }
-  this->Initialized = true;
 }
 
-void vtkEGLRenderWindow::Finalize(void)
+void vtkEGLRenderWindow::Finalize()
 {
   // clean and destroy window
   this->DestroyWindow();
@@ -572,7 +677,16 @@ void vtkEGLRenderWindow::MakeCurrent()
   }
 }
 
-// ----------------------------------------------------------------------------
+void vtkEGLRenderWindow::ReleaseCurrent()
+{
+  vtkInternals* impl = this->Internals;
+  if (impl->Display != EGL_NO_DISPLAY)
+  {
+    eglMakeCurrent(impl->Display, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
+  }
+}
+
+//------------------------------------------------------------------------------
 // Description:
 // Tells if this window is the current OpenGL context for the calling thread.
 bool vtkEGLRenderWindow::IsCurrent()
@@ -589,7 +703,7 @@ int* vtkEGLRenderWindow::GetScreenSize()
 }
 
 // Get the position in screen coordinates (pixels) of the window.
-int* vtkEGLRenderWindow::GetPosition(void)
+int* vtkEGLRenderWindow::GetPosition()
 {
   return this->Position;
 }
@@ -608,8 +722,17 @@ void vtkEGLRenderWindow::SetPosition(int x, int y)
 // Set this RenderWindow to a pre-existing window.
 void vtkEGLRenderWindow::SetWindowInfo(const char*)
 {
-  this->OwnWindow = 0;
   this->Mapped = 1;
+  this->OwnWindow = false;
+
+#if defined(__ANDROID__) || defined(ANDROID)
+  vtkAndroidRenderWindowInteractor* interactor =
+    vtkAndroidRenderWindowInteractor::SafeDownCast(this->Interactor);
+  if (interactor)
+  {
+    interactor->SetOwnWindow(this->OwnWindow);
+  }
+#endif
 }
 
 void vtkEGLRenderWindow::SetWindowName(const char* name)
@@ -623,27 +746,27 @@ void vtkEGLRenderWindow::Render()
   this->vtkOpenGLRenderWindow::Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEGLRenderWindow::HideCursor() {}
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEGLRenderWindow::ShowCursor() {}
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void* vtkEGLRenderWindow::GetGenericDisplayId()
 {
   vtkInternals* impl = this->Internals;
   return impl->Display;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void* vtkEGLRenderWindow::GetGenericContext()
 {
   vtkInternals* impl = this->Internals;
   return impl->Context;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkEGLRenderWindow::IsPointSpriteBugPresent()
 {
   // eventually we'll want to check with the NVIDIA EGL version to see if the
@@ -664,9 +787,56 @@ bool vtkEGLRenderWindow::IsPointSpriteBugPresent()
   return this->IsPointSpriteBugPresent_;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEGLRenderWindow::SetWindowId(void* window)
 {
   vtkInternals* impl = this->Internals;
   impl->Window = reinterpret_cast<EGLNativeWindowType>(window);
 }
+
+//------------------------------------------------------------------------------
+const char* vtkEGLRenderWindow::ReportCapabilities()
+{
+  this->MakeCurrent();
+
+  auto& internals = (*this->Internals);
+  if (!internals.Display)
+  {
+    return "Display ID not set";
+  }
+  const char* eglVersion = eglQueryString(internals.Display, EGL_VERSION);
+  const char* eglVendor = eglQueryString(internals.Display, EGL_VENDOR);
+  const char* eglClientAPIs = eglQueryString(internals.Display, EGL_CLIENT_APIS);
+  const char* eglExtensions = eglQueryString(internals.Display, EGL_EXTENSIONS);
+  const char* glVendor = reinterpret_cast<const char*>(glGetString(GL_VENDOR));
+  const char* glRenderer = reinterpret_cast<const char*>(glGetString(GL_RENDERER));
+  const char* glVersion = reinterpret_cast<const char*>(glGetString(GL_VERSION));
+
+  std::ostringstream strm;
+  strm << "EGL version string:  " << eglVersion << endl;
+  strm << "EGL vendor string:  " << eglVendor << endl;
+  strm << "EGL client APIs:  " << eglClientAPIs << endl;
+  strm << "EGL extensions:  " << eglExtensions << endl;
+  strm << "OpenGL vendor string:  " << glVendor << endl;
+  strm << "OpenGL renderer string:  " << glRenderer << endl;
+  strm << "OpenGL version string:  " << glVersion << endl;
+  strm << "OpenGL extensions:  " << endl;
+  int n = 0;
+  glGetIntegerv(GL_NUM_EXTENSIONS, &n);
+  for (int i = 0; i < n; i++)
+  {
+    const char* ext = (const char*)glGetStringi(GL_EXTENSIONS, i);
+    strm << "  " << ext << endl;
+  }
+  delete[] this->Capabilities;
+
+  const auto capsString = strm.str();
+  size_t len = capsString.length();
+  this->Capabilities = new char[len + 1];
+  strncpy(this->Capabilities, capsString.c_str(), len);
+  this->Capabilities[len] = 0;
+
+  return this->Capabilities;
+}
+
+VTK_ABI_NAMESPACE_END
