@@ -1,17 +1,5 @@
-/*=========================================================================
-
-Program:   Visualization Toolkit
-Module:    vtkIOSRenderWindow.mm
-
-Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-All rights reserved.
-See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkOpenGLRenderWindow.h"
 
@@ -19,13 +7,16 @@ PURPOSE.  See the above copyright notice for more information.
 #import "vtkIOSRenderWindow.h"
 #import "vtkIdList.h"
 #import "vtkObjectFactory.h"
+#import "vtkOpenGLFramebufferObject.h"
+#import "vtkOpenGLState.h"
 #import "vtkRenderWindowInteractor.h"
 #import "vtkRendererCollection.h"
 
 #import <sstream>
 
-#include "vtk_glew.h"
+#include "vtk_glad.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkIOSRenderWindow);
 
 //----------------------------------------------------------------------------
@@ -38,12 +29,27 @@ vtkIOSRenderWindow::vtkIOSRenderWindow()
   this->ForceMakeCurrent = 0;
   this->OnScreenInitialized = 0;
   this->OffScreenInitialized = 0;
-  // it seems that LEFT/RIGHT cause issues on IOS so we just use
-  // generic BACK/FRONT
-  this->BackLeftBuffer = static_cast<unsigned int>(GL_BACK);
-  this->BackRightBuffer = static_cast<unsigned int>(GL_BACK);
-  this->FrontLeftBuffer = static_cast<unsigned int>(GL_FRONT);
-  this->FrontRightBuffer = static_cast<unsigned int>(GL_FRONT);
+  this->SetFrameBlitModeToBlitToCurrent();
+}
+
+void vtkIOSRenderWindow::BlitDisplayFramebuffersToHardware()
+{
+  auto ostate = this->GetState();
+  ostate->PushFramebufferBindings();
+  this->DisplayFramebuffer->Bind(GL_READ_FRAMEBUFFER);
+  this->GetState()->vtkglViewport(0, 0, this->Size[0], this->Size[1]);
+  this->GetState()->vtkglScissor(0, 0, this->Size[0], this->Size[1]);
+
+  this->GetState()->vtkglBindFramebuffer(GL_DRAW_FRAMEBUFFER, 0);
+
+  this->DisplayFramebuffer->ActivateReadBuffer(0);
+  this->GetState()->vtkglDrawBuffer(this->DoubleBuffer ? GL_BACK : GL_FRONT);
+
+  // recall Blit upper right corner is exclusive of the range
+  this->GetState()->vtkglBlitFramebuffer(0, 0, this->Size[0], this->Size[1], 0, 0, this->Size[0],
+    this->Size[1], GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT, GL_NEAREST);
+
+  this->GetState()->PopFramebufferBindings();
 }
 
 //----------------------------------------------------------------------------
@@ -156,16 +162,6 @@ vtkTypeBool vtkIOSRenderWindow::GetEventPending()
   return 0;
 }
 
-//----------------------------------------------------------------------------
-// Initialize the rendering process.
-void vtkIOSRenderWindow::Start()
-{
-  this->Initialize();
-
-  // set the current window
-  this->MakeCurrent();
-}
-
 //----------------------------------------------------------------------------
 void vtkIOSRenderWindow::MakeCurrent()
 {
@@ -183,18 +179,6 @@ bool vtkIOSRenderWindow::IsCurrent()
   return true;
 }
 
-//----------------------------------------------------------------------------
-#ifndef VTK_LEGACY_REMOVE
-bool vtkIOSRenderWindow::IsDrawable()
-{
-  // you must initialize it first
-  // else it always evaluates false
-  this->Initialize();
-
-  return true;
-}
-#endif
-
 //----------------------------------------------------------------------------
 void vtkIOSRenderWindow::UpdateContext() {}
 
@@ -560,3 +544,4 @@ void vtkIOSRenderWindow::SetCurrentCursor(int shape)
   }
   this->Superclass::SetCurrentCursor(shape);
 }
+VTK_ABI_NAMESPACE_END
