@@ -10,6 +10,7 @@
 #include "vtkCompositeDataSetRange.h"
 #include "vtkDataObjectTree.h"
 #include "vtkDataObjectTreeIterator.h"
+#include "vtkDataObjectTreeRange.h"
 #include "vtkHardwareSelector.h"
 #include "vtkMath.h"
 #include "vtkMatrix3x3.h"
@@ -97,7 +98,7 @@ public:
   {
     this->NumberOfPoints = 0;
     this->DataObject = nullptr;
-  };
+  }
   ~vtkOpenGLGlyph3DMapperEntry()
   {
     this->ClearMappers();
@@ -105,7 +106,7 @@ public:
     {
       this->DataObject->Delete();
     }
-  };
+  }
   void ClearMappers()
   {
     for (MapperMap::iterator it = this->Mappers.begin(); it != this->Mappers.end(); ++it)
@@ -122,7 +123,7 @@ public:
   std::vector<vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry*> Entries;
   vtkTimeStamp BuildTime;
   vtkOpenGLGlyph3DMapperSubArray() = default;
-  ~vtkOpenGLGlyph3DMapperSubArray() { this->ClearEntries(); };
+  ~vtkOpenGLGlyph3DMapperSubArray() { this->ClearEntries(); }
   void ClearEntries()
   {
     std::vector<vtkOpenGLGlyph3DMapper::vtkOpenGLGlyph3DMapperEntry*>::iterator miter =
@@ -148,7 +149,7 @@ public:
       delete miter->second;
     }
     this->Entries.clear();
-  };
+  }
 };
 
 vtkStandardNewMacro(vtkOpenGLGlyph3DMapper);
@@ -219,6 +220,100 @@ void vtkOpenGLGlyph3DMapper::SetupColorMapper()
   this->ColorMapper->ShallowCopy(this);
 }
 
+//------------------------------------------------------------------------------
+void vtkOpenGLGlyph3DMapper::RenderChildren(
+  vtkRenderer* renderer, vtkActor* actor, vtkDataObject* dobj, unsigned int& flatIndex)
+{
+  // Push overridden attributes onto the stack.
+  // Keep track of attributes that were pushed so that they can be popped after they're applied to
+  // the batch element.
+  vtkCompositeDataDisplayAttributes* cda = this->BlockAttributes;
+  bool overrides_visibility = (cda && cda->HasBlockVisibility(dobj));
+  if (overrides_visibility)
+  {
+    this->BlockState.Visibility.push(cda->GetBlockVisibility(dobj));
+  }
+  bool overrides_pickability = (cda && cda->HasBlockPickability(dobj));
+  if (overrides_pickability)
+  {
+    this->BlockState.Pickability.push(cda->GetBlockPickability(dobj));
+  }
+  bool overrides_opacity = (cda && cda->HasBlockOpacity(dobj));
+  if (overrides_opacity)
+  {
+    this->BlockState.Opacity.push(cda->GetBlockOpacity(dobj));
+  }
+  bool overrides_color = (cda && cda->HasBlockColor(dobj));
+  if (overrides_color)
+  {
+    vtkColor3d color = cda->GetBlockColor(dobj);
+    this->BlockState.Color.push(color);
+  }
+  // Advance flat-index. After this point, flatIndex no longer points to this
+  // block.
+  const auto originalFlatIndex = flatIndex;
+  flatIndex++;
+
+  if (auto dObjTree = vtkDataObjectTree::SafeDownCast(dobj))
+  {
+    using Opts = vtk::DataObjectTreeOptions;
+    for (vtkDataObject* child : vtk::Range(dObjTree, Opts::None))
+    {
+      if (!child)
+      {
+        ++flatIndex;
+      }
+      else
+      {
+        this->RenderChildren(renderer, actor, child, flatIndex);
+      }
+    }
+  }
+  else
+  {
+    auto ds = vtkDataSet::SafeDownCast(dobj);
+    // Skip invisible blocks and unpickable ones when performing selection:
+    bool blockVis = this->BlockState.Visibility.top();
+    bool blockPick = this->BlockState.Pickability.top();
+    auto selector = renderer->GetSelector();
+    bool skip = (!blockVis || (selector && !blockPick));
+    if (!skip)
+    {
+      if (ds)
+      {
+        if (selector)
+        {
+          selector->RenderCompositeIndex(originalFlatIndex);
+        }
+        actor->GetProperty()->SetColor(this->BlockState.Color.top().GetData());
+        actor->GetProperty()->SetOpacity(this->BlockState.Opacity.top());
+        this->Render(renderer, actor, ds);
+      }
+      else
+      {
+        vtkErrorMacro(<< "Expected a vtkDataObjectTree or vtkDataSet input. Got "
+                      << dobj->GetClassName());
+      }
+    }
+  }
+  if (overrides_color)
+  {
+    this->BlockState.Color.pop();
+  }
+  if (overrides_opacity)
+  {
+    this->BlockState.Opacity.pop();
+  }
+  if (overrides_pickability)
+  {
+    this->BlockState.Pickability.pop();
+  }
+  if (overrides_visibility)
+  {
+    this->BlockState.Visibility.pop();
+  }
+}
+
 //------------------------------------------------------------------------------
 // Description:
 // Method initiates the mapping process. Generally sent by the actor
@@ -327,45 +422,20 @@ void vtkOpenGLGlyph3DMapper::Render(vtkRenderer* ren, vtkActor* actor)
     double origColor[4];
     blockProp->GetColor(origColor);
 
-    using Opts = vtk::CompositeDataSetOptions;
-    for (auto node : vtk::Range(cd, Opts::SkipEmptyNodes))
-    {
-      auto curIndex = node.GetFlatIndex();
-      auto currentObj = node.GetDataObject();
+    // Push base-values on the state stack.
+    this->BlockState.Visibility.push(true);
+    this->BlockState.Pickability.push(true);
+    this->BlockState.Opacity.push(blockProp->GetOpacity());
+    this->BlockState.Color.emplace(origColor);
 
-      // Skip invisible blocks and unpickable ones when performing selection:
-      bool blockVis =
-        (this->BlockAttributes && this->BlockAttributes->HasBlockVisibility(currentObj))
-        ? this->BlockAttributes->GetBlockVisibility(currentObj)
-        : true;
-      bool blockPick =
-        (this->BlockAttributes && this->BlockAttributes->HasBlockPickability(currentObj))
-        ? this->BlockAttributes->GetBlockPickability(currentObj)
-        : true;
-      if (!blockVis || (selector && !blockPick))
-      {
-        continue;
-      }
-      ds = vtkDataSet::SafeDownCast(currentObj);
-      if (ds)
-      {
-        if (selector)
-        {
-          selector->RenderCompositeIndex(curIndex);
-        }
-        else if (this->BlockAttributes && this->BlockAttributes->HasBlockColor(currentObj))
-        {
-          double color[3];
-          this->BlockAttributes->GetBlockColor(currentObj, color);
-          blockProp->SetColor(color);
-        }
-        else
-        {
-          blockProp->SetColor(origColor);
-        }
-        this->Render(ren, blockAct.GetPointer(), ds);
-      }
-    }
+    unsigned int flatIndex = 0;
+    this->RenderChildren(ren, blockAct, cd, flatIndex);
+
+    // Pop base-values from the state stack.
+    this->BlockState.Visibility.pop();
+    this->BlockState.Pickability.pop();
+    this->BlockState.Opacity.pop();
+    this->BlockState.Color.pop();
   }
 
   if (selector)
@@ -730,7 +800,8 @@ void vtkOpenGLGlyph3DMapper::RebuildStructures(
     }
 
     // source can be null.
-    vtkDataObject* source = sourceCache[index];
+    vtkDataObject* source =
+      index < static_cast<int>(sourceCache.size()) ? sourceCache[index] : nullptr;
 
     // Make sure we're not indexing into empty glyph
     if (source)
@@ -972,7 +1043,7 @@ void vtkOpenGLGlyph3DMapper::ReleaseGraphicsResources(vtkWindow* window)
 vtkIdType vtkOpenGLGlyph3DMapper::GetMaxNumberOfLOD()
 {
 #ifndef GL_ES_VERSION_3_0
-  if (!GLEW_ARB_gpu_shader5 || !GLEW_ARB_transform_feedback3)
+  if (!GLAD_GL_ARB_gpu_shader5 || !GLAD_GL_ARB_transform_feedback3)
   {
     return 0;
   }
