@@ -1,13 +1,14 @@
 // SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 // SPDX-License-Identifier: BSD-3-Clause
 #include "vtkOpenGLRenderWindow.h"
-#include "vtk_glew.h"
+#include "vtk_glad.h"
 
 #include "vtkOpenGLHelper.h"
 
 #include "vtkFloatArray.h"
 #include "vtkImageData.h"
 #include "vtkJPEGReader.h"
+#include "vtkLogger.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkOpenGLActor.h"
@@ -29,6 +30,7 @@
 #include "vtkPerlinNoise.h"
 #include "vtkRenderTimerLog.h"
 #include "vtkRendererCollection.h"
+#include "vtkRenderingOpenGLConfigure.h"
 #include "vtkShaderProgram.h"
 #include "vtkStringOutputWindow.h"
 #include "vtkTextureObject.h"
@@ -36,10 +38,28 @@
 #include "vtkTimerLog.h"
 #include "vtkUnsignedCharArray.h"
 
+#if defined(_WIN32)
+#include "vtkWin32OpenGLRenderWindow.h"
+#endif
+#if defined(VTK_USE_X)
+#include "vtkXOpenGLRenderWindow.h"
+#include "vtkglad/include/glad/glx.h"
+#endif
+#if defined(VTK_OPENGL_HAS_EGL)
+#include "vtkEGLRenderWindow.h"
+#include "vtkglad/include/glad/egl.h"
+#endif
+#include "vtkOSOpenGLRenderWindow.h"
+
+#include "vtksys/SystemTools.hxx"
+
 #include "BlueNoiseTexture64x64.h"
 #include "vtkTextureObjectVS.h" // a pass through shader
 
+#include <cstdlib>
+#include <cstring>
 #include <sstream>
+#include <string>
 #include <type_traits>
 using std::ostringstream;
 
@@ -75,13 +95,18 @@ static const vtkOpenGLRenderWindowDriverInfo vtkOpenGLRenderWindowMSAATextureBug
   // OpenGL Version: 4.6 (Core Profile) Mesa 20.0.8
   // OpenGL Renderer: AMD RAVEN (DRM 3.35.0, 5.4.0-42-generic, LLVM 10.0.0)
   { "X.Org", "", "AMD" },
+
+  // xref https://gitlab.freedesktop.org/mesa/mesa/-/issues/11999
+  // OpenGL Vendor: Mesa
+  // OpenGL Version: 4.3 (Core Profile) Mesa 24.0.9-0ubuntu0.1
+  // OpenGL Renderer: NV137
+  { "Mesa", "", "NV" },
 };
 
-const char* defaultWindowName = "Visualization Toolkit - OpenGL";
+static const char* defaultWindowName = "Visualization Toolkit - OpenGL";
 
-const char* ResolveShader =
-  R"***(
-  //VTK::System::Dec
+static const char* ResolveShader =
+  R"***(//VTK::System::Dec
   in vec2 texCoord;
   uniform sampler2DMS tex;
   uniform int samplecount;
@@ -98,10 +123,10 @@ const char* ResolveShader =
 
     for (int i = 0; i < samplecount; i++)
     {
-      vec4 sample = texelFetch(tex, itexcoords, i);
+      vec4 sampleValue = texelFetch(tex, itexcoords, i);
       // apply gamma correction and sum
-      accumulate += pow(sample.rgb, vec3(gamma));
-      alpha += sample.a;
+      accumulate += pow(sampleValue.rgb, vec3(gamma));
+      alpha += sampleValue.a;
     }
 
     // divide and reverse gamma correction
@@ -110,9 +135,8 @@ const char* ResolveShader =
   }
   )***";
 
-const char* DepthBlitShader =
-  R"***(
-  //VTK::System::Dec
+static const char* DepthBlitShader =
+  R"***(//VTK::System::Dec
   in vec2 texCoord;
   uniform sampler2D tex;
   uniform vec2 texLL;
@@ -125,7 +149,7 @@ const char* DepthBlitShader =
   }
   )***";
 
-const char* DepthReadShader =
+static const char* DepthReadShader =
   R"***(//VTK::System::Dec
   in vec2 texCoord;
   uniform sampler2D tex;
@@ -156,9 +180,8 @@ const char* DepthReadShader =
   }
   )***";
 
-const char* FlipShader =
-  R"***(
-  //VTK::System::Dec
+static const char* FlipShader =
+  R"***(//VTK::System::Dec
   in vec2 texCoord;
   uniform sampler2D tex;
   //VTK::Output::Dec
@@ -169,6 +192,106 @@ const char* FlipShader =
   }
   )***";
 
+#if defined(VTK_REPORT_OPENGL_ERRORS) && defined(GLAD_GL)
+static void GLAPIENTRY vtkOpenGLMessageHandler(GLenum source, GLenum type, GLuint id,
+  GLenum severity, GLsizei /*length*/, const GLchar* message, const void* /*userParam*/)
+{
+  std::string messageType;
+  switch (type)
+  {
+    case GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR:
+      messageType = "DEPRECATED_BEHAVIOR";
+      break;
+    case GL_DEBUG_TYPE_ERROR:
+      messageType = "ERROR";
+      break;
+    case GL_DEBUG_TYPE_MARKER:
+      messageType = "MARKER";
+      break;
+    case GL_DEBUG_TYPE_OTHER:
+      messageType = "OTHER";
+      break;
+    case GL_DEBUG_TYPE_PERFORMANCE:
+      messageType = "PERFORMANCE";
+      break;
+    case GL_DEBUG_TYPE_POP_GROUP:
+      messageType = "POP_GROUP";
+      break;
+    case GL_DEBUG_TYPE_PORTABILITY:
+      messageType = "PORTABILITY";
+      break;
+    case GL_DEBUG_TYPE_PUSH_GROUP:
+      messageType = "PUSH_GROUP";
+      break;
+    case GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR:
+      messageType = "UNDEFINED_BEHAVIOR";
+      break;
+    default:
+      messageType = "UNKNOWN";
+      break;
+  }
+  std::string messageSeverity;
+  switch (severity)
+  {
+    case GL_DEBUG_SEVERITY_HIGH:
+      messageSeverity = "HIGH";
+      break;
+    case GL_DEBUG_SEVERITY_LOW:
+      messageSeverity = "LOW";
+      break;
+    case GL_DEBUG_SEVERITY_MEDIUM:
+      messageSeverity = "MEDIUM";
+      break;
+    case GL_DEBUG_SEVERITY_NOTIFICATION:
+      messageSeverity = "NOTIFICATION";
+      break;
+    default:
+      messageSeverity = "UNKNOWN";
+      break;
+  }
+
+  std::string sourceType;
+  switch (source)
+  {
+    case GL_DEBUG_SOURCE_API:
+      sourceType = "SOURCE_API";
+      break;
+    case GL_DEBUG_SOURCE_APPLICATION:
+      sourceType = "SOURCE_APPLICATION";
+      break;
+    case GL_DEBUG_SOURCE_OTHER:
+      sourceType = "SOURCE_OTHER";
+      break;
+    case GL_DEBUG_SOURCE_SHADER_COMPILER:
+      sourceType = "SOURCE_SHADER_COMPILER";
+      break;
+    case GL_DEBUG_SOURCE_THIRD_PARTY:
+      sourceType = "SOURCE_THIRD_PARTY";
+      break;
+    case GL_DEBUG_SOURCE_WINDOW_SYSTEM:
+      sourceType = "SOURCE_WINDOW_SYSTEM";
+      break;
+    default:
+      sourceType = "UNKNOWN";
+      break;
+  }
+
+  std::ostringstream oss;
+  oss << "GL Message: id=" << id << " source=" << sourceType << "(0x" << std::hex << source << ")"
+      << std::dec << " type=" << messageType << "(0x" << std::hex << type << std::dec << ")"
+      << " severity=" << messageSeverity << "(0x" << std::hex << severity << std::dec << ")"
+      << " message=" << message;
+  if (severity == GL_DEBUG_SEVERITY_HIGH)
+  {
+    vtkLog(WARNING, << oss.str());
+  }
+  else
+  {
+    vtkLog(TRACE, << oss.str());
+  }
+}
+#endif
+
 #ifdef GL_ES_VERSION_3_0
 namespace
 {
@@ -395,9 +518,11 @@ vtkOpenGLRenderWindow::vtkOpenGLRenderWindow()
   this->FramebufferFlipY = false;
 
   this->Initialized = false;
-  this->GlewInitValid = false;
 
-  this->MultiSamples = vtkOpenGLRenderWindowGlobalMaximumNumberOfMultiSamples;
+  this->MultiSamples = vtksys::SystemTools::HasEnv("VTK_TESTING")
+    ? 0
+    : vtkOpenGLRenderWindowGlobalMaximumNumberOfMultiSamples;
+
   delete[] this->WindowName;
   this->WindowName = new char[strlen(defaultWindowName) + 1];
   strcpy(this->WindowName, defaultWindowName);
@@ -424,6 +549,7 @@ vtkOpenGLRenderWindow::vtkOpenGLRenderWindow()
   // this->DepthRenderBufferObject = 0;
   this->AlphaBitPlanes = 8;
   this->Capabilities = nullptr;
+  this->RenderBufferTargetDepthSize = 32;
 
   this->TQuad2DVBO = nullptr;
   this->NoiseTextureObject = nullptr;
@@ -483,6 +609,74 @@ vtkOpenGLRenderWindow::~vtkOpenGLRenderWindow()
   this->State->Delete();
 }
 
+#if !(defined(__APPLE__) || defined(__ANDROID__) || defined(__EMSCRIPTEN__))
+//------------------------------------------------------------------------------
+vtkOpenGLRenderWindow* vtkOpenGLRenderWindow::New()
+{
+  const char* backend = std::getenv("VTK_DEFAULT_OPENGL_WINDOW");
+#if defined(_WIN32)
+  if ((backend == nullptr) || (std::string(backend) == "vtkWin32OpenGLRenderWindow"))
+  {
+    vtkNew<vtkWin32OpenGLRenderWindow> win32RenderWindow;
+    win32RenderWindow->SetOffScreenRendering(true);
+    win32RenderWindow->Initialize();
+    if (win32RenderWindow->Initialized)
+    {
+      return win32RenderWindow->NewInstance();
+    }
+  }
+#endif
+#if defined(VTK_USE_X)
+  if ((backend == nullptr) || (std::string(backend) == "vtkXOpenGLRenderWindow"))
+  {
+    // No need to complain if GLX failed to load because vtkXOpenGLRenderWindow will
+    // print the exact reason as a warning anyway.
+    vtkNew<vtkXOpenGLRenderWindow> xRenderWindow;
+    xRenderWindow->SetOffScreenRendering(true);
+    xRenderWindow->Initialize();
+    if (xRenderWindow->Initialized)
+    {
+      return xRenderWindow->NewInstance();
+    }
+  }
+#endif
+#if defined(VTK_OPENGL_HAS_EGL)
+  if ((backend == nullptr) || (std::string(backend) == "vtkEGLRenderWindow"))
+  {
+    // Load core egl functions.
+    if (!gladLoaderLoadEGL(EGL_NO_DISPLAY))
+    {
+      vtkGenericWarningMacro(<< "Failed to load EGL! Please install the EGL library from your "
+                                "distribution's package manager.");
+    }
+    else
+    {
+      vtkNew<vtkEGLRenderWindow> eglRenderWindow;
+      eglRenderWindow->Initialize();
+      if (eglRenderWindow->Initialized)
+      {
+        return eglRenderWindow->NewInstance();
+      }
+    }
+  }
+#endif
+  if ((backend == nullptr) || (std::string(backend) == "vtkOSOpenGLRenderWindow"))
+  {
+    // OSMesa support is always built, don't check for initialization it might work if user has
+    // libOSMesa.so or osmesa.dll.
+    return vtkOSOpenGLRenderWindow::New();
+  }
+  if (backend != nullptr)
+  {
+    vtkGenericWarningMacro(<< "Failed to create a vtkOpenGLRenderWindow subclass with "
+                              "VTK_DEFAULT_OPENGL_WINDOW="
+                           << backend);
+  }
+  // OSMesa support is always built, it might work if user has libOSMesa.so or osmesa.dll.
+  return vtkOSOpenGLRenderWindow::New();
+}
+#endif
+
 //------------------------------------------------------------------------------
 const char* vtkOpenGLRenderWindow::ReportCapabilities()
 {
@@ -655,6 +849,25 @@ void vtkOpenGLRenderWindow::OpenGLInitState()
   this->SetAlphaBitPlanes(rgba[3]);
 }
 
+//------------------------------------------------------------------------------
+bool vtkOpenGLRenderWindow::IsPrimIDBugPresent()
+{
+  if (this->Initialized)
+  {
+    const char* glVendor = reinterpret_cast<const char*>(glGetString(GL_VENDOR));
+    const char* glVersion = reinterpret_cast<const char*>(glGetString(GL_VERSION));
+
+    if (!strcmp(glVendor, "Apple"))
+    {
+      if (strstr(glVersion, "Metal") != nullptr)
+      {
+        return true;
+      }
+    }
+  }
+  return false;
+}
+
 //------------------------------------------------------------------------------
 int vtkOpenGLRenderWindow::GetDefaultTextureInternalFormat(
   int vtktype, int numComponents, bool needInt, bool needFloat, bool needSRGB)
@@ -695,34 +908,55 @@ void vtkOpenGLRenderWindow::OpenGLInitContext()
   // When a new OpenGL context is created, force an update
   if (!this->Initialized)
   {
-#ifdef GLEW_OK
-    GLenum result = glewInit();
-    this->GlewInitValid = (result == GLEW_OK);
-    if (!this->GlewInitValid)
+#if defined(GLAD_GL)
+    if (this->SymbolLoader.LoadFunction != nullptr)
     {
-      const char* errorMsg = reinterpret_cast<const char*>(glewGetErrorString(result));
-      vtkErrorMacro("GLEW could not be initialized: " << errorMsg);
-      return;
+      if (gladLoadGLUserPtr(this->SymbolLoader.LoadFunction, this->SymbolLoader.UserData) > 0)
+      {
+        this->Initialized = true;
+      }
+      else
+      {
+        vtkWarningMacro(<< "Failed to initialize OpenGL functions!");
+      }
     }
-
-    if (!GLEW_VERSION_3_2 && !GLEW_VERSION_3_1)
+    else
     {
-      vtkErrorMacro("Unable to find a valid OpenGL 3.2 or later implementation. "
-                    "Please update your video card driver to the latest version. "
-                    "If you are using Mesa please make sure you have version 11.2 or "
-                    "later and make sure your driver in Mesa supports OpenGL 3.2 such "
-                    "as llvmpipe or openswr. If you are on windows and using Microsoft "
-                    "remote desktop note that it only supports OpenGL 3.2 with nvidia "
-                    "quadro cards. You can use other remoting software such as nomachine "
-                    "to avoid this issue.");
-      return;
+      if (gladLoaderLoadGL() > 0)
+      {
+        this->Initialized = true;
+      }
+      else
+      {
+        vtkWarningMacro(<< "Failed to initialize OpenGL functions!");
+      }
     }
-#else
-    // GLEW is not being used, so avoid false failure on GL checks later.
-    this->GlewInitValid = true;
-#endif
+#else // gles
     this->Initialized = true;
+#endif
+    if (!this->Initialized)
+    {
+      vtkWarningMacro(<< "Unable to find a valid OpenGL 3.2 or later implementation. "
+                         "Please update your video card driver to the latest version. "
+                         "If you are using Mesa please make sure you have version 11.2 or "
+                         "later and make sure your driver in Mesa supports OpenGL 3.2 such "
+                         "as llvmpipe or openswr. If you are on windows and using Microsoft "
+                         "remote desktop note that it only supports OpenGL 3.2 with nvidia "
+                         "quadro cards. You can use other remoting software such as nomachine "
+                         "to avoid this issue.");
+      return;
+    }
 
+    // Enable debug output if OpenGL version supports attaching debug callbacks.
+#if defined(VTK_REPORT_OPENGL_ERRORS) && defined(GLAD_GL)
+    if (GLAD_GL_ARB_debug_output)
+    {
+      glEnable(GL_DEBUG_OUTPUT);
+      glEnable(GL_DEBUG_OUTPUT_SYNCHRONOUS);
+      glDebugMessageControl(GL_DONT_CARE, GL_DONT_CARE, GL_DONT_CARE, 0, nullptr, GL_TRUE);
+      glDebugMessageCallback(vtkOpenGLMessageHandler, this);
+    }
+#endif
     // get this system's supported maximum line width
     // we do it here and store it to avoid repeated glGet
     // calls when the result should not change
@@ -865,6 +1099,15 @@ int vtkOpenGLRenderWindow::GetColorBufferSizes(int* rgba)
     {
       attachment = GL_BACK_LEFT;
     }
+    if (attachment == GL_NONE)
+    {
+      // when using vtkGenericOpenGLRenderWindow through QVTKOpenGLNativeWidget,
+      // or a subclass of QOpenGLWidget, the rendering takes place in an offscreen buffer
+      // and is then transferred to the default framebuffer object which is setup
+      // with glDrawBuffers(GL_NONE). So treat it as if it were GL_BACK_LEFT
+      // before querying the color buffer sizes.
+      attachment = GL_BACK_LEFT;
+    }
 
     // make sure we clear any errors before we start
     // otherwise we may get incorrect results
@@ -931,7 +1174,7 @@ int vtkOpenGLRenderWindow::GetColorBufferInternalFormat(int attachmentPoint)
   int format = 0;
 
 #ifndef GL_ES_VERSION_3_0
-  if (GLEW_ARB_direct_state_access)
+  if (GLAD_GL_ARB_direct_state_access)
   {
     int type;
     glGetFramebufferAttachmentParameteriv(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0 + attachmentPoint,
@@ -1068,9 +1311,11 @@ int vtkOpenGLRenderWindow::ReadPixels(
   }
 
   // Must clear previous errors first.
+#ifdef VTK_REPORT_OPENGL_ERRORS
   while (glGetError() != GL_NO_ERROR)
   {
   }
+#endif
 
   this->GetState()->vtkglDisable(GL_SCISSOR_TEST);
 
@@ -1233,6 +1478,13 @@ void vtkOpenGLRenderWindow::End()
   this->GetState()->PopFramebufferBindings();
 }
 
+//------------------------------------------------------------------------------
+void vtkOpenGLRenderWindow::SetOpenGLSymbolLoader(VTKOpenGLLoaderFunction loader, void* userData)
+{
+  this->SymbolLoader.LoadFunction = loader;
+  this->SymbolLoader.UserData = userData;
+}
+
 void vtkOpenGLRenderWindow::TextureDepthBlit(vtkTextureObject* source, int srcX, int srcY,
   int srcX2, int srcY2, int destX, int destY, int destX2, int destY2)
 {
@@ -1348,8 +1600,15 @@ void vtkOpenGLRenderWindow::Frame()
     this->RenderFramebuffer->Bind(GL_READ_FRAMEBUFFER);
     this->RenderFramebuffer->ActivateReadBuffer(0);
 
-    this->GetState()->vtkglBlitFramebuffer(0, 0, fbsize[0], fbsize[1], 0, 0, fbsize[0], fbsize[1],
-      (copiedColor ? 0 : GL_COLOR_BUFFER_BIT) | GL_DEPTH_BUFFER_BIT, GL_NEAREST);
+    if (this->FramebufferFlipY)
+    {
+      this->TextureDepthBlit(this->RenderFramebuffer->GetDepthAttachmentAsTextureObject());
+    }
+    else
+    {
+      this->GetState()->vtkglBlitFramebuffer(0, 0, fbsize[0], fbsize[1], 0, 0, fbsize[0], fbsize[1],
+        (copiedColor ? 0 : GL_COLOR_BUFFER_BIT) | GL_DEPTH_BUFFER_BIT, GL_NEAREST);
+    }
 
     this->GetState()->vtkglViewport(0, 0, this->Size[0], this->Size[1]);
     this->GetState()->vtkglScissor(0, 0, this->Size[0], this->Size[1]);
@@ -1365,6 +1624,10 @@ void vtkOpenGLRenderWindow::Frame()
       {
         this->BlitDisplayFramebuffer();
       }
+      if (this->FrameBlitMode == BlitToCurrentWithDepth)
+      {
+        this->BlitDisplayFramebufferColorAndDepth();
+      }
     }
   }
 }
@@ -1379,19 +1642,28 @@ bool vtkOpenGLRenderWindow::ResolveFlipRenderFramebuffer()
   if (this->MultiSamples > 1 && this->RenderFramebuffer->GetColorAttachmentAsTextureObject(0))
   {
     useTexture = true;
-    const std::string& vendorString = this->GetState()->GetVendor();
-    const std::string& versionString = this->GetState()->GetVersion();
-    const std::string& rendererString = this->GetState()->GetRenderer();
-    size_t numExceptions =
-      sizeof(vtkOpenGLRenderWindowMSAATextureBug) / sizeof(vtkOpenGLRenderWindowDriverInfo);
-    for (size_t i = 0; i < numExceptions; i++)
+    // can set VTK_FORCE_MSAA=0/1 to override driver exclusion
+    const char* useMSAAEnv = std::getenv("VTK_FORCE_MSAA");
+    if (useMSAAEnv)
     {
-      if (vendorString.find(vtkOpenGLRenderWindowMSAATextureBug[i].Vendor) == 0 &&
-        versionString.find(vtkOpenGLRenderWindowMSAATextureBug[i].Version) == 0 &&
-        rendererString.find(vtkOpenGLRenderWindowMSAATextureBug[i].Renderer) == 0)
+      useTexture = strlen(useMSAAEnv) ? (std::atoi(useMSAAEnv) == 1) : true;
+    }
+    else
+    {
+      const std::string& vendorString = this->GetState()->GetVendor();
+      const std::string& versionString = this->GetState()->GetVersion();
+      const std::string& rendererString = this->GetState()->GetRenderer();
+      size_t numExceptions =
+        sizeof(vtkOpenGLRenderWindowMSAATextureBug) / sizeof(vtkOpenGLRenderWindowDriverInfo);
+      for (size_t i = 0; i < numExceptions; i++)
       {
-        useTexture = false;
-        break;
+        if (vendorString.find(vtkOpenGLRenderWindowMSAATextureBug[i].Vendor) == 0 &&
+          versionString.find(vtkOpenGLRenderWindowMSAATextureBug[i].Version) == 0 &&
+          rendererString.find(vtkOpenGLRenderWindowMSAATextureBug[i].Renderer) == 0)
+        {
+          useTexture = false;
+          break;
+        }
       }
     }
   }
@@ -1550,6 +1822,12 @@ void vtkOpenGLRenderWindow::BlitDisplayFramebuffer()
     this->Size[1], GL_COLOR_BUFFER_BIT, GL_NEAREST);
 }
 
+void vtkOpenGLRenderWindow::BlitDisplayFramebufferColorAndDepth()
+{
+  this->BlitDisplayFramebuffer(0, 0, 0, this->Size[0], this->Size[1], 0, 0, this->Size[0],
+    this->Size[1], GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT, GL_NEAREST);
+}
+
 void vtkOpenGLRenderWindow::BlitDisplayFramebuffer(int right, int srcX, int srcY, int srcWidth,
   int srcHeight, int destX, int destY, int destWidth, int destHeight, int bufferMode,
   int interpolation)
@@ -1985,7 +2263,7 @@ int vtkOpenGLRenderWindow::SetRGBAPixelData(
   if (!blend)
   {
     this->GetState()->vtkglDisable(GL_BLEND);
-    this->DrawPixels(x1, y1, x2, y2, 4, VTK_FLOAT, data); // TODO replace dprecated function
+    this->DrawPixels(x1, y1, x2, y2, 4, VTK_FLOAT, data); // TODO replace deprecated function
     this->GetState()->vtkglEnable(GL_BLEND);
   }
   else
@@ -2285,6 +2563,7 @@ int vtkOpenGLRenderWindow::GetZbufferData(int x1, int y1, int x2, int y2, float*
     }
     else
     {
+      const auto maxDepthValueAsInteger = float(1 << depthSize) - 1.0f;
       this->GetState()->PushReadFramebufferBinding();
       this->DepthFramebuffer->Bind(GL_READ_FRAMEBUFFER);
       this->DepthFramebuffer->ActivateReadBuffer(0);
@@ -2298,11 +2577,15 @@ int vtkOpenGLRenderWindow::GetZbufferData(int x1, int y1, int x2, int y2, float*
         z_int += (z_data_quarters[j++] << 8);
 #if defined(GL_DEPTH_COMPONENT24) || defined(GL_DEPTH_COMPONENT32)
         z_int += (z_data_quarters[j++] << 16);
+#else
+        ++j;
 #endif
 #ifdef GL_DEPTH_COMPONENT32
         z_int += (z_data_quarters[j++] << 24);
+#else
+        ++j;
 #endif
-        z_data[i] = z_int / float(0xffffff);
+        z_data[i] = z_int / maxDepthValueAsInteger;
       }
     }
   }
@@ -2475,7 +2758,7 @@ int vtkOpenGLRenderWindow::CreateFramebuffers(int width, int height)
 
   if (!this->RenderFramebuffer->GetFBOIndex())
   {
-    // verify that our multisample setting doe snot exceed the hardware
+    // verify that our multisample setting does not exceed the hardware
     if (this->MultiSamples)
     {
 #ifdef GL_MAX_SAMPLES
@@ -2500,8 +2783,8 @@ int vtkOpenGLRenderWindow::CreateFramebuffers(int width, int height)
 #else
       this->MultiSamples ? false : true, // textures
 #endif
-      1, VTK_UNSIGNED_CHAR, // 1 color buffer uchar
-      true, 32,             // depth buffer
+      1, VTK_UNSIGNED_CHAR,                    // 1 color buffer uchar
+      true, this->RenderBufferTargetDepthSize, // depth buffer
       this->MultiSamples, this->StencilCapable != 0);
     this->LastMultiSamples = this->MultiSamples;
     this->GetState()->PopFramebufferBindings();
@@ -2515,9 +2798,9 @@ int vtkOpenGLRenderWindow::CreateFramebuffers(int width, int height)
   {
     this->GetState()->PushFramebufferBindings();
     this->DisplayFramebuffer->PopulateFramebuffer(width, height,
-      true,                 // textures
-      2, VTK_UNSIGNED_CHAR, // 1 color buffer uchar
-      true, 32,             // depth buffer
+      true,                                    // textures
+      2, VTK_UNSIGNED_CHAR,                    // 1 color buffer uchar
+      true, this->RenderBufferTargetDepthSize, // depth buffer
       0, this->StencilCapable != 0);
     this->GetState()->PopFramebufferBindings();
   }
@@ -2530,9 +2813,9 @@ int vtkOpenGLRenderWindow::CreateFramebuffers(int width, int height)
   {
     this->GetState()->PushFramebufferBindings();
     this->ResolveFramebuffer->PopulateFramebuffer(width, height,
-      true,                 // textures
-      1, VTK_UNSIGNED_CHAR, // 1 color buffer uchar
-      true, 32,             // depth buffer
+      true,                                    // textures
+      1, VTK_UNSIGNED_CHAR,                    // 1 color buffer uchar
+      true, this->RenderBufferTargetDepthSize, // depth buffer
       0, this->StencilCapable != 0);
     this->GetState()->PopFramebufferBindings();
   }
@@ -2617,36 +2900,48 @@ int vtkOpenGLRenderWindow::SupportsOpenGL()
   rw->SetDisplayId(this->GetGenericDisplayId());
   rw->SetOffScreenRendering(1);
   rw->Initialize();
-  if (!rw->GlewInitValid)
+  if (!rw->Initialized)
   {
-    this->OpenGLSupportMessage = "glewInit failed for this window, OpenGL not supported.";
+    this->OpenGLSupportMessage =
+      "Failed to initialize OpenGL for this window, OpenGL not supported.";
     rw->Delete();
     vtkOutputWindow::SetInstance(oldOW);
     oldOW->Delete();
     return 0;
   }
 
-#ifdef GLEW_OK
-
-  else if (GLEW_VERSION_3_2 || GLEW_VERSION_3_1)
+#if defined(GLAD_GL)
+  else if (GLAD_GL_VERSION_3_2 || GLAD_GL_VERSION_3_1)
   {
     this->OpenGLSupportResult = 1;
     this->OpenGLSupportMessage = "The system appears to support OpenGL 3.2/3.1";
   }
-#else
-#ifdef GL_ES_VERSION_2_0
-  this->OpenGLSupportResult = 1;
-  this->OpenGLSupportMessage = "The system appears to support OpenGL ES 2.0";
-#endif
-#ifdef GL_ES_VERSION_3_0
-  this->OpenGLSupportResult = 1;
-  this->OpenGLSupportMessage = "The system appears to support OpenGL ES 3.0";
-#endif
+#elif defined(GLAD_GLES2)
+  else if (GLAD_GL_ES_VERSION_3_2)
+  {
+    this->OpenGLSupportResult = 1;
+    this->OpenGLSupportMessage = "The system appears to support OpenGL ES 3.2";
+  }
+  else if (GLAD_GL_ES_VERSION_3_1)
+  {
+    this->OpenGLSupportResult = 1;
+    this->OpenGLSupportMessage = "The system appears to support OpenGL ES 3.1";
+  }
+  else if (GLAD_GL_ES_VERSION_3_0)
+  {
+    this->OpenGLSupportResult = 1;
+    this->OpenGLSupportMessage = "The system appears to support OpenGL ES 3.0";
+  }
+  else if (GLAD_GL_ES_VERSION_2_0)
+  {
+    this->OpenGLSupportResult = 1;
+    this->OpenGLSupportMessage = "The system appears to support OpenGL ES 2.0";
+  }
 #endif
 
   if (this->OpenGLSupportResult)
   {
-    // even if glew thinks we have support we should actually try linking a
+    // even if glad thinks we have support we should actually try linking a
     // shader program to make sure
     vtkShaderProgram* newShader = rw->GetShaderCache()->ReadyShaderProgram(
       // simple vert shader
