@@ -18,8 +18,6 @@
 #include "vtkShaderProgram.h"
 #include "vtkTexture.h"
 
-#include <cmath>
-
 VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkOpenGLSkybox);
 
@@ -64,9 +62,6 @@ vtkOpenGLSkybox::vtkOpenGLSkybox()
     false // only do it once
   );
 
-  this->CubeMapper->AddObserver(
-    vtkCommand::UpdateShaderEvent, this, &vtkOpenGLSkybox::UpdateUniforms);
-
   this->LastProjection = -1;
   this->LastGammaCorrect = false;
 
@@ -79,10 +74,15 @@ vtkOpenGLSkybox::vtkOpenGLSkybox()
 
 vtkOpenGLSkybox::~vtkOpenGLSkybox() = default;
 
+void vtkOpenGLSkybox::SetMapper(vtkMapper* mapper)
+{
+  this->Superclass::SetMapper(mapper);
+  mapper->AddObserver(vtkCommand::UpdateShaderEvent, this, &vtkOpenGLSkybox::UpdateUniforms);
+}
+
 void vtkOpenGLSkybox::UpdateUniforms(vtkObject*, unsigned long, void* calldata)
 {
   vtkShaderProgram* program = reinterpret_cast<vtkShaderProgram*>(calldata);
-
   program->SetUniform3f("cameraPos", this->LastCameraPosition);
   float plane[4];
   double norm = vtkMath::Norm(this->FloorPlane, 3);
@@ -92,6 +92,7 @@ void vtkOpenGLSkybox::UpdateUniforms(vtkObject*, unsigned long, void* calldata)
   plane[3] = this->FloorPlane[3] / norm;
   program->SetUniform4f("floorPlane", plane);
   program->SetUniform3f("floorRight", this->FloorRight);
+  program->SetUniform2f("floorTCoordScale", this->FloorTexCoordScale);
   float front[3];
   vtkMath::Cross(plane, this->FloorRight, front);
   program->SetUniform3f("floorFront", front);
@@ -177,9 +178,10 @@ void vtkOpenGLSkybox::Render(vtkRenderer* ren, vtkMapper* mapper)
     if (this->Projection == vtkSkybox::Floor)
     {
       vtkShaderProgram::Substitute(str, "//VTK::Projection::Dec",
-        "uniform vec4 floorPlane;\n" // floor plane eqn
-        "uniform vec3 floorRight;\n" // floor plane right
-        "uniform vec3 floorFront;\n" // floor plane front
+        "uniform vec4 floorPlane;\n"       // floor plane eqn
+        "uniform vec3 floorRight;\n"       // floor plane right
+        "uniform vec3 floorFront;\n"       // floor plane front
+        "uniform vec2 floorTCoordScale;\n" // floor texture scale
         "uniform mat4 MCDCMatrix;\n"
         "uniform sampler2D actortexture;\n");
 
@@ -193,7 +195,7 @@ void vtkOpenGLSkybox::Render(vtkRenderer* ren, vtkMapper* mapper)
         "    if (t >= 0.0) {\n"
         "      vec3 pos = dirv*t - p0l0;\n"
         "      vec4 color = texture(actortexture, "
-        "vec2(dot(floorRight,pos), dot(floorFront, pos)));\n"
+        "vec2(dot(floorRight,pos)/floorTCoordScale.x, dot(floorFront, pos)/floorTCoordScale.y));\n"
         "      //VTK::Gamma::Impl\n"
         // The discards cause a discontinuity with mipmapping
         // on the horizon of the floor. So we fade out the floor
@@ -201,7 +203,7 @@ void vtkOpenGLSkybox::Render(vtkRenderer* ren, vtkMapper* mapper)
         // dot product equals .02 which is at 88.85 degrees and
         // going to zero at 90 degrees.
         "      gl_FragData[0].a *= (50.0*min(0.02, abs(den)));\n"
-        "      vec4 tpos = MCDCMatrix*vec4(pos.xyz,1.0);\n"
+        "      vec4 tpos = MCDCMatrix*vec4(pos.xyz + 0.01 * p0l0,1.0);\n"
         "      gl_FragDepth = clamp(0.5 + 0.5*tpos.z/tpos.w,0.0,1.0);\n"
         "    } else { discard; }\n"
         "  }\n");
@@ -220,6 +222,7 @@ void vtkOpenGLSkybox::Render(vtkRenderer* ren, vtkMapper* mapper)
     sp->SetFragmentShaderCode(str.c_str());
 
     this->CubeMapper->Modified();
+    mapper->Modified();
     this->LastProjection = this->Projection;
     this->LastGammaCorrect = this->GammaCorrect;
   }
