@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkValuePass.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkValuePass
  *
@@ -45,7 +33,9 @@
 #include "vtkOpenGLRenderPass.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 #include "vtkSmartPointer.h"           //for ivar
+#include "vtkWrappingHints.h"          // For VTK_MARSHALAUTO
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAbstractArray;
 class vtkActor;
 class vtkDataArray;
@@ -58,7 +48,7 @@ class vtkRenderer;
 class vtkRenderWindow;
 class vtkShaderProgram;
 
-class VTKRENDERINGOPENGL2_EXPORT vtkValuePass : public vtkOpenGLRenderPass
+class VTKRENDERINGOPENGL2_EXPORT VTK_MARSHALAUTO vtkValuePass : public vtkOpenGLRenderPass
 {
 public:
   enum Mode
@@ -71,14 +61,9 @@ public:
   vtkTypeMacro(vtkValuePass, vtkOpenGLRenderPass);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  // @deprecated As of 9.0, We are moving to only FLOATING_POINT.
-  VTK_LEGACY(vtkSetMacro(RenderingMode, int));
-  VTK_LEGACY(vtkGetMacro(RenderingMode, int));
   void SetInputArrayToProcess(int fieldAssociation, const char* name);
   void SetInputArrayToProcess(int fieldAssociation, int fieldId);
   void SetInputComponentToProcess(int component);
-  // @deprecated As of 9.0, Not needed with FLOATING_POINT.
-  VTK_LEGACY(void SetScalarRange(double min, double max));
 
   /**
    * Perform rendering according to a render state \p s.
@@ -98,7 +83,7 @@ public:
    * a format for the internal glReadPixels call can be specified. 'data' is expected
    * to be allocated and cleaned-up by the caller.
    */
-  void GetFloatImageData(int const format, int const width, int const height, void* data);
+  void GetFloatImageData(int format, int width, int height, void* data);
 
   /**
    * Interface to get the rendered image in FLOATING_POINT mode.  Image extents of
@@ -106,22 +91,8 @@ public:
    */
   int* GetFloatImageExtents();
 
-  /**
-   * Check for extension support.
-   * @deprecated As of 9.0, All platforms support FLOATING_POINT.
-   */
-  VTK_LEGACY(bool IsFloatingPointModeSupported());
-
   void ReleaseGraphicsResources(vtkWindow* win) override;
 
-  /**
-   * Convert an RGB triplet to a floating point value. This method is exposed
-   * as a convenience function for testing (TestValuePass2).
-   * @deprecated As of 9.0, not necessary with FLOATING_POINT.
-   */
-  VTK_LEGACY(void ColorToValue(
-    unsigned char const* color, double const min, double const scale, double& value));
-
 protected:
   vtkValuePass();
   ~vtkValuePass() override;
@@ -132,7 +103,7 @@ protected:
    */
 
   /**
-   * Use vtkShaderProgram::Substitute to replace //VTK::XXX:YYY declarations in
+   * Use vtkShaderProgram::Substitute to replace @code //VTK::XXX:YYY @endcode declarations in
    * the shader sources. Gets called after other mapper shader replacements.
    * Return false on error.
    */
@@ -205,14 +176,14 @@ protected:
   void BindAttributes(vtkShaderProgram* prog, vtkOpenGLVertexArrayObject* VAO);
   void BindUniforms(vtkShaderProgram* prog);
 
-  //@{
+  ///@{
   /**
    * Methods managing graphics resources required during FLOATING_POINT mode.
    */
   bool HasWindowSizeChanged(vtkRenderer* ren);
   bool InitializeFBO(vtkRenderer* ren);
   void ReleaseFBO(vtkWindow* win);
-  //@}
+  ///@}
 
   class vtkInternalsFloat;
   vtkInternalsFloat* ImplFloat;
@@ -238,4 +209,5 @@ private:
   void operator=(const vtkValuePass&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
