@@ -7,35 +7,6 @@
 #include "vtkOpenGLRenderer.h"
 #include "vtkXOpenGLRenderWindow.h"
 
-#include "vtk_glew.h"
-// Define GLX_GLXEXT_LEGACY to prevent glx.h from including the glxext.h
-// provided by the system.
-//#define GLX_GLXEXT_LEGACY
-
-// Ensure older version of glx.h define glXGetProcAddressARB
-#define GLX_GLXEXT_PROTOTYPES
-
-// New Workaround:
-// The GLX_GLXEXT_LEGACY definition was added to work around system glxext.h
-// files that used the GLintptr and GLsizeiptr types, but did not define them.
-// However, this broke multisampling (See PR#15433). Instead of using that
-// define, we're just defining the missing typedefs here.
-typedef ptrdiff_t GLintptr;
-typedef ptrdiff_t GLsizeiptr;
-#include "GL/glx.h"
-
-#ifndef GLAPI
-#define GLAPI extern
-#endif
-
-#ifndef GLAPIENTRY
-#define GLAPIENTRY
-#endif
-
-#ifndef APIENTRY
-#define APIENTRY GLAPIENTRY
-#endif
-
 #include "vtkCommand.h"
 #include "vtkIdList.h"
 #include "vtkImageData.h"
@@ -59,6 +30,9 @@ typedef ptrdiff_t GLsizeiptr;
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
+#include "vtk_glad.h"
+#include "vtkglad/include/glad/glx.h"
+
 /*
  * Work-around to get forward declarations of C typedef of anonymous
  * structs working. We do not want to include XUtil.h in the header as
@@ -69,6 +43,52 @@ struct vtkXVisualInfo : public XVisualInfo
 {
 };
 
+/*******************************************************************************
+ * Motif style hint definitions
+ *
+ * The definitions in this section are taken from here:
+ *
+ *     https://sources.debian.org/src/motif/2.3.4-6+deb8u1/lib/Xm/MwmUtil.h/
+ *
+ * These are likely to be supported as long as xlib is, and the extended
+ * window manager hints documented at freedesktop.org don't seem to have a
+ * good alternative:
+ *
+ *     https://specifications.freedesktop.org/wm-spec/latest/ar01s05.html#id-1.6.7
+ *
+ * The _NET_WM_WINDOW_TYPE_SPLASH window type mentioned there comes close, but
+ * does not result in task bar entries that can be used to bring the windows
+ * to the front.
+ */
+typedef struct
+{
+  int flags;
+  int functions;
+  int decorations;
+  int input_mode;
+  int status;
+} MotifWmHints;
+
+typedef MotifWmHints MwmHints;
+
+/* bit definitions for MwmHints.flags */
+#define MWM_HINTS_FUNCTIONS (1L << 0)
+#define MWM_HINTS_DECORATIONS (1L << 1)
+
+/* bit definitions for MwmHints.functions */
+#define MWM_FUNC_ALL (1L << 0)
+
+/* number of elements of size 32 in _MWM_HINTS */
+#define PROP_MOTIF_WM_HINTS_ELEMENTS 5
+#define PROP_MWM_HINTS_ELEMENTS PROP_MOTIF_WM_HINTS_ELEMENTS
+
+/* atom name for _MWM_HINTS property */
+#define _XA_MOTIF_WM_HINTS "_MOTIF_WM_HINTS"
+#define _XA_MWM_HINTS _XA_MOTIF_WM_HINTS
+/*
+ * Motif style hint definitions
+ ******************************************************************************/
+
 #define GLX_CONTEXT_MAJOR_VERSION_ARB 0x2091
 #define GLX_CONTEXT_MINOR_VERSION_ARB 0x2092
 typedef GLXContext (*glXCreateContextAttribsARBProc)(
@@ -98,6 +118,8 @@ vtkStandardNewMacro(vtkXOpenGLRenderWindow);
 
 #define MAX_LIGHTS 8
 
+namespace
+{
 GLXFBConfig vtkXOpenGLRenderWindowTryForFBConfig(Display* DisplayId, int drawable_type,
   vtkTypeBool doublebuff, vtkTypeBool stereo, vtkTypeBool stencil, bool srgb)
 {
@@ -165,24 +187,6 @@ GLXFBConfig vtkXOpenGLRenderWindowTryForFBConfig(Display* DisplayId, int drawabl
   return None;
 }
 
-// dead code?
-#if 0
-XVisualInfo *vtkXOpenGLRenderWindowTryForVisual(Display *DisplayId,
-                                                vtkTypeBool doublebuff,
-                                                vtkTypeBool stereo,
-                                                int stencil, bool srgb)
-{
-  GLXFBConfig fbc = vtkXOpenGLRenderWindowTryForFBConfig(DisplayId,
-       GLX_WINDOW_BIT,
-       doublebuff, stereo,
-       stencil, srgb);
-
-  XVisualInfo *v = glXGetVisualFromFBConfig( DisplayId, fbc);
-
-  return v;
-}
-#endif
-
 GLXFBConfig vtkXOpenGLRenderWindowGetDesiredFBConfig(Display* DisplayId, vtkTypeBool& win_stereo,
   vtkTypeBool& win_doublebuffer, int drawable_type, vtkTypeBool& stencil, bool srgb)
 {
@@ -229,24 +233,48 @@ int XEventTypeEquals(Display*, XEvent* event, XPointer winptr)
     *(reinterpret_cast<Window*>(winptr)) == reinterpret_cast<XAnyEvent*>(event)->window);
 }
 
+// to manage the static GLADGLXLibraryDisplay correctly.
+std::atomic<unsigned int> vtkGLXLibraryDisplayCleanupCounter{ 0 };
+
+/**
+ * The glX symbols are globally defined in glad sources, see glad/src/glx.c.
+ * These symbols must be initialized exactly once in the lifetime of an
+ * application. Symbol reassigment would corrupt existing render
+ * windows.
+ *
+ * This setup is created to overcome an inadvertent memory leak
+ * when `gladLoaderLoadGLX(display, 0)` is used. The memory leak
+ * occurs when the passed in display is nullptr.
+ * glad internally opens a display, discovers GLX extensions
+ * supported by the display.
+ *
+ * Hence, if the code simply called `gladLoaderLoadGLX(nullptr, 0)`,
+ * the application will leak the `Display*`, worst case, one
+ * of the glX functions will crash with an error message
+ * "Maximum number of clients reached". This was a real issue
+ * in VTK 9.4.0. See https://gitlab.kitware.com/vtk/vtk/-/issues/19618
+ */
+// static Display used for loading GLX extensions with GLAD.
+std::atomic<bool> GLADGLXLibraryDisplayOpened{ false };
+int GLXVersion = 0;
+Display* GLADGLXLibraryDisplay = nullptr;
+}
+
 vtkXVisualInfo* vtkXOpenGLRenderWindow::GetDesiredVisualInfo()
 {
   XVisualInfo* v = nullptr;
 
   // get the default display connection
-  if (!this->DisplayId)
+  if (!this->EnsureDisplay())
   {
-    this->DisplayId = XOpenDisplay(static_cast<char*>(nullptr));
-
-    if (this->DisplayId == nullptr)
-    {
-      vtkErrorMacro(<< "bad X server connection. DISPLAY=" << vtksys::SystemTools::GetEnv("DISPLAY")
-                    << ". Aborting.\n");
-      abort();
-    }
-
-    this->OwnDisplay = 1;
+    return nullptr;
   }
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return nullptr;
+  }
+
   this->Internal->FBConfig =
     vtkXOpenGLRenderWindowGetDesiredFBConfig(this->DisplayId, this->StereoCapableWindow,
       this->DoubleBuffer, GLX_WINDOW_BIT, this->StencilCapable, this->UseSRGBColorSpace);
@@ -292,6 +320,18 @@ vtkXOpenGLRenderWindow::vtkXOpenGLRenderWindow()
   this->XCSizeSW = 0;
   this->XCHand = 0;
   this->XCCustom = 0;
+
+  auto loadFunc = [](void*, const char* name) -> VTKOpenGLAPIProc
+  {
+    if (name)
+    {
+      return glXGetProcAddress((const GLubyte*)name);
+    }
+    return nullptr;
+  };
+  this->SetOpenGLSymbolLoader(loadFunc, nullptr);
+  // Increment static counter
+  ++::vtkGLXLibraryDisplayCleanupCounter;
 }
 
 // free up memory & close the window
@@ -307,6 +347,14 @@ vtkXOpenGLRenderWindow::~vtkXOpenGLRenderWindow()
   {
     ren->SetRenderWindow(nullptr);
   }
+  if (--::vtkGLXLibraryDisplayCleanupCounter == 0)
+  {
+    if (::GLADGLXLibraryDisplay != nullptr)
+    {
+      XCloseDisplay(::GLADGLXLibraryDisplay);
+      GLADGLXLibraryDisplayOpened = false;
+    }
+  }
 
   delete this->Internal;
 }
@@ -314,6 +362,10 @@ vtkXOpenGLRenderWindow::~vtkXOpenGLRenderWindow()
 // End the rendering process and display the image.
 void vtkXOpenGLRenderWindow::Frame()
 {
+  if (!this->EnsureGLX())
+  {
+    return;
+  }
   this->MakeCurrent();
   this->Superclass::Frame();
   if (!this->AbortRender && this->DoubleBuffer && this->SwapBuffers && this->WindowId != 0)
@@ -339,6 +391,15 @@ bool vtkXOpenGLRenderWindow::InitializeFromCurrentContext()
   return false;
 }
 
+void vtkXOpenGLRenderWindow::SetCoverable(vtkTypeBool coverable)
+{
+  if (this->Coverable != coverable)
+  {
+    this->Coverable = coverable;
+    this->Modified();
+  }
+}
+
 //
 // Set the variable that indicates that we want a stereo capable window
 // be created. This method can only be called before a window is realized.
@@ -357,9 +418,10 @@ void vtkXOpenGLRenderWindow::SetStereoCapableWindow(vtkTypeBool capable)
 }
 
 static int PbufferAllocFail = 0;
+#define vtkXOGLPbufferErrorHandler VTK_ABI_NAMESPACE_MANGLE(vtkXOGLPbufferErrorHandler)
 extern "C"
 {
-  int vtkXOGLPbufferErrorHandler(Display*, XErrorEvent*)
+  int VTK_ABI_NAMESPACE_MANGLE(vtkXOGLPbufferErrorHandler)(Display*, XErrorEvent*)
   {
     PbufferAllocFail = 1;
     return 1;
@@ -367,9 +429,11 @@ extern "C"
 }
 
 static bool ctxErrorOccurred = false;
+#define vtkXOGLContextCreationErrorHandler                                                         \
+  VTK_ABI_NAMESPACE_MANGLE(vtkXOGLContextCreationErrorHandler)
 extern "C"
 {
-  int vtkXOGLContextCreationErrorHandler(Display*, XErrorEvent*)
+  int VTK_ABI_NAMESPACE_MANGLE(vtkXOGLContextCreationErrorHandler)(Display*, XErrorEvent*)
   {
     ctxErrorOccurred = true;
     return 1;
@@ -435,8 +499,8 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
   if ((this->Position[0] >= 0) && (this->Position[1] >= 0))
   {
     xsh.flags |= USPosition;
-    xsh.x = static_cast<int>(this->Position[0]);
-    xsh.y = static_cast<int>(this->Position[1]);
+    xsh.x = this->Position[0];
+    xsh.y = this->Position[1];
   }
 
   x = this->Position[0];
@@ -447,22 +511,22 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
   xsh.width = width;
   xsh.height = height;
 
-  // get the default display connection
-  if (!this->DisplayId)
+  // load GLX
+  if (!this->EnsureGLX())
   {
-    this->DisplayId = XOpenDisplay(static_cast<char*>(nullptr));
-    if (this->DisplayId == nullptr)
-    {
-      vtkErrorMacro(<< "bad X server connection. DISPLAY=" << vtksys::SystemTools::GetEnv("DISPLAY")
-                    << ". Aborting.\n");
-      abort();
-    }
-    this->OwnDisplay = 1;
+    return;
+  }
+
+  // get the default display connection
+  if (!this->EnsureDisplay())
+  {
+    return;
   }
 
   attr.override_redirect = False;
-  if (this->Borders == 0.0)
+  if (this->Borders == 0.0 && !this->Coverable)
   {
+    // Removes borders, and makes the window appear on top of all other windows
     attr.override_redirect = True;
   }
 
@@ -473,8 +537,8 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
     v = this->GetDesiredVisualInfo();
     if (!v)
     {
-      vtkErrorMacro(<< "Could not find a decent visual\n");
-      abort();
+      vtkWarningMacro(<< "Could not find a decent visual\n");
+      return;
     }
     this->ColorMap = XCreateColormap(
       this->DisplayId, XRootWindow(this->DisplayId, v->screen), v->visual, AllocNone);
@@ -493,6 +557,19 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
       XCreateWindow(this->DisplayId, this->ParentId, x, y, static_cast<unsigned int>(width),
         static_cast<unsigned int>(height), 0, v->depth, InputOutput, v->visual,
         CWBackPixel | CWBorderPixel | CWColormap | CWOverrideRedirect | CWEventMask, &attr);
+
+    if (this->Borders == 0.0 && this->Coverable)
+    {
+      // Removes borders, while still allowing other windows on top
+      Atom mwmHintsProperty = XInternAtom(this->DisplayId, _XA_MWM_HINTS, 0);
+      MotifWmHints mwmHints;
+      mwmHints.flags = MWM_HINTS_FUNCTIONS | MWM_HINTS_DECORATIONS;
+      mwmHints.functions = MWM_FUNC_ALL;
+      mwmHints.decorations = 0;
+      XChangeProperty(this->DisplayId, this->WindowId, mwmHintsProperty, XA_ATOM, 32,
+        PropModeReplace, reinterpret_cast<unsigned char*>(&mwmHints), PROP_MWM_HINTS_ELEMENTS);
+    }
+
     XStoreName(this->DisplayId, this->WindowId, this->WindowName);
     XSetNormalHints(this->DisplayId, this->WindowId, &xsh);
 
@@ -546,7 +623,7 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
   // is GLX extension is supported?
   if (!glXQueryExtension(this->DisplayId, nullptr, nullptr))
   {
-    vtkErrorMacro("GLX not found.  Aborting.");
+    vtkWarningMacro("GLX not found.");
     if (this->HasObserver(vtkCommand::ExitEvent))
     {
       this->InvokeEvent(vtkCommand::ExitEvent, nullptr);
@@ -554,7 +631,7 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
     }
     else
     {
-      abort();
+      return;
     }
   }
 
@@ -571,6 +648,8 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
     // GLX_CONTEXT_FLAGS_ARB        , GLX_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB,
 #ifdef GL_ES_VERSION_3_0
       GLX_CONTEXT_PROFILE_MASK_ARB, GLX_CONTEXT_ES_PROFILE_BIT_EXT,
+#else
+      GLX_CONTEXT_PROFILE_MASK_ARB, GLX_CONTEXT_CORE_PROFILE_BIT_ARB,
 #endif
       0 };
 
@@ -648,7 +727,7 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
 
   if (!this->Internal->ContextId)
   {
-    vtkErrorMacro("Cannot create GLX context.  Aborting.");
+    vtkWarningMacro("Cannot create GLX context.");
     if (this->HasObserver(vtkCommand::ExitEvent))
     {
       this->InvokeEvent(vtkCommand::ExitEvent, nullptr);
@@ -656,7 +735,7 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
     }
     else
     {
-      abort();
+      return;
     }
   }
 
@@ -771,8 +850,12 @@ void vtkXOpenGLRenderWindow::DestroyWindow()
     if (this->Internal->ContextId)
     {
       glFinish();
-      glXDestroyContext(this->DisplayId, this->Internal->ContextId);
-      glXMakeCurrent(this->DisplayId, None, nullptr);
+      // load GLX
+      if (this->EnsureGLX())
+      {
+        glXDestroyContext(this->DisplayId, this->Internal->ContextId);
+        glXMakeCurrent(this->DisplayId, None, nullptr);
+      }
     }
   }
   else
@@ -809,6 +892,10 @@ void vtkXOpenGLRenderWindow::DestroyWindow()
 void vtkXOpenGLRenderWindow::WindowInitialize()
 {
   this->CreateAWindow();
+  if (!this->DisplayId || !this->WindowId)
+  {
+    return;
+  }
 
   this->MakeCurrent();
 
@@ -835,6 +922,10 @@ void vtkXOpenGLRenderWindow::Initialize()
 
 void vtkXOpenGLRenderWindow::Finalize()
 {
+  if (!this->Initialized)
+  {
+    return;
+  }
   // clean and destroy window
   this->DestroyWindow();
 }
@@ -1023,17 +1114,14 @@ void vtkXOpenGLRenderWindow::SetSize(int width, int height)
   }
 }
 
-void vtkXOpenGLRenderWindow::SetSizeNoXResize(int width, int height)
-{
-  if ((this->Size[0] != width) || (this->Size[1] != height))
-  {
-    this->Superclass::SetSize(width, height);
-    this->Modified();
-  }
-}
-
 bool vtkXOpenGLRenderWindow::SetSwapControl(int i)
 {
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return false;
+  }
+
   glXSwapIntervalEXTProc glXSwapIntervalEXT =
     (glXSwapIntervalEXTProc)glXGetProcAddressARB((const GLubyte*)"glXSwapIntervalEXT");
 
@@ -1136,6 +1224,11 @@ void vtkXOpenGLRenderWindow::PrintSelf(ostream& os, vtkIndent indent)
 
 void vtkXOpenGLRenderWindow::MakeCurrent()
 {
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return;
+  }
   // when debugging XErrors uncomment the following lines
   // if (this->DisplayId)
   //   {
@@ -1152,6 +1245,11 @@ void vtkXOpenGLRenderWindow::MakeCurrent()
 
 void vtkXOpenGLRenderWindow::ReleaseCurrent()
 {
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return;
+  }
   if (this->Internal->ContextId && (this->Internal->ContextId == glXGetCurrentContext()) &&
     this->DisplayId)
   {
@@ -1164,6 +1262,11 @@ void vtkXOpenGLRenderWindow::ReleaseCurrent()
 // Tells if this window is the current OpenGL context for the calling thread.
 bool vtkXOpenGLRenderWindow::IsCurrent()
 {
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return false;
+  }
   bool result = false;
   if (this->Internal->ContextId)
   {
@@ -1174,6 +1277,11 @@ bool vtkXOpenGLRenderWindow::IsCurrent()
 
 void vtkXOpenGLRenderWindow::PushContext()
 {
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return;
+  }
   GLXContext current = glXGetCurrentContext();
   this->ContextStack.push(current);
   this->DisplayStack.push(glXGetCurrentDisplay());
@@ -1186,6 +1294,11 @@ void vtkXOpenGLRenderWindow::PushContext()
 
 void vtkXOpenGLRenderWindow::PopContext()
 {
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return;
+  }
   GLXContext current = glXGetCurrentContext();
   GLXContext target = static_cast<GLXContext>(this->ContextStack.top());
   this->ContextStack.pop();
@@ -1204,9 +1317,11 @@ void vtkXOpenGLRenderWindow::SetForceMakeCurrent()
 
 vtkTypeBool vtkXOpenGLRenderWindowFoundMatch;
 
+#define vtkXOpenGLRenderWindowPredProc VTK_ABI_NAMESPACE_MANGLE(vtkXOpenGLRenderWindowPredProc)
 extern "C"
 {
-  Bool vtkXOpenGLRenderWindowPredProc(Display* vtkNotUsed(disp), XEvent* event, char* arg)
+  Bool VTK_ABI_NAMESPACE_MANGLE(vtkXOpenGLRenderWindowPredProc)(
+    Display* vtkNotUsed(disp), XEvent* event, char* arg)
   {
     Window win = (Window)arg;
 
@@ -1252,19 +1367,11 @@ vtkTypeBool vtkXOpenGLRenderWindow::GetEventPending()
 int* vtkXOpenGLRenderWindow::GetScreenSize()
 {
   // get the default display connection
-  if (!this->DisplayId)
+  if (!this->EnsureDisplay())
   {
-    this->DisplayId = XOpenDisplay(static_cast<char*>(nullptr));
-    if (this->DisplayId == nullptr)
-    {
-      vtkErrorMacro(<< "bad X server connection. DISPLAY=" << vtksys::SystemTools::GetEnv("DISPLAY")
-                    << ". Aborting.\n");
-      abort();
-    }
-    else
-    {
-      this->OwnDisplay = 1;
-    }
+    this->ScreenSize[0] = 0;
+    this->ScreenSize[1] = 0;
+    return this->ScreenSize;
   }
 
   this->ScreenSize[0] = XDisplayWidth(this->DisplayId, XDefaultScreen(this->DisplayId));
@@ -1305,6 +1412,60 @@ Display* vtkXOpenGLRenderWindow::GetDisplayId()
   return this->DisplayId;
 }
 
+bool vtkXOpenGLRenderWindow::EnsureDisplay()
+{
+  if (!this->DisplayId)
+  {
+    this->DisplayId = XOpenDisplay(static_cast<char*>(nullptr));
+    if (this->DisplayId == nullptr)
+    {
+      // Only warn about DISPLAY if on-screen rendering is selected,
+      // this helps with automatic detection of best window backend.
+      if (this->ShowWindow)
+      {
+        vtkWarningMacro(<< "bad X server connection. DISPLAY="
+                        << vtksys::SystemTools::GetEnv("DISPLAY"));
+      }
+    }
+    else
+    {
+      this->OwnDisplay = 1;
+    }
+  }
+  return this->DisplayId != nullptr;
+}
+
+bool vtkXOpenGLRenderWindow::EnsureGLX()
+{
+  if (!::GLADGLXLibraryDisplayOpened.exchange(true))
+  {
+    ::GLADGLXLibraryDisplay = XOpenDisplay(static_cast<char*>(nullptr));
+    if (::GLADGLXLibraryDisplay)
+    {
+      ::GLXVersion = gladLoaderLoadGLX(::GLADGLXLibraryDisplay, 0);
+      if (::GLXVersion > 0)
+      {
+        return true;
+      }
+      else
+      {
+        vtkGenericWarningMacro(<< "Failed to load GLX. Please install OpenGL drivers.");
+        return false;
+      }
+    }
+    else
+    {
+      vtkGenericWarningMacro(<< "bad X server connection. DISPLAY="
+                             << vtksys::SystemTools::GetEnv("DISPLAY"));
+      return false;
+    }
+  }
+  else
+  {
+    return (::GLXVersion > 0);
+  }
+}
+
 // Get this RenderWindow's parent X window id.
 Window vtkXOpenGLRenderWindow::GetParentId()
 {
@@ -1369,26 +1530,11 @@ void vtkXOpenGLRenderWindow::SetWindowId(Window arg)
 // Set this RenderWindow's X window id to a pre-existing window.
 void vtkXOpenGLRenderWindow::SetWindowInfo(const char* info)
 {
+  // note: potential Display/Window mismatch here
+  this->EnsureDisplay();
+
   int tmp;
-
-  // get the default display connection
-  if (!this->DisplayId)
-  {
-    this->DisplayId = XOpenDisplay(static_cast<char*>(nullptr));
-    if (this->DisplayId == nullptr)
-    {
-      vtkErrorMacro(<< "bad X server connection. DISPLAY=" << vtksys::SystemTools::GetEnv("DISPLAY")
-                    << ". Aborting.\n");
-      abort();
-    }
-    else
-    {
-      this->OwnDisplay = 1;
-    }
-  }
-
   sscanf(info, "%i", &tmp);
-
   this->SetWindowId(static_cast<Window>(tmp));
 }
 
@@ -1397,33 +1543,17 @@ void vtkXOpenGLRenderWindow::SetNextWindowInfo(const char* info)
 {
   int tmp;
   sscanf(info, "%i", &tmp);
-
   this->SetNextWindowId(static_cast<Window>(tmp));
 }
 
 // Sets the X window id of the window that WILL BE created.
 void vtkXOpenGLRenderWindow::SetParentInfo(const char* info)
 {
+  // note: potential Display/Window mismatch here
+  this->EnsureDisplay();
+
   int tmp;
-
-  // get the default display connection
-  if (!this->DisplayId)
-  {
-    this->DisplayId = XOpenDisplay(static_cast<char*>(nullptr));
-    if (this->DisplayId == nullptr)
-    {
-      vtkErrorMacro(<< "bad X server connection. DISPLAY=" << vtksys::SystemTools::GetEnv("DISPLAY")
-                    << ". Aborting.\n");
-      abort();
-    }
-    else
-    {
-      this->OwnDisplay = 1;
-    }
-  }
-
   sscanf(info, "%i", &tmp);
-
   this->SetParentId(static_cast<Window>(tmp));
 }
 
@@ -1444,6 +1574,11 @@ const char* vtkXOpenGLRenderWindow::ReportCapabilities()
   {
     return "display id not set";
   }
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return "GLX not available.";
+  }
 
   int scrnum = XDefaultScreen(this->DisplayId);
   const char* serverVendor = glXQueryServerString(this->DisplayId, scrnum, GLX_VENDOR);
@@ -1518,6 +1653,11 @@ void vtkXOpenGLRenderWindow::CloseDisplay()
 vtkTypeBool vtkXOpenGLRenderWindow::IsDirect()
 {
   this->MakeCurrent();
+  // load GLX
+  if (!this->EnsureGLX())
+  {
+    return false;
+  }
   this->UsingHardware = 0;
   if (this->DisplayId && this->Internal->ContextId)
   {
