@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkSynchronizedRenderers.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkSynchronizedRenderers.h"
 
 #include "vtkBoundingBox.h"
@@ -35,10 +23,16 @@
 #include "vtkPNGWriter.h"
 #include "vtkParallelRenderManager.h"
 #include "vtkRenderWindow.h"
+#include "vtkSynchronizableActors.h"
+#include "vtkSynchronizableAvatars.h"
+#include "vtkTextProperty.h"
 
 #include <cassert>
+#include <map>
+#include <string>
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 class vtkSynchronizedRenderers::vtkObserver : public vtkCommand
 {
 public:
@@ -73,16 +67,77 @@ public:
   vtkSynchronizedRenderers* Target;
 };
 
+class vtkSynchronizedRenderers::vtkInternals
+{
+public:
+  vtkInternals()
+    : SynchronizableActorsEnabled(false)
+  {
+  }
+
+  void InitializeRenderer(vtkRenderer* ren)
+  {
+    if (this->SynchronizableActorsEnabled)
+    {
+      for (auto iter = this->SynchronizedActors.begin(); iter != this->SynchronizedActors.end();
+           iter++)
+      {
+        (*iter)->InitializeRenderer(ren);
+      }
+    }
+  }
+
+  void CleanUpRenderer(vtkRenderer* ren)
+  {
+    if (this->SynchronizableActorsEnabled)
+    {
+      for (auto iter = this->SynchronizedActors.begin(); iter != this->SynchronizedActors.end();
+           iter++)
+      {
+        (*iter)->CleanUpRenderer(ren);
+      }
+    }
+  }
+
+  void Save(vtkMultiProcessStream& stream, vtkRenderer* ren)
+  {
+    if (this->SynchronizableActorsEnabled)
+    {
+      for (auto iter = this->SynchronizedActors.begin(); iter != this->SynchronizedActors.end();
+           iter++)
+      {
+        (*iter)->SaveToStream(stream, ren);
+      }
+    }
+  }
+
+  void Restore(vtkMultiProcessStream& stream, vtkRenderer* ren)
+  {
+    if (this->SynchronizableActorsEnabled)
+    {
+      for (auto iter = this->SynchronizedActors.begin(); iter != this->SynchronizedActors.end();
+           iter++)
+      {
+        (*iter)->RestoreFromStream(stream, ren);
+      }
+    }
+  }
+
+  std::vector<vtkSmartPointer<vtkSynchronizableActors>> SynchronizedActors;
+  bool SynchronizableActorsEnabled;
+};
+
 vtkStandardNewMacro(vtkSynchronizedRenderers);
 vtkCxxSetObjectMacro(vtkSynchronizedRenderers, ParallelController, vtkMultiProcessController);
 vtkCxxSetObjectMacro(vtkSynchronizedRenderers, CaptureDelegate, vtkSynchronizedRenderers);
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSynchronizedRenderers::vtkSynchronizedRenderers()
   : LastBackground{ 0, 0, 0 }
   , LastBackgroundAlpha(0)
   , LastTexturedBackground(false)
   , LastGradientBackground(false)
   , FixBackground(false)
+  , Internal(new vtkSynchronizedRenderers::vtkInternals())
 {
   this->Observer = vtkSynchronizedRenderers::vtkObserver::New();
   this->Observer->Target = this;
@@ -102,7 +157,7 @@ vtkSynchronizedRenderers::vtkSynchronizedRenderers()
   this->AutomaticEventHandling = true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSynchronizedRenderers::~vtkSynchronizedRenderers()
 {
   this->SetCaptureDelegate(nullptr);
@@ -122,7 +177,37 @@ vtkSynchronizedRenderers::~vtkSynchronizedRenderers()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+void vtkSynchronizedRenderers::EnableSynchronizableActors(bool enabled)
+{
+  if (enabled != this->Internal->SynchronizableActorsEnabled)
+  {
+    this->Internal->SynchronizableActorsEnabled = enabled;
+
+    if (enabled)
+    {
+      this->Internal->SynchronizedActors.emplace_back(
+        vtkSmartPointer<vtkSynchronizableAvatars>::New());
+      // In the future, we can add any other instances that can synchronize
+      // collections of actors here, e.g. controller models, desktop camera
+      // model, etc.
+      if (this->Renderer)
+      {
+        this->Internal->InitializeRenderer(this->Renderer);
+      }
+    }
+    else
+    {
+      if (this->Renderer)
+      {
+        this->Internal->CleanUpRenderer(this->Renderer);
+      }
+      this->Internal->SynchronizedActors.clear();
+    }
+  }
+}
+
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::SetRenderer(vtkRenderer* renderer)
 {
   if (this->Renderer != renderer)
@@ -130,6 +215,8 @@ void vtkSynchronizedRenderers::SetRenderer(vtkRenderer* renderer)
     if (this->Renderer)
     {
       this->Renderer->RemoveObserver(this->Observer);
+
+      this->Internal->CleanUpRenderer(this->Renderer);
     }
 
     // The renderer should be OpenGL ...
@@ -147,16 +234,18 @@ void vtkSynchronizedRenderers::SetRenderer(vtkRenderer* renderer)
       this->Renderer->AddObserver(vtkCommand::StartEvent, this->Observer);
       this->Renderer->AddObserver(vtkCommand::EndEvent, this->Observer);
       // this->Renderer->AddObserver(vtkCommand::AbortCheckEvent, this->Observer);
+
+      this->Internal->InitializeRenderer(this->Renderer);
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::HandleStartRender()
 {
   if (!this->Renderer || !this->ParallelRendering || !this->ParallelController)
   {
-    if (this->CaptureDelegate && this->CaptureDelegate->GetAutomaticEventHandling() == false)
+    if (this->CaptureDelegate && !this->CaptureDelegate->GetAutomaticEventHandling())
     {
       this->CaptureDelegate->HandleStartRender();
     }
@@ -201,13 +290,13 @@ void vtkSynchronizedRenderers::HandleStartRender()
       this->LastViewport[3] / this->ImageReductionFactor);
   }
 
-  if (this->CaptureDelegate && this->CaptureDelegate->GetAutomaticEventHandling() == false)
+  if (this->CaptureDelegate && !this->CaptureDelegate->GetAutomaticEventHandling())
   {
     this->CaptureDelegate->HandleStartRender();
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::MasterStartRender()
 {
   RendererInfo renInfo;
@@ -216,10 +305,12 @@ void vtkSynchronizedRenderers::MasterStartRender()
   vtkMultiProcessStream stream;
   renInfo.Save(stream);
 
+  this->Internal->Save(stream, this->Renderer);
+
   this->ParallelController->Broadcast(stream, this->RootProcessId);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::SlaveStartRender()
 {
   vtkMultiProcessStream stream;
@@ -228,13 +319,16 @@ void vtkSynchronizedRenderers::SlaveStartRender()
   RendererInfo renInfo;
   renInfo.Restore(stream);
   renInfo.CopyTo(this->Renderer);
+
+  this->Internal->Restore(stream, this->Renderer);
+
   this->SetImageReductionFactor(renInfo.ImageReductionFactor);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::HandleEndRender()
 {
-  if (this->CaptureDelegate && this->CaptureDelegate->GetAutomaticEventHandling() == false)
+  if (this->CaptureDelegate && !this->CaptureDelegate->GetAutomaticEventHandling())
   {
     this->CaptureDelegate->HandleEndRender();
   }
@@ -284,13 +378,13 @@ void vtkSynchronizedRenderers::HandleEndRender()
   this->UseFXAA = false;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::MasterEndRender() {}
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::SlaveEndRender() {}
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSynchronizedRenderers::vtkRawImage& vtkSynchronizedRenderers::CaptureRenderedImage()
 {
   vtkRawImage& rawImage = this->Image;
@@ -309,7 +403,7 @@ vtkSynchronizedRenderers::vtkRawImage& vtkSynchronizedRenderers::CaptureRendered
   return rawImage;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::PushImageToScreen()
 {
   vtkRawImage& rawImage = this->Image;
@@ -318,7 +412,10 @@ void vtkSynchronizedRenderers::PushImageToScreen()
     return;
   }
 
-  rawImage.PushToViewport(this->Renderer);
+  // If this->FixBackground is true, the rawImage was generated using a black
+  // background. Such an image can be blended. If this->FixBackground is not
+  // true, then the image simply replaces the existing image.
+  rawImage.PushToViewport(this->Renderer, /*blend=*/this->FixBackground);
 
   vtkHardwareSelector* sel = this->Renderer->GetSelector();
   if (sel)
@@ -354,7 +451,7 @@ void vtkSynchronizedRenderers::PushImageToScreen()
 //    }
 //}
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::CollectiveExpandForVisiblePropBounds(double bounds[6])
 {
   // get local bounds.
@@ -404,7 +501,7 @@ void vtkSynchronizedRenderers::CollectiveExpandForVisiblePropBounds(double bound
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -446,9 +543,9 @@ void vtkSynchronizedRenderers::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // ** INFO OBJECT METHODS ***
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::RendererInfo::Save(vtkMultiProcessStream& stream)
 {
   stream << 1023 << this->ImageReductionFactor << this->Draw << this->CameraParallelProjection
@@ -476,7 +573,7 @@ void vtkSynchronizedRenderers::RendererInfo::Save(vtkMultiProcessStream& stream)
          << this->ModelTransformMatrix[14] << this->ModelTransformMatrix[15];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkSynchronizedRenderers::RendererInfo::Restore(vtkMultiProcessStream& stream)
 {
   int tag;
@@ -509,7 +606,7 @@ bool vtkSynchronizedRenderers::RendererInfo::Restore(vtkMultiProcessStream& stre
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::RendererInfo::CopyFrom(vtkRenderer* ren)
 {
   vtkCamera* cam = ren->GetActiveCamera();
@@ -536,7 +633,7 @@ void vtkSynchronizedRenderers::RendererInfo::CopyFrom(vtkRenderer* ren)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::RendererInfo::CopyTo(vtkRenderer* ren)
 {
   vtkCamera* cam = ren->GetActiveCamera();
@@ -571,7 +668,7 @@ void vtkSynchronizedRenderers::RendererInfo::CopyTo(vtkRenderer* ren)
 // vtkSynchronizedRenderers::vtkRawImage Methods
 //****************************************************************************
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::vtkRawImage::Initialize(int dx, int dy, vtkUnsignedCharArray* data)
 {
   this->Data = data;
@@ -579,7 +676,7 @@ void vtkSynchronizedRenderers::vtkRawImage::Initialize(int dx, int dy, vtkUnsign
   this->Size[1] = dy;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::vtkRawImage::Allocate(int dx, int dy, int numcomps)
 {
   if (dx * dy <= this->Data->GetNumberOfTuples() && this->Data->GetNumberOfComponents() == numcomps)
@@ -596,7 +693,7 @@ void vtkSynchronizedRenderers::vtkRawImage::Allocate(int dx, int dy, int numcomp
   this->Size[1] = dy;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedRenderers::vtkRawImage::SaveAsPNG(const char* filename)
 {
   if (!this->IsValid())
@@ -619,8 +716,8 @@ void vtkSynchronizedRenderers::vtkRawImage::SaveAsPNG(const char* filename)
   img->Delete();
 }
 
-//----------------------------------------------------------------------------
-bool vtkSynchronizedRenderers::vtkRawImage::PushToViewport(vtkRenderer* ren)
+//------------------------------------------------------------------------------
+bool vtkSynchronizedRenderers::vtkRawImage::PushToViewport(vtkRenderer* ren, bool blend)
 {
   if (!this->IsValid())
   {
@@ -644,11 +741,11 @@ bool vtkSynchronizedRenderers::vtkRawImage::PushToViewport(vtkRenderer* ren)
   ostate->vtkglScissor(low_point[0], low_point[1], size[0], size[1]);
 
   ren->Clear();
-  return this->PushToFrameBuffer(ren);
+  return this->PushToFrameBuffer(ren, blend);
 }
 
-//----------------------------------------------------------------------------
-bool vtkSynchronizedRenderers::vtkRawImage::PushToFrameBuffer(vtkRenderer* ren)
+//------------------------------------------------------------------------------
+bool vtkSynchronizedRenderers::vtkRawImage::PushToFrameBuffer(vtkRenderer* ren, bool blend)
 {
   if (!this->IsValid())
   {
@@ -663,8 +760,18 @@ bool vtkSynchronizedRenderers::vtkRawImage::PushToFrameBuffer(vtkRenderer* ren)
 
   // framebuffers have their color premultiplied by alpha.
   vtkOpenGLState::ScopedglBlendFuncSeparate bfsaver(ostate);
-  ostate->vtkglEnable(GL_BLEND);
-  ostate->vtkglBlendFuncSeparate(GL_ONE, GL_ONE_MINUS_SRC_ALPHA, GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
+  vtkOpenGLState::ScopedglEnableDisable bsaver(ostate, GL_BLEND);
+  if (blend)
+  {
+    vtkLogF(TRACE, "PushToFrameBuffer: using blend");
+    ostate->vtkglEnable(GL_BLEND);
+    ostate->vtkglBlendFuncSeparate(GL_ONE, GL_ONE_MINUS_SRC_ALPHA, GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
+  }
+  else
+  {
+    ostate->vtkglDisable(GL_BLEND);
+    vtkLogF(TRACE, "PushToFrameBuffer: not-using blend");
+  }
 
   int size[2], low_point[2];
   ren->GetTiledSizeAndOrigin(&size[0], &size[1], &low_point[0], &low_point[1]);
@@ -679,7 +786,7 @@ bool vtkSynchronizedRenderers::vtkRawImage::PushToFrameBuffer(vtkRenderer* ren)
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkSynchronizedRenderers::vtkRawImage::Capture(vtkRenderer* ren)
 {
   double viewport[4];
@@ -707,8 +814,7 @@ bool vtkSynchronizedRenderers::vtkRawImage::Capture(vtkRenderer* ren)
   this->Resize(image_size[0], image_size[1], 4);
 
   ren->GetRenderWindow()->GetRGBACharPixelData(viewport_in_pixels[0], viewport_in_pixels[1],
-    viewport_in_pixels[2], viewport_in_pixels[3], ren->GetRenderWindow()->GetDoubleBuffer() ? 0 : 1,
-    this->GetRawPtr(),
+    viewport_in_pixels[2], viewport_in_pixels[3], 0, this->GetRawPtr(),
     /*right=*/ren->GetActiveCamera()->GetLeftEye() == 0);
 
   // if selecting then pass the processed pixel buffer
@@ -745,3 +851,4 @@ vtkRenderer* vtkSynchronizedRenderers::GetRenderer()
                 << this->Renderer);
   return this->Renderer;
 }
+VTK_ABI_NAMESPACE_END
