@@ -1,5 +1,9 @@
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #pragma once
 
+#include "vtkLogger.h"
+
 #include "../Types.h"
 #include "OSPRayMDL.h"
 #include "Texture.h"
@@ -12,19 +16,20 @@
 
 namespace RTW
 {
+VTK_ABI_NAMESPACE_BEGIN
     class Material : public Object
     {
         friend class Geometry;
 
     public:
-        Material(const std::string& type) : type(type)
+        Material(const std::string& type) : Object(RTW_MATERIAL), type(type)
         {
             VisRTX::Context* rtx = VisRTX_GetContext();
 
             /*
              * Basic material
              */
-            if (this->type == "OBJMaterial" || this->type == "Luminous")
+            if (this->type == "obj" || this->type == "luminous")
             {
                 this->material = rtx->CreateBasicMaterial();
             }
@@ -34,6 +39,24 @@ namespace RTW
              */
             else
             {
+                //OSPRay 2.0 name backward compatibility.
+                if (this->type == "alloy")
+                    this->type = "Alloy";
+                else if (this->type == "carPaint")
+                    this->type = "CarPaint";
+                else if (this->type == "glass")
+                    this->type = "Glass";
+                else if (this->type == "metal")
+                    this->type = "Metal";
+                else if (this->type == "metallicPaint")
+                    this->type = "MetallicPaint";
+                else if (this->type == "obj")
+                    this->type = "OBJMaterial";
+                else if (this->type == "principled")
+                    this->type = "Principled";
+                else if (this->type == "thinGlass")
+                    this->type = "ThinGlass";
+
                 const std::string materialname = "::ospray::" + this->type;
                 try
                 {
@@ -41,7 +64,7 @@ namespace RTW
                 }
                 catch(const std::exception&)
                 {
-                    std::cerr << "CreateMDLMaterial failed! Falling back to BasicMaterial.\n";
+                    vtkLogF(ERROR, "VisRTX Error: CreateMDLMaterial failed! Falling back to BasicMaterial.");
                     this->material = nullptr;
                 }
                 if (!this->material)
@@ -64,7 +87,7 @@ namespace RTW
             /*
              * OBJMaterial (Basic material)
              */
-            if (this->type == "OBJMaterial" && this->material->GetType() == VisRTX::MaterialType::BASIC)
+            if (this->type == "obj" && this->material->GetType() == VisRTX::MaterialType::BASIC)
             {
                 VisRTX::BasicMaterial* basicMaterial = dynamic_cast<VisRTX::BasicMaterial*>(this->material);
                 assert(basicMaterial);
@@ -75,11 +98,11 @@ namespace RTW
 
                 //this->PrintAllParameters();
 
-                basicMaterial->SetDiffuse(this->Get3f({ "Kd" }, VisRTX::Vec3f(0.8f, 0.8f, 0.8f)));
-                basicMaterial->SetSpecular(this->Get3f({ "Ks" }, VisRTX::Vec3f(0.0f, 0.0f, 0.0f)));
-                basicMaterial->SetShininess(this->Get1f({ "Ns" }, 10.0f));
-                basicMaterial->SetOpacity(this->Get1f({ "d", "alpha" }, 1.0f));
-                basicMaterial->SetTransparencyFilter(this->Get3f({ "Tf" }, VisRTX::Vec3f(0.0f, 0.0f, 0.0f)));
+                basicMaterial->SetDiffuse(this->GetVec3f({ "kd", "Kd" }, VisRTX::Vec3f(0.8f, 0.8f, 0.8f)));
+                basicMaterial->SetSpecular(this->GetVec3f({ "ks", "Ks" }, VisRTX::Vec3f(0.0f, 0.0f, 0.0f)));
+                basicMaterial->SetShininess(this->GetFloat({ "ns", "Ns" }, 10.0f));
+                basicMaterial->SetOpacity(this->GetFloat({ "d", "alpha" }, 1.0f));
+                basicMaterial->SetTransparencyFilter(this->GetVec3f({ "tf", "Tf" }, VisRTX::Vec3f(0.0f, 0.0f, 0.0f)));
 
                 Texture* diffuseTex = this->GetObject<Texture>({ "map_Kd", "map_kd" });
                 if (diffuseTex)
@@ -105,7 +128,7 @@ namespace RTW
             /*
              * Luminous (Basic material)
              */
-            else if (this->type == "Luminous" && this->material->GetType() == VisRTX::MaterialType::BASIC)
+            else if (this->type == "luminous" && this->material->GetType() == VisRTX::MaterialType::BASIC)
             {
                 VisRTX::BasicMaterial* basicMaterial = dynamic_cast<VisRTX::BasicMaterial*>(this->material);
                 assert(basicMaterial);
@@ -113,8 +136,8 @@ namespace RTW
                 {
                     return;
                 }
-                basicMaterial->SetEmissive(this->Get3f({ "color" }, VisRTX::Vec3f(0.0f, 0.0f, 0.0f)));
-                basicMaterial->SetLuminosity(this->Get1f({ "intensity" }, 0.0f));
+                basicMaterial->SetEmissive(this->GetVec3f({ "color" }, VisRTX::Vec3f(0.0f, 0.0f, 0.0f)));
+                basicMaterial->SetLuminosity(this->GetFloat({ "intensity" }, 0.0f));
             }
 
             /*
@@ -162,7 +185,9 @@ namespace RTW
                         case VisRTX::ParameterType::TEXTURE:
                             parameterType = "texture"; break;
                         }
-                        std::cerr << "(mdl) " << this->type << ": " << parameterType << " " << parameter << "\n";
+                        std::stringstream logStrBuf;
+                        logStrBuf << "(mdl) " << this->type << ": " << parameterType << " " << parameter;
+                        vtkLogF(INFO, "%s", logStrBuf.str().c_str());
                     }
                     mdltypes_printed.insert(this->type);
                 }
@@ -175,13 +200,13 @@ namespace RTW
                     std::string complete = this->type + ": " + param;
                     if (ospparams_printed.find(complete) == ospparams_printed.end())
                     {
-                        std::cerr << "(osp) " << complete << "\n";
+                        vtkLogF(INFO, "(osp) %s", complete.c_str());
                         ospparams_printed.insert(complete);
                     }
                 }
 #endif //PRINT_MATERIAL_PARAMETERS
 
-#define WARN_NOT_IMPLEMENTED() std::cerr<<"Warning: type \""<<paramType<<"\" not implemented (Material: "<<this->type<<", "<<paramName<<")\n";
+#define WARN_NOT_IMPLEMENTED() vtkLogF(WARNING, "Warning: type \"%s\" not implemented (Material: %s, %s)", paramType.c_str(), this->type.c_str(), paramName.c_str());
 
                 for (const std::string &param : ospparams_current)
                 {
@@ -200,10 +225,10 @@ namespace RTW
 
                     static const std::map<std::pair<std::string, std::string>, std::string> renameMap
                     {
-                        { { "OBJMaterial", "map_kd" }, "map_Kd"},
-                        { { "OBJMaterial", "map_bump" }, "map_Bump"},
+                        { { "obj", "map_kd" }, "map_Kd"},
+                        { { "obj", "map_bump" }, "map_Bump"},
                         { { "Glass", "etaInside" }, "eta"},
-                        { { "OBJMaterial", "alpha" }, "d"},
+                        { { "obj", "alpha" }, "d"},
                         { { "ThinGlass", "transmission" }, "attenuationColor"}
                     };
 
@@ -232,11 +257,11 @@ namespace RTW
                     if (paramName == std::string("ior") && paramType == std::string("object"))
                     {
                         Data* iorData = this->GetObject<Data>(names);
-                        assert(iorData->GetDataType() == RTW_FLOAT3);
+                        assert(iorData->GetElementDataType() == RTW_VEC3F);
 
-                        if (iorData->GetDataType() != RTW_FLOAT3)
+                        if (iorData->GetElementDataType() != RTW_VEC3F)
                         {
-                            std::cerr << "Error: unexpected data type in ior object\n";
+                            vtkLogF(ERROR, "Error: unexpected data type in ior object");
                             return;
                         }
 
@@ -340,12 +365,12 @@ namespace RTW
                         }
                         else
                         {
-                            std::cerr << "Object \"" << paramName << "\" of material type \"" << this->type << "\" is not a texture.\n";
+                            vtkLogF(WARNING, "Object \"%s\" of material type \"%s\" is not a texture.", paramName.c_str(), this->type.c_str());
                         }
                     }
                     else if (paramType == std::string("int1"))
                     {
-                        int ospParam = this->Get1i(names);
+                        int ospParam = this->GetInt(names);
 
                         if (mdlMaterial->GetParameterType(paramName.c_str()) == VisRTX::ParameterType::BOOL)
                         {
@@ -358,7 +383,7 @@ namespace RTW
                     }
                     else if (paramType == std::string("float1"))
                     {
-                        float ospParam = this->Get1f(names);
+                        float ospParam = this->GetFloat(names);
 
                         if (mdlMaterial->GetParameterType(paramName.c_str()) == VisRTX::ParameterType::BOOL)
                         {
@@ -371,22 +396,22 @@ namespace RTW
                     }
                     else if (paramType == std::string("float2"))
                     {
-                        VisRTX::Vec2f ospParam = this->Get2f(names);
+                        VisRTX::Vec2f ospParam = this->GetVec2f(names);
                         WARN_NOT_IMPLEMENTED();
                     }
                     else if (paramType == std::string("int3"))
                     {
-                        VisRTX::Vec3i ospParam = this->Get3i(names);
+                        VisRTX::Vec3i ospParam = this->GetVec3i(names);
                         WARN_NOT_IMPLEMENTED();
                     }
                     else if (paramType == std::string("float3"))
                     {
-                        VisRTX::Vec3f ospParam = this->Get3f(names);
+                        VisRTX::Vec3f ospParam = this->GetVec3f(names);
                         mdlMaterial->SetParameterColor(paramName.c_str(), ospParam);
                     }
                     else if (paramType == std::string("float4"))
                     {
-                        VisRTX::Vec4f ospParam = this->Get4f(names);
+                        VisRTX::Vec4f ospParam = this->GetVec4f(names);
                         WARN_NOT_IMPLEMENTED();
                     }
                     else
@@ -403,4 +428,5 @@ namespace RTW
         std::string type;
         VisRTX::Material* material = nullptr;
         };
-    }
+VTK_ABI_NAMESPACE_END
+}
