@@ -23,7 +23,6 @@
 #include "vtkTk.h"
 #include "vtkWindows.h"
 
-VTK_ABI_NAMESPACE_BEGIN
 struct vtkTkImageViewerWidget
 {
   Tk_Window TkWin;    /* Tk window structure */
@@ -37,6 +36,5 @@ struct vtkTkImageViewerWidget
 #endif
 };
 
-VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkTkImageViewerWidget.h
