@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkBridgePointIterator.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 // .NAME vtkBridgePointIterator - Implementation of vtkGenericPointIterator.
 // .SECTION Description
 // It is just an example that show how to implement the Generic. It is also
@@ -31,9 +19,10 @@
 #include "vtkBridgePointIteratorOnDataSet.h"
 #include "vtkBridgePointIteratorOne.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBridgePointIterator);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Default constructor.
 vtkBridgePointIterator::vtkBridgePointIterator()
@@ -44,7 +33,7 @@ vtkBridgePointIterator::vtkBridgePointIterator()
   this->IteratorOnCell = vtkBridgePointIteratorOnCell::New();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Destructor.
 vtkBridgePointIterator::~vtkBridgePointIterator()
@@ -54,13 +43,13 @@ vtkBridgePointIterator::~vtkBridgePointIterator()
   this->IteratorOnCell->Delete();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBridgePointIterator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Move iterator to first position if any (loop initialization).
 void vtkBridgePointIterator::Begin()
@@ -71,7 +60,7 @@ void vtkBridgePointIterator::Begin()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Is there no point at iterator position? (exit condition).
 vtkTypeBool vtkBridgePointIterator::IsAtEnd()
@@ -85,7 +74,7 @@ vtkTypeBool vtkBridgePointIterator::IsAtEnd()
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Move iterator to next position. (loop progression).
 // \pre not_off: !IsAtEnd()
@@ -95,7 +84,7 @@ void vtkBridgePointIterator::Next()
   this->CurrentIterator->Next();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Point at iterator position.
 // \pre not_off: !IsAtEnd()
@@ -110,7 +99,7 @@ double* vtkBridgePointIterator::GetPosition()
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Point at iterator position.
 // \pre not_off: !IsAtEnd()
@@ -122,7 +111,7 @@ void vtkBridgePointIterator::GetPosition(double x[3])
   this->CurrentIterator->GetPosition(x);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Unique identifier for the point, could be non-contiguous
 // \pre not_off: !IsAtEnd()
@@ -133,7 +122,7 @@ vtkIdType vtkBridgePointIterator::GetId()
   return this->CurrentIterator->GetId();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Used internally by vtkBridgeDataSet.
 // Iterate over points of `ds'.
@@ -146,7 +135,7 @@ void vtkBridgePointIterator::InitWithDataSet(vtkBridgeDataSet* ds)
   this->CurrentIterator = this->IteratorOnDataSet;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Used internally by vtkBridgeDataSet.
 // Iterate over one point of identifier `id' on dataset `ds'.
@@ -161,7 +150,7 @@ void vtkBridgePointIterator::InitWithOnePoint(vtkBridgeDataSet* ds, vtkIdType id
   this->CurrentIterator = this->IteratorOne;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // The iterator will iterate over the point of a cell
 // \pre cell_exists: cell!=0
@@ -172,3 +161,4 @@ void vtkBridgePointIterator::InitWithCell(vtkBridgeCell* cell)
   this->IteratorOnCell->InitWithCell(cell);
   this->CurrentIterator = this->IteratorOnCell;
 }
+VTK_ABI_NAMESPACE_END
