@@ -8,12 +8,12 @@ readonly name="exprtk"
 readonly ownership="ExprTk Upstream <kwrobot@kitware.com>"
 readonly subtree="ThirdParty/$name/vtk$name"
 readonly repo="https://gitlab.kitware.com/third-party/exprtk.git"
-readonly tag="for/vtk-20210816-2.71"
+readonly tag="for/vtk-20250313-0.0.3-cmake"
 readonly paths="
 .gitattributes
 CMakeLists.vtk.txt
-exprtk.hpp
-License.txt
+include/exprtk.hpp
+license.txt
 readme.txt
 README.kitware.md
 "
