@@ -8,9 +8,10 @@ readonly name="netcdf"
 readonly ownership="netcdf Upstream <kwrobot@kitware.com>"
 readonly subtree="ThirdParty/$name/vtk$name"
 readonly repo="https://gitlab.kitware.com/third-party/netcdf.git"
-readonly tag="for/vtk-20200415-4.7.3"
+readonly tag="for/vtk-20241205-4.9.2"
 readonly paths="
 include/*.h
+include/netcdf_dispatch.h.in
 include/netcdf_meta.h.in
 libdispatch/*.c
 libdispatch/*.h
@@ -19,6 +20,7 @@ libsrc/*.h
 libsrc/*.c
 libsrc4/*.c
 libhdf5/*.c
+libhdf5/*.h
 
 .gitattributes
 CMakeLists.vtk.txt
@@ -32,11 +34,10 @@ vtk_netcdf_config.h.in
 extract_source () {
     git_archive
     pushd "$extractdir/$name-reduced"
-    sed -i -e '/#line/d' libsrc/attr.c libsrc/ncx.c libsrc/putget.c
-    # macOS takes "-e" as an extension for backup files for in-place replacement specified by -i
-    # remove the backup files
-    rm -f libsrc/attr.c-e libsrc/ncx.c-e libsrc/putget.c-e
+    sed -i.bak -e '/#line/d' libsrc/attr.c libsrc/ncx.c libsrc/putget.c
+    rm libsrc/attr.c.bak libsrc/ncx.c.bak libsrc/putget.c.bak
     mv -v CMakeLists.vtk.txt CMakeLists.txt
+    rm -v libdispatch/ezxml_extra.c
     popd
 }
 
