@@ -1,19 +1,5 @@
-/*=========================================================================
-
-  Program:   DICOMParser
-  Module:    DICOMAppHelper.cxx
-  Language:  C++
-
-  Copyright (c) 2003 Matt Turek
-  All rights reserved.
-  See Copyright.txt for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-
+// SPDX-FileCopyrightText: Copyright (c) 2003 Matt Turek
+// SPDX-License-Identifier: BSD-4-Clause
 #ifdef _MSC_VER
 #pragma warning(disable : 4514)
 #pragma warning(disable : 4786)
@@ -28,6 +14,8 @@
 #include "DICOMConfig.h"
 
 #include <algorithm>
+#include <fstream>
+#include <iostream>
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -37,25 +25,26 @@
 #include <mem.h> // for memcpy
 #endif
 
-//#define DEBUG_DICOM_APP_HELPER
+// #define DEBUG_DICOM_APP_HELPER
 
+VTK_ABI_NAMESPACE_BEGIN
 class DICOMAppHelperImplementation
 {
 public:
   // map from series UID to vector of files in the series
-  dicom_stl::map<dicom_stl::string, dicom_stl::vector<dicom_stl::string>, ltstdstr> SeriesUIDMap;
+  std::map<std::string, std::vector<std::string>, ltstdstr> SeriesUIDMap;
 
   // map from filename to intraseries sortable tags
-  dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr> SliceOrderingMap;
+  std::map<std::string, DICOMOrderingElements, ltstdstr> SliceOrderingMap;
 
-  typedef dicom_stl::map<dicom_stl::pair<doublebyte, doublebyte>, DICOMTagInfo> TagMapType;
+  typedef std::map<std::pair<doublebyte, doublebyte>, DICOMTagInfo> TagMapType;
   TagMapType TagMap;
 };
 
 struct lt_pair_int_string
 {
-  bool operator()(const dicom_stl::pair<int, dicom_stl::string>& s1,
-    const dicom_stl::pair<int, dicom_stl::string>& s2) const
+  bool operator()(
+    const std::pair<int, std::string>& s1, const std::pair<int, std::string>& s2) const
   {
     return s1.first < s2.first;
   }
@@ -63,8 +52,8 @@ struct lt_pair_int_string
 
 struct lt_pair_float_string
 {
-  bool operator()(const dicom_stl::pair<float, dicom_stl::string>& s1,
-    const dicom_stl::pair<float, dicom_stl::string>& s2) const
+  bool operator()(
+    const std::pair<float, std::string>& s1, const std::pair<float, std::string>& s2) const
   {
     return s1.first < s2.first;
   }
@@ -72,8 +61,8 @@ struct lt_pair_float_string
 
 struct gt_pair_int_string
 {
-  bool operator()(const dicom_stl::pair<int, dicom_stl::string>& s1,
-    const dicom_stl::pair<int, dicom_stl::string>& s2) const
+  bool operator()(
+    const std::pair<int, std::string>& s1, const std::pair<int, std::string>& s2) const
   {
     return s1.first > s2.first;
   }
@@ -81,8 +70,8 @@ struct gt_pair_int_string
 
 struct gt_pair_float_string
 {
-  bool operator()(const dicom_stl::pair<float, dicom_stl::string>& s1,
-    const dicom_stl::pair<float, dicom_stl::string>& s2) const
+  bool operator()(
+    const std::pair<float, std::string>& s1, const std::pair<float, std::string>& s2) const
   {
     return s1.first > s2.first;
   }
@@ -90,21 +79,21 @@ struct gt_pair_float_string
 
 DICOMAppHelper::DICOMAppHelper()
 {
-  this->HeaderFile = new dicom_stream::ofstream();
+  this->HeaderFile = new std::ofstream();
 
   this->BitsAllocated = 8;
   this->ByteSwapData = false;
   this->PixelSpacing[0] = this->PixelSpacing[1] = this->PixelSpacing[2] = 1.0;
   this->Dimensions[0] = this->Dimensions[1] = 0;
-  this->PhotometricInterpretation = new dicom_stl::string();
-  this->TransferSyntaxUID = new dicom_stl::string();
+  this->PhotometricInterpretation = new std::string();
+  this->TransferSyntaxUID = new std::string();
   this->RescaleOffset = 0.0;
   this->RescaleSlope = 1.0;
   this->ImageData = nullptr;
   this->ImageDataLengthInBytes = 0;
-  this->PatientName = new dicom_stl::string();
-  this->StudyUID = new dicom_stl::string();
-  this->StudyID = new dicom_stl::string();
+  this->PatientName = new std::string();
+  this->StudyUID = new std::string();
+  this->StudyID = new std::string();
   this->GantryAngle = 0.0;
   this->Width = 0;
   this->Height = 0;
@@ -144,7 +133,7 @@ DICOMAppHelper::~DICOMAppHelper()
   //
   // Fix warning here.
   //
-  delete[](static_cast<char*>(this->ImageData));
+  delete[] (static_cast<char*>(this->ImageData));
 
   delete this->TransferSyntaxUID;
   delete this->PhotometricInterpretation;
@@ -179,7 +168,7 @@ void DICOMAppHelper::RegisterCallbacks(DICOMParser* parser)
 {
   if (!parser)
   {
-    dicom_stream::cerr << "Null parser!" << dicom_stream::endl;
+    std::cerr << "Null parser!" << std::endl;
     return;
   }
 
@@ -289,9 +278,8 @@ void DICOMAppHelper::RegisterCallbacks(DICOMParser* parser)
     doublebyte group = tagStruct.group;
     doublebyte element = tagStruct.element;
 
-    dicom_stl::pair<doublebyte, doublebyte> gePair(group, element);
-    dicom_stl::pair<const dicom_stl::pair<doublebyte, doublebyte>, DICOMTagInfo> mapPair(
-      gePair, tagStruct);
+    std::pair<doublebyte, doublebyte> gePair(group, element);
+    std::pair<const std::pair<doublebyte, doublebyte>, DICOMTagInfo> mapPair(gePair, tagStruct);
     this->Implementation->TagMap.insert(mapPair);
 
 #ifdef DEBUG_DICOM_APP_HELPER
@@ -312,17 +300,16 @@ void DICOMAppHelper::SeriesUIDCallback(
   DICOMParser* parser, doublebyte, doublebyte, DICOMParser::VRTypes, unsigned char* val, quadbyte)
 {
   char* newString = reinterpret_cast<char*>(val);
-  dicom_stl::string newStdString(newString);
-  dicom_stl::map<dicom_stl::string, dicom_stl::vector<dicom_stl::string>, ltstdstr>::iterator iter =
+  std::string newStdString(newString);
+  std::map<std::string, std::vector<std::string>, ltstdstr>::iterator iter =
     this->Implementation->SeriesUIDMap.find(newStdString);
   if (iter == this->Implementation->SeriesUIDMap.end())
   {
-    dicom_stl::vector<dicom_stl::string> newVector;
+    std::vector<std::string> newVector;
 
     newVector.push_back(parser->GetFileName());
     this->Implementation->SeriesUIDMap.insert(
-      dicom_stl::pair<const dicom_stl::string, dicom_stl::vector<dicom_stl::string> >(
-        newStdString, newVector));
+      std::pair<const std::string, std::vector<std::string>>(newStdString, newVector));
   }
   else
   {
@@ -332,19 +319,18 @@ void DICOMAppHelper::SeriesUIDCallback(
 
 void DICOMAppHelper::OutputSeries()
 {
-  dicom_stream::cout << dicom_stream::endl << dicom_stream::endl;
+  std::cout << std::endl << std::endl;
 
-  for (dicom_stl::map<dicom_stl::string, dicom_stl::vector<dicom_stl::string>, ltstdstr>::iterator
-         iter = this->Implementation->SeriesUIDMap.begin();
+  for (std::map<std::string, std::vector<std::string>, ltstdstr>::iterator iter =
+         this->Implementation->SeriesUIDMap.begin();
        iter != this->Implementation->SeriesUIDMap.end(); ++iter)
   {
-    dicom_stream::cout << "SERIES: " << (*iter).first.c_str() << dicom_stream::endl;
-    dicom_stl::vector<dicom_stl::string>& v_ref = (*iter).second;
+    std::cout << "SERIES: " << (*iter).first.c_str() << std::endl;
+    std::vector<std::string>& v_ref = (*iter).second;
 
-    for (dicom_stl::vector<dicom_stl::string>::iterator v_iter = v_ref.begin();
-         v_iter != v_ref.end(); ++v_iter)
+    for (std::vector<std::string>::iterator v_iter = v_ref.begin(); v_iter != v_ref.end(); ++v_iter)
     {
-      dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr>::iterator sn_iter =
+      std::map<std::string, DICOMOrderingElements, ltstdstr>::iterator sn_iter =
         Implementation->SliceOrderingMap.find(*v_iter);
 
       int slice = -1;
@@ -352,7 +338,7 @@ void DICOMAppHelper::OutputSeries()
       {
         slice = (*sn_iter).second.SliceNumber;
       }
-      dicom_stream::cout << "\t" << (*v_iter).c_str() << " [" << slice << "]" << dicom_stream::endl;
+      std::cout << "\t" << (*v_iter).c_str() << " [" << slice << "]" << std::endl;
     }
   }
 }
@@ -363,7 +349,7 @@ void DICOMAppHelper::ArrayCallback(DICOMParser* parser, doublebyte group, double
   const char* desc = "No description";
 
   TagMapType::iterator iter =
-    this->Implementation->TagMap.find(dicom_stl::pair<doublebyte, doublebyte>(group, element));
+    this->Implementation->TagMap.find(std::pair<doublebyte, doublebyte>(group, element));
   if (iter != this->Implementation->TagMap.end())
   {
     desc = (*iter).second.description;
@@ -380,17 +366,17 @@ void DICOMAppHelper::ArrayCallback(DICOMParser* parser, doublebyte group, double
   this->HeaderFile->width(4);
   char prev = this->HeaderFile->fill('0');
 
-  *this->HeaderFile << dicom_stream::hex << group;
+  *this->HeaderFile << std::hex << group;
   *this->HeaderFile << ",0x";
 
   this->HeaderFile->width(4);
   this->HeaderFile->fill('0');
 
-  *this->HeaderFile << dicom_stream::hex << element;
+  *this->HeaderFile << std::hex << element;
   *this->HeaderFile << ") ";
 
   this->HeaderFile->fill(prev);
-  *this->HeaderFile << dicom_stream::dec;
+  *this->HeaderFile << std::dec;
   *this->HeaderFile << " " << ct1 << ct2 << " ";
   *this->HeaderFile << "[" << len << " bytes] ";
 
@@ -455,7 +441,7 @@ void DICOMAppHelper::ArrayCallback(DICOMParser* parser, doublebyte group, double
       case DICOMParser::VR_UNKNOWN:
       case DICOMParser::VR_AW:
       default:
-        *this->HeaderFile << val << dicom_stream::endl;
+        *this->HeaderFile << val << std::endl;
         break;
     }
   }
@@ -464,7 +450,7 @@ void DICOMAppHelper::ArrayCallback(DICOMParser* parser, doublebyte group, double
     *this->HeaderFile << "NULL";
   }
 
-  *this->HeaderFile << dicom_stream::dec << dicom_stream::endl;
+  *this->HeaderFile << std::dec << std::endl;
   this->HeaderFile->fill(prev);
 
   delete[] val;
@@ -474,7 +460,7 @@ void DICOMAppHelper::SliceNumberCallback(
   DICOMParser* parser, doublebyte, doublebyte, DICOMParser::VRTypes, unsigned char* val, quadbyte)
 {
   // Look for the current file in the map of slice ordering data
-  dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr>::iterator it;
+  std::map<std::string, DICOMOrderingElements, ltstdstr>::iterator it;
   it = this->Implementation->SliceOrderingMap.find(parser->GetFileName());
   if (it == Implementation->SliceOrderingMap.end())
   {
@@ -491,7 +477,7 @@ void DICOMAppHelper::SliceNumberCallback(
 
     // insert into the map
     this->Implementation->SliceOrderingMap.insert(
-      dicom_stl::pair<const dicom_stl::string, DICOMOrderingElements>(parser->GetFileName(), ord));
+      std::pair<const std::string, DICOMOrderingElements>(parser->GetFileName(), ord));
   }
   else
   {
@@ -521,7 +507,7 @@ void DICOMAppHelper::SliceLocationCallback(
   DICOMParser* parser, doublebyte, doublebyte, DICOMParser::VRTypes, unsigned char* val, quadbyte)
 {
   // Look for the current file in the map of slice ordering data
-  dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr>::iterator it;
+  std::map<std::string, DICOMOrderingElements, ltstdstr>::iterator it;
   it = this->Implementation->SliceOrderingMap.find(parser->GetFileName());
   if (it == Implementation->SliceOrderingMap.end())
   {
@@ -531,7 +517,7 @@ void DICOMAppHelper::SliceLocationCallback(
 
     // insert into the map
     this->Implementation->SliceOrderingMap.insert(
-      dicom_stl::pair<const dicom_stl::string, DICOMOrderingElements>(parser->GetFileName(), ord));
+      std::pair<const std::string, DICOMOrderingElements>(parser->GetFileName(), ord));
   }
   else if (val)
   {
@@ -544,7 +530,7 @@ void DICOMAppHelper::ImagePositionPatientCallback(
   DICOMParser* parser, doublebyte, doublebyte, DICOMParser::VRTypes, unsigned char* val, quadbyte)
 {
   // Look for the current file in the map of slice ordering data
-  dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr>::iterator it;
+  std::map<std::string, DICOMOrderingElements, ltstdstr>::iterator it;
   it = this->Implementation->SliceOrderingMap.find(parser->GetFileName());
   if (it == Implementation->SliceOrderingMap.end())
   {
@@ -566,7 +552,7 @@ void DICOMAppHelper::ImagePositionPatientCallback(
 
     // insert into the map
     this->Implementation->SliceOrderingMap.insert(
-      dicom_stl::pair<const dicom_stl::string, DICOMOrderingElements>(parser->GetFileName(), ord));
+      std::pair<const std::string, DICOMOrderingElements>(parser->GetFileName(), ord));
 
     // cache the value
     memcpy(this->ImagePositionPatient, ord.ImagePositionPatient, 3 * sizeof(float));
@@ -596,7 +582,7 @@ void DICOMAppHelper::ImageOrientationPatientCallback(
   DICOMParser* parser, doublebyte, doublebyte, DICOMParser::VRTypes, unsigned char* val, quadbyte)
 {
   // Look for the current file in the map of slice ordering data
-  dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr>::iterator it;
+  std::map<std::string, DICOMOrderingElements, ltstdstr>::iterator it;
   it = this->Implementation->SliceOrderingMap.find(parser->GetFileName());
   if (it == Implementation->SliceOrderingMap.end())
   {
@@ -622,7 +608,7 @@ void DICOMAppHelper::ImageOrientationPatientCallback(
 
     // insert into the map
     this->Implementation->SliceOrderingMap.insert(
-      dicom_stl::pair<const dicom_stl::string, DICOMOrderingElements>(parser->GetFileName(), ord));
+      std::pair<const std::string, DICOMOrderingElements>(parser->GetFileName(), ord));
 
     // cache the value
     memcpy(this->ImageOrientationPatient, ord.ImageOrientationPatient, 6 * sizeof(float));
@@ -663,7 +649,7 @@ void DICOMAppHelper::TransferSyntaxCallback(
 #else
   char platformByteOrder = 'B';
 #endif
-  dicom_stream::cout << "Platform byte order: " << platformByteOrder << dicom_stream::endl;
+  std::cout << "Platform byte order: " << platformByteOrder << std::endl;
 #endif
 
   static const char* TRANSFER_UID_EXPLICIT_BIG_ENDIAN = "1.2.840.10008.1.2.2";
@@ -674,27 +660,27 @@ void DICOMAppHelper::TransferSyntaxCallback(
     this->ByteSwapData = true;
     parser->AddDICOMTagCallback(0x0800, 0x0000, DICOMParser::VR_UNKNOWN, ToggleSwapBytesCB);
 #ifdef DEBUG_DICOM_APP_HELPER
-    dicom_stream::cerr << "Registering callback for swapping bytes." << dicom_stream::endl;
+    std::cerr << "Registering callback for swapping bytes." << std::endl;
 #endif
   }
 
   delete this->TransferSyntaxUID;
-  this->TransferSyntaxUID = new dicom_stl::string(reinterpret_cast<char*>(val));
+  this->TransferSyntaxUID = new std::string(reinterpret_cast<char*>(val));
 
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Transfer Syntax UID: " << *this->TransferSyntaxUID;
-  dicom_stream::cout << " " << this->TransferSyntaxUIDDescription(this->TransferSyntaxUID->c_str())
-                     << dicom_stream::endl;
+  std::cout << "Transfer Syntax UID: " << *this->TransferSyntaxUID;
+  std::cout << " " << this->TransferSyntaxUIDDescription(this->TransferSyntaxUID->c_str())
+            << std::endl;
 #endif
 }
 
 void DICOMAppHelper::BitsAllocatedCallback(
   DICOMParser* parser, doublebyte, doublebyte, DICOMParser::VRTypes, unsigned char* val, quadbyte)
 {
-  this->BitsAllocated = parser->GetDICOMFile()->ReturnAsUnsignedShort(
-    val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
+  this->BitsAllocated =
+    DICOMFile::ReturnAsUnsignedShort(val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Bits allocated: " << this->BitsAllocated << dicom_stream::endl;
+  std::cout << "Bits allocated: " << this->BitsAllocated << std::endl;
 #endif
 }
 
@@ -702,14 +688,14 @@ void DICOMAppHelper::ToggleSwapBytesCallback(
   DICOMParser* parser, doublebyte, doublebyte, DICOMParser::VRTypes, unsigned char*, quadbyte len)
 {
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "ToggleSwapBytesCallback" << dicom_stream::endl;
+  std::cout << "ToggleSwapBytesCallback" << std::endl;
 #endif
   bool bs = parser->GetDICOMFile()->GetPlatformIsBigEndian();
   parser->GetDICOMFile()->SetPlatformIsBigEndian(!bs);
 
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Set byte swap to: " << parser->GetDICOMFile()->GetPlatformIsBigEndian()
-                     << dicom_stream::endl;
+  std::cout << "Set byte swap to: " << parser->GetDICOMFile()->GetPlatformIsBigEndian()
+            << std::endl;
 #endif
 
   long pos = parser->GetDICOMFile()->Tell();
@@ -729,17 +715,26 @@ void DICOMAppHelper::PixelSpacingCallback(DICOMParser* parser, doublebyte group,
 {
   if (group == 0x0028 && element == 0x0030)
   {
+    // DICOM spacing is in Row/Column order rather than X/Y order,
+    // so we reverse it to provide what the application expects
     if (!val ||
-      sscanf(reinterpret_cast<char*>(val), "%f\\%f", &this->PixelSpacing[0],
-        &this->PixelSpacing[1]) != 2)
+      sscanf(reinterpret_cast<char*>(val), "%f\\%f", &this->PixelSpacing[1],
+        &this->PixelSpacing[0]) != 2)
     {
       this->PixelSpacing[0] = this->PixelSpacing[1] = 0.0;
     }
   }
   else if (group == 0x0018 && element == 0x0050)
   {
-    this->PixelSpacing[2] =
-      DICOMFile::ReturnAsFloat(val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
+    if (!val)
+    {
+      this->PixelSpacing[2] = 0.0;
+    }
+    else
+    {
+      this->PixelSpacing[2] =
+        DICOMFile::ReturnAsFloat(val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
+    }
   }
 }
 
@@ -749,7 +744,7 @@ void DICOMAppHelper::WidthCallback(
   unsigned short uival =
     DICOMFile::ReturnAsUnsignedShort(val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Width: " << uival << dicom_stream::endl;
+  std::cout << "Width: " << uival << std::endl;
 #endif
 
   this->Width = uival;
@@ -762,7 +757,7 @@ void DICOMAppHelper::HeightCallback(
   unsigned short uival =
     DICOMFile::ReturnAsUnsignedShort(val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Height: " << uival << dicom_stream::endl;
+  std::cout << "Height: " << uival << std::endl;
 #endif
   this->Height = uival;
   this->Dimensions[1] = this->Height;
@@ -774,8 +769,7 @@ void DICOMAppHelper::PixelRepresentationCallback(
   unsigned short uival =
     DICOMFile::ReturnAsUnsignedShort(val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Pixel Representation: " << (uival ? "Signed" : "Unsigned")
-                     << dicom_stream::endl;
+  std::cout << "Pixel Representation: " << (uival ? "Signed" : "Unsigned") << std::endl;
 #endif
   this->PixelRepresentation = uival;
 }
@@ -784,11 +778,11 @@ void DICOMAppHelper::PhotometricInterpretationCallback(
   DICOMParser*, doublebyte, doublebyte, DICOMParser::VRTypes, unsigned char* val, quadbyte)
 {
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Photometric Interpretation: " << (char*)val << dicom_stream::endl;
+  std::cout << "Photometric Interpretation: " << (char*)val << std::endl;
 #endif
   delete this->PhotometricInterpretation;
 
-  this->PhotometricInterpretation = new dicom_stl::string(reinterpret_cast<char*>(val));
+  this->PhotometricInterpretation = new std::string(reinterpret_cast<char*>(val));
 }
 
 void DICOMAppHelper::PixelDataCallback(
@@ -805,7 +799,7 @@ void DICOMAppHelper::PixelDataCallback(
   }
 
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "numPixels : " << numPixels << dicom_stream::endl;
+  std::cout << "numPixels : " << numPixels << std::endl;
 #endif
 
   int ptrIncr = int(this->BitsAllocated / 8.0);
@@ -821,10 +815,10 @@ void DICOMAppHelper::PixelDataCallback(
   if (isFloat)
   {
 #ifdef DEBUG_DICOM_APP_HELPER
-    dicom_stream::cout << "Slope and offset are not integer valued : ";
-    dicom_stream::cout << this->RescaleSlope << ", " << this->RescaleOffset << dicom_stream::endl;
+    std::cout << "Slope and offset are not integer valued : ";
+    std::cout << this->RescaleSlope << ", " << this->RescaleOffset << std::endl;
 #endif
-    delete[](static_cast<char*>(this->ImageData));
+    delete[] (static_cast<char*>(this->ImageData));
     this->ImageData = new float[numPixels];
     floatOutputData = static_cast<float*>(this->ImageData);
 
@@ -842,8 +836,8 @@ void DICOMAppHelper::PixelDataCallback(
         floatOutputData[i] = newFloatPixel;
       }
 #ifdef DEBUG_DICOM_APP_HELPER
-      dicom_stream::cout << "Did rescale, offset to float from char." << dicom_stream::endl;
-      dicom_stream::cout << numPixels << " pixels." << dicom_stream::endl;
+      std::cout << "Did rescale, offset to float from char." << std::endl;
+      std::cout << numPixels << " pixels." << std::endl;
 #endif
     }
     else if (ptrIncr == 2)
@@ -855,21 +849,21 @@ void DICOMAppHelper::PixelDataCallback(
         floatOutputData[i] = newFloatPixel;
       }
 #ifdef DEBUG_DICOM_APP_HELPER
-      dicom_stream::cout << "Did rescale, offset to float from short." << dicom_stream::endl;
-      dicom_stream::cout << numPixels << " pixels." << dicom_stream::endl;
+      std::cout << "Did rescale, offset to float from short." << std::endl;
+      std::cout << numPixels << " pixels." << std::endl;
 #endif
     }
   }
   else
   {
 #ifdef DEBUG_DICOM_APP_HELPER
-    dicom_stream::cout << "Slope and offset are integer valued : ";
-    dicom_stream::cout << this->RescaleSlope << ", " << this->RescaleOffset << dicom_stream::endl;
+    std::cout << "Slope and offset are integer valued : ";
+    std::cout << this->RescaleSlope << ", " << this->RescaleOffset << std::endl;
 #endif
 
     if (ptrIncr == 1)
     {
-      delete[](static_cast<char*>(this->ImageData));
+      delete[] (static_cast<char*>(this->ImageData));
       this->ImageData = new char[numPixels];
 
       char* charOutputData = static_cast<char*>(this->ImageData);
@@ -886,13 +880,13 @@ void DICOMAppHelper::PixelDataCallback(
         charOutputData[i] = newCharPixel;
       }
 #ifdef DEBUG_DICOM_APP_HELPER
-      dicom_stream::cout << "Did rescale, offset to char from char." << dicom_stream::endl;
-      dicom_stream::cout << numPixels << " pixels." << dicom_stream::endl;
+      std::cout << "Did rescale, offset to char from char." << std::endl;
+      std::cout << numPixels << " pixels." << std::endl;
 #endif
     }
     else if (ptrIncr == 2)
     {
-      delete[](static_cast<char*>(this->ImageData));
+      delete[] (static_cast<char*>(this->ImageData));
       this->ImageData = new short[numPixels];
       short* shortOutputData = static_cast<short*>(this->ImageData);
 
@@ -907,8 +901,8 @@ void DICOMAppHelper::PixelDataCallback(
         shortOutputData[i] = newShortPixel;
       }
 #ifdef DEBUG_DICOM_APP_HELPER
-      dicom_stream::cout << "Did rescale, offset to short from short." << dicom_stream::endl;
-      dicom_stream::cout << numPixels << " pixels." << dicom_stream::endl;
+      std::cout << "Did rescale, offset to short from short." << std::endl;
+      std::cout << numPixels << " pixels." << std::endl;
 #endif
     }
   }
@@ -926,52 +920,55 @@ void DICOMAppHelper::RescaleOffsetCallback(
   float fval = DICOMFile::ReturnAsFloat(val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
   this->RescaleOffset = fval;
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Pixel offset: " << this->RescaleOffset << dicom_stream::endl;
+  std::cout << "Pixel offset: " << this->RescaleOffset << std::endl;
 #endif
 }
 
 const char* DICOMAppHelper::TransferSyntaxUIDDescription(const char* uid)
 {
-  static const char* DICOM_IMPLICIT_VR_LITTLE_ENDIAN = "1.2.840.10008.1.2";
-  static const char* DICOM_LOSSLESS_JPEG = "1.2.840.10008.1.2.4.70";
-  static const char* DICOM_LOSSY_JPEG_8BIT = "1.2.840.10008.1.2.4.50";
-  static const char* DICOM_LOSSY_JPEG_16BIT = "1.2.840.10008.1.2.4.51";
-  static const char* DICOM_EXPLICIT_VR_LITTLE_ENDIAN = "1.2.840.10008.1.2.1";
-  static const char* DICOM_EXPLICIT_VR_BIG_ENDIAN = "1.2.840.10008.1.2.2";
-  static const char* DICOM_GE_PRIVATE_IMPLICIT_BIG_ENDIAN = "1.2.840.113619.5.2";
+  constexpr struct uid_description
+  {
+    const char* uid;
+    const char* description;
+  } tsUIDs[] = {
+    { "1.2.840.10008.1.2", "Implicit VR little endian" },
+    { "1.2.840.10008.1.2.1", "Explicit VR little endian" },
+    { "1.2.840.10008.1.2.2", "Explicit VR big endian" },
+    { "1.2.840.10008.1.2.5", "Run length encoded" }, // RLE packbits
+    { "1.2.840.10008.1.2.4.50", "JPEG baseline" },
+    { "1.2.840.10008.1.2.4.51", "JPEG extended precision" },
+    { "1.2.840.10008.1.2.4.57", "JPEG lossless" },
+    { "1.2.840.10008.1.2.4.70", "JPEG lossless prediction" },
+    { "1.2.840.10008.1.2.4.80", "JPEG-LS" },
+    { "1.2.840.10008.1.2.4.81", "JPEG-LS constrained error" },
+    { "1.2.840.10008.1.2.4.90", "JPEG 2000 lossless" },
+    { "1.2.840.10008.1.2.4.91", "JPEG 2000 lossless/lossy" },
+    { "1.2.840.10008.1.2.4.100", "MPEG2 ML" }, // video
+    { "1.2.840.10008.1.2.4.101", "MPEG2 HL" },
+    { "1.2.840.10008.1.2.4.102", "MPEG4 AVC/H.264 High Profile / Level 4.1" },
+    { "1.2.840.10008.1.2.4.103", "MPEG4 AVC/H.264 BD-compatible" },
+    { "1.2.840.10008.1.2.4.104", "MPEG4 AVC/H.264 High Profile / 4.2 2D" },
+    { "1.2.840.10008.1.2.4.105", "MPEG4 AVC/H.264 High Profile / 4.2 3D" },
+    { "1.2.840.10008.1.2.4.106", "MPEG4 AVC/H.264 Stereo High Profile / 4.2" },
+    { "1.2.840.10008.1.2.4.107", "HEVC/H.265 Main Profile / 5.1" },
+    { "1.2.840.10008.1.2.4.108", "HEVC/H.265 Main 10 Profile / 5.1" },
+    { "1.2.840.10008.1.2.4.110", "JPEG XL lossless" },
+    { "1.2.840.10008.1.2.4.111", "JPEG XL JPEG recompression" },
+    { "1.2.840.10008.1.2.4.112", "JPEG XL" }, // all other JPEG XL
+    { "1.2.840.10008.1.20", "Papyrus little endian" },
+    { "1.2.840.113619.5.2", "GE private implicit VR big endian pixels" },
+    { nullptr, nullptr } // sentinel
+  };
 
-  if (!strcmp(DICOM_IMPLICIT_VR_LITTLE_ENDIAN, uid))
+  for (int i = 0; tsUIDs[i].uid; ++i)
   {
-    return "Implicit VR, Little Endian";
-  }
-  else if (!strcmp(DICOM_LOSSLESS_JPEG, uid))
-  {
-    return "Lossless JPEG";
-  }
-  else if (!strcmp(DICOM_LOSSY_JPEG_8BIT, uid))
-  {
-    return "Lossy JPEG 8 bit";
-  }
-  else if (!strcmp(DICOM_LOSSY_JPEG_16BIT, uid))
-  {
-    return "Lossy JPEG 16 bit.";
-  }
-  else if (!strcmp(DICOM_EXPLICIT_VR_LITTLE_ENDIAN, uid))
-  {
-    return "Explicit VR, Little Endian.";
-  }
-  else if (!strcmp(DICOM_EXPLICIT_VR_BIG_ENDIAN, uid))
-  {
-    return "Explicit VR, Big Endian.";
-  }
-  else if (!strcmp(DICOM_GE_PRIVATE_IMPLICIT_BIG_ENDIAN, uid))
-  {
-    return "GE Private, Implicit VR, Big Endian Image Data.";
-  }
-  else
-  {
-    return "Unknown.";
+    if (strcmp(uid, tsUIDs[i].uid) == 0)
+    {
+      return tsUIDs[i].description;
+    }
   }
+
+  return "Unknown";
 }
 
 void DICOMAppHelper::RescaleSlopeCallback(
@@ -979,7 +976,7 @@ void DICOMAppHelper::RescaleSlopeCallback(
 {
   float fval = DICOMFile::ReturnAsFloat(val, parser->GetDICOMFile()->GetPlatformIsBigEndian());
 #ifdef DEBUG_DICOM_APP_HELPER
-  dicom_stream::cout << "Rescale slope: " << fval << dicom_stream::endl;
+  std::cout << "Rescale slope: " << fval << std::endl;
 #endif
   this->RescaleSlope = fval;
 }
@@ -995,14 +992,7 @@ bool DICOMAppHelper::RescaledImageDataIsFloat()
   double d1 = fabs(sf - this->RescaleSlope);
   double d2 = fabs(of - this->RescaleOffset);
 
-  if (d1 > 0.0 || d2 > 0.0)
-  {
-    return true;
-  }
-  else
-  {
-    return false;
-  }
+  return d1 > 0.0 || d2 > 0.0;
 }
 
 void DICOMAppHelper::GetImageData(void*& data, DICOMParser::VRTypes& dataType, unsigned long& len)
@@ -1021,13 +1011,13 @@ bool DICOMAppHelper::RescaledImageDataIsSigned()
   return (rescaleSigned || pixelRepSigned || offsetSigned);
 }
 
-void DICOMAppHelper::GetSliceNumberFilenamePairs(const dicom_stl::string& seriesUID,
-  dicom_stl::vector<dicom_stl::pair<int, dicom_stl::string> >& v, bool ascending)
+void DICOMAppHelper::GetSliceNumberFilenamePairs(
+  const std::string& seriesUID, std::vector<std::pair<int, std::string>>& v, bool ascending)
 {
   v.clear();
 
-  dicom_stl::map<dicom_stl::string, dicom_stl::vector<dicom_stl::string>, ltstdstr>::iterator
-    miter = this->Implementation->SeriesUIDMap.find(seriesUID);
+  std::map<std::string, std::vector<std::string>, ltstdstr>::iterator miter =
+    this->Implementation->SeriesUIDMap.find(seriesUID);
 
   if (miter == this->Implementation->SeriesUIDMap.end())
   {
@@ -1035,15 +1025,15 @@ void DICOMAppHelper::GetSliceNumberFilenamePairs(const dicom_stl::string& series
   }
 
   // grab the filenames for the specified series
-  dicom_stl::vector<dicom_stl::string> files = (*miter).second;
+  std::vector<std::string> files = (*miter).second;
 
-  for (dicom_stl::vector<dicom_stl::string>::iterator fileIter = files.begin();
-       fileIter != files.end(); ++fileIter)
+  for (std::vector<std::string>::iterator fileIter = files.begin(); fileIter != files.end();
+       ++fileIter)
   {
-    dicom_stl::pair<int, dicom_stl::string> p;
-    p.second = dicom_stl::string(*fileIter);
+    std::pair<int, std::string> p;
+    p.second = std::string(*fileIter);
     int slice_number;
-    dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr>::iterator sn_iter =
+    std::map<std::string, DICOMOrderingElements, ltstdstr>::iterator sn_iter =
       Implementation->SliceOrderingMap.find(*fileIter);
     // Only store files that have a valid slice number
     if (sn_iter != Implementation->SliceOrderingMap.end())
@@ -1055,16 +1045,16 @@ void DICOMAppHelper::GetSliceNumberFilenamePairs(const dicom_stl::string& series
   }
   if (ascending)
   {
-    dicom_stl::sort(v.begin(), v.end(), lt_pair_int_string());
+    std::sort(v.begin(), v.end(), lt_pair_int_string());
   }
   else
   {
-    dicom_stl::sort(v.begin(), v.end(), gt_pair_int_string());
+    std::sort(v.begin(), v.end(), gt_pair_int_string());
   }
 }
 
 void DICOMAppHelper::GetSliceNumberFilenamePairs(
-  dicom_stl::vector<dicom_stl::pair<int, dicom_stl::string> >& v, bool ascending)
+  std::vector<std::pair<int, std::string>>& v, bool ascending)
 {
   // Default to using the first series
   if (!this->Implementation->SeriesUIDMap.empty())
@@ -1078,13 +1068,13 @@ void DICOMAppHelper::GetSliceNumberFilenamePairs(
   }
 }
 
-void DICOMAppHelper::GetSliceLocationFilenamePairs(const dicom_stl::string& seriesUID,
-  dicom_stl::vector<dicom_stl::pair<float, dicom_stl::string> >& v, bool ascending)
+void DICOMAppHelper::GetSliceLocationFilenamePairs(
+  const std::string& seriesUID, std::vector<std::pair<float, std::string>>& v, bool ascending)
 {
   v.clear();
 
-  dicom_stl::map<dicom_stl::string, dicom_stl::vector<dicom_stl::string>, ltstdstr>::iterator
-    miter = this->Implementation->SeriesUIDMap.find(seriesUID);
+  std::map<std::string, std::vector<std::string>, ltstdstr>::iterator miter =
+    this->Implementation->SeriesUIDMap.find(seriesUID);
 
   if (miter == this->Implementation->SeriesUIDMap.end())
   {
@@ -1092,15 +1082,15 @@ void DICOMAppHelper::GetSliceLocationFilenamePairs(const dicom_stl::string& seri
   }
 
   // grab the filenames for the specified series
-  dicom_stl::vector<dicom_stl::string> files = (*miter).second;
+  std::vector<std::string> files = (*miter).second;
 
-  for (dicom_stl::vector<dicom_stl::string>::iterator fileIter = files.begin();
-       fileIter != files.end(); ++fileIter)
+  for (std::vector<std::string>::iterator fileIter = files.begin(); fileIter != files.end();
+       ++fileIter)
   {
-    dicom_stl::pair<float, dicom_stl::string> p;
-    p.second = dicom_stl::string(*fileIter);
+    std::pair<float, std::string> p;
+    p.second = std::string(*fileIter);
     float slice_location;
-    dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr>::iterator sn_iter =
+    std::map<std::string, DICOMOrderingElements, ltstdstr>::iterator sn_iter =
       Implementation->SliceOrderingMap.find(*fileIter);
 
     if (sn_iter != Implementation->SliceOrderingMap.end())
@@ -1112,16 +1102,16 @@ void DICOMAppHelper::GetSliceLocationFilenamePairs(const dicom_stl::string& seri
   }
   if (ascending)
   {
-    dicom_stl::sort(v.begin(), v.end(), lt_pair_float_string());
+    std::sort(v.begin(), v.end(), lt_pair_float_string());
   }
   else
   {
-    dicom_stl::sort(v.begin(), v.end(), gt_pair_float_string());
+    std::sort(v.begin(), v.end(), gt_pair_float_string());
   }
 }
 
 void DICOMAppHelper::GetSliceLocationFilenamePairs(
-  dicom_stl::vector<dicom_stl::pair<float, dicom_stl::string> >& v, bool ascending)
+  std::vector<std::pair<float, std::string>>& v, bool ascending)
 {
   // Default to using the first series
   if (!this->Implementation->SeriesUIDMap.empty())
@@ -1135,13 +1125,13 @@ void DICOMAppHelper::GetSliceLocationFilenamePairs(
   }
 }
 
-void DICOMAppHelper::GetImagePositionPatientFilenamePairs(const dicom_stl::string& seriesUID,
-  dicom_stl::vector<dicom_stl::pair<float, dicom_stl::string> >& v, bool ascending)
+void DICOMAppHelper::GetImagePositionPatientFilenamePairs(
+  const std::string& seriesUID, std::vector<std::pair<float, std::string>>& v, bool ascending)
 {
   v.clear();
 
-  dicom_stl::map<dicom_stl::string, dicom_stl::vector<dicom_stl::string>, ltstdstr>::iterator
-    miter = this->Implementation->SeriesUIDMap.find(seriesUID);
+  std::map<std::string, std::vector<std::string>, ltstdstr>::iterator miter =
+    this->Implementation->SeriesUIDMap.find(seriesUID);
 
   if (miter == this->Implementation->SeriesUIDMap.end())
   {
@@ -1149,18 +1139,18 @@ void DICOMAppHelper::GetImagePositionPatientFilenamePairs(const dicom_stl::strin
   }
 
   // grab the filenames for the specified series
-  dicom_stl::vector<dicom_stl::string> files = (*miter).second;
+  std::vector<std::string> files = (*miter).second;
 
-  for (dicom_stl::vector<dicom_stl::string>::iterator fileIter = files.begin();
-       fileIter != files.end(); ++fileIter)
+  for (std::vector<std::string>::iterator fileIter = files.begin(); fileIter != files.end();
+       ++fileIter)
   {
-    dicom_stl::pair<float, dicom_stl::string> p;
-    p.second = dicom_stl::string(*fileIter);
+    std::pair<float, std::string> p;
+    p.second = std::string(*fileIter);
 
     float image_position;
     float normal[3];
 
-    dicom_stl::map<dicom_stl::string, DICOMOrderingElements, ltstdstr>::iterator sn_iter =
+    std::map<std::string, DICOMOrderingElements, ltstdstr>::iterator sn_iter =
       Implementation->SliceOrderingMap.find(*fileIter);
 
     if (sn_iter != Implementation->SliceOrderingMap.end())
@@ -1190,16 +1180,16 @@ void DICOMAppHelper::GetImagePositionPatientFilenamePairs(const dicom_stl::strin
   }
   if (ascending)
   {
-    dicom_stl::sort(v.begin(), v.end(), lt_pair_float_string());
+    std::sort(v.begin(), v.end(), lt_pair_float_string());
   }
   else
   {
-    dicom_stl::sort(v.begin(), v.end(), gt_pair_float_string());
+    std::sort(v.begin(), v.end(), gt_pair_float_string());
   }
 }
 
 void DICOMAppHelper::GetImagePositionPatientFilenamePairs(
-  dicom_stl::vector<dicom_stl::pair<float, dicom_stl::string> >& v, bool ascending)
+  std::vector<std::pair<float, std::string>>& v, bool ascending)
 {
   // Default to using the first series
   if (!this->Implementation->SeriesUIDMap.empty())
@@ -1213,11 +1203,11 @@ void DICOMAppHelper::GetImagePositionPatientFilenamePairs(
   }
 }
 
-void DICOMAppHelper::GetSeriesUIDs(dicom_stl::vector<dicom_stl::string>& v)
+void DICOMAppHelper::GetSeriesUIDs(std::vector<std::string>& v)
 {
   v.clear();
 
-  dicom_stl::map<dicom_stl::string, dicom_stl::vector<dicom_stl::string>, ltstdstr>::iterator miter;
+  std::map<std::string, std::vector<std::string>, ltstdstr>::iterator miter;
 
   for (miter = this->Implementation->SeriesUIDMap.begin();
        miter != this->Implementation->SeriesUIDMap.end(); ++miter)
@@ -1239,11 +1229,11 @@ void DICOMAppHelper::PatientNameCallback(
 
   if (val)
   {
-    this->PatientName = new dicom_stl::string(reinterpret_cast<char*>(val));
+    this->PatientName = new std::string(reinterpret_cast<char*>(val));
   }
   else
   {
-    this->PatientName = new dicom_stl::string();
+    this->PatientName = new std::string();
   }
 }
 
@@ -1254,11 +1244,11 @@ void DICOMAppHelper::StudyUIDCallback(
 
   if (val)
   {
-    this->StudyUID = new dicom_stl::string(reinterpret_cast<char*>(val));
+    this->StudyUID = new std::string(reinterpret_cast<char*>(val));
   }
   else
   {
-    this->StudyUID = new dicom_stl::string();
+    this->StudyUID = new std::string();
   }
 }
 
@@ -1269,11 +1259,11 @@ void DICOMAppHelper::StudyIDCallback(
 
   if (val)
   {
-    this->StudyID = new dicom_stl::string(reinterpret_cast<char*>(val));
+    this->StudyID = new std::string(reinterpret_cast<char*>(val));
   }
   else
   {
-    this->StudyID = new dicom_stl::string();
+    this->StudyID = new std::string();
   }
 }
 
@@ -1293,3 +1283,4 @@ void DICOMAppHelper::GantryAngleCallback(
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
+VTK_ABI_NAMESPACE_END
