@@ -10,11 +10,11 @@
 #include <stdlib.h>
 #include <string.h>
 
-HierarchyInfo* hierarchyInfo = NULL;
-StringCache* stringCache = NULL;
-int numberOfWrappedFunctions = 0;
-FunctionInfo* wrappedFunctions[1000];
-FunctionInfo* thisFunction;
+static HierarchyInfo* hierarchyInfo = NULL;
+static StringCache* stringCache = NULL;
+static int numberOfWrappedFunctions = 0;
+static FunctionInfo* wrappedFunctions[1000];
+static FunctionInfo* thisFunction;
 
 void outputScalarParamDeclarations(FILE* fp, int i, unsigned int aType)
 {
@@ -248,9 +248,10 @@ void return_result_native(FILE* fp)
  * return 0 if the types do not map to the same type */
 static int CheckMatch(unsigned int type1, unsigned int type2, const char* c1, const char* c2)
 {
+  /* VTK_PARSE_UNKNOWN is used for enum types, which are mapped to java's int type */
   static unsigned int byteTypes[] = { VTK_PARSE_UNSIGNED_CHAR, VTK_PARSE_SIGNED_CHAR, 0 };
   static unsigned int shortTypes[] = { VTK_PARSE_UNSIGNED_SHORT, VTK_PARSE_SHORT, 0 };
-  static unsigned int intTypes[] = { VTK_PARSE_UNSIGNED_INT, VTK_PARSE_INT, 0 };
+  static unsigned int intTypes[] = { VTK_PARSE_UNKNOWN, VTK_PARSE_UNSIGNED_INT, VTK_PARSE_INT, 0 };
   static unsigned int longTypes[] = { VTK_PARSE_UNSIGNED_LONG, VTK_PARSE_UNSIGNED_LONG_LONG,
     VTK_PARSE_LONG, VTK_PARSE_LONG_LONG, 0 };
 
@@ -339,7 +340,7 @@ int DoneOne(void)
 {
   int i, j;
   int match;
-  FunctionInfo* fi;
+  const FunctionInfo* fi;
 
   for (i = 0; i < numberOfWrappedFunctions; i++)
   {
@@ -378,7 +379,7 @@ void HandleDataReader(FILE* fp)
   fprintf(fp, "    { %s_%i(id0,id1); }\n", thisFunction->Name, numberOfWrappedFunctions);
 }
 
-void HandleDataArray(FILE* fp, ClassInfo* data)
+void HandleDataArray(FILE* fp, const ClassInfo* data)
 {
   const char* type = 0;
 
@@ -442,7 +443,7 @@ void HandleDataArray(FILE* fp, ClassInfo* data)
 
 static int isClassWrapped(const char* classname)
 {
-  HierarchyEntry* entry;
+  const HierarchyEntry* entry;
 
   if (hierarchyInfo)
   {
@@ -928,13 +929,13 @@ void outputFunction(FILE* fp, ClassInfo* data)
   }
 }
 
-void WriteDummyClass(FILE* fp, ClassInfo* data, const char* filename)
+static void WriteDummyClass(FILE* fp, const ClassInfo* data, const char* filename)
 {
   char* class_name = NULL;
   if (data == NULL)
   {
-    char* last_slash = strrchr(filename, '/');
-    char* first_dot = strchr(last_slash, '.');
+    const char* last_slash = strrchr(filename, '/');
+    const char* first_dot = strchr(last_slash, '.');
     size_t size = first_dot - last_slash;
     class_name = malloc(size * sizeof(char));
     strncpy(class_name, last_slash + 1, size);
@@ -951,7 +952,7 @@ void WriteDummyClass(FILE* fp, ClassInfo* data, const char* filename)
 /* print the parsed structures */
 int VTK_PARSE_MAIN(int argc, char* argv[])
 {
-  OptionInfo* options;
+  const OptionInfo* options;
   FileInfo* file_info;
   ClassInfo* data;
   FILE* fp;
@@ -982,7 +983,7 @@ int VTK_PARSE_MAIN(int argc, char* argv[])
   if (!fp)
   {
     fprintf(stderr, "Error opening output file %s\n", options->OutputFileName);
-    exit(1);
+    return vtkParse_FinalizeMain(1);
   }
 
   /* get the main class */
@@ -991,14 +992,16 @@ int VTK_PARSE_MAIN(int argc, char* argv[])
   {
     WriteDummyClass(fp, data, options->OutputFileName);
     fclose(fp);
-    exit(0);
+    vtkWrap_WarnEmpty(options);
+    return vtkParse_FinalizeMain(0);
   }
 
   if (data->Template)
   {
     WriteDummyClass(fp, data, options->OutputFileName);
     fclose(fp);
-    exit(0);
+    vtkWrap_WarnEmpty(options);
+    return vtkParse_FinalizeMain(0);
   }
 
   for (i = 0; i < data->NumberOfSuperClasses; ++i)
@@ -1007,7 +1010,8 @@ int VTK_PARSE_MAIN(int argc, char* argv[])
     {
       WriteDummyClass(fp, data, options->OutputFileName);
       fclose(fp);
-      exit(0);
+      vtkWrap_WarnEmpty(options);
+      return vtkParse_FinalizeMain(0);
     }
   }
 
@@ -1017,7 +1021,8 @@ int VTK_PARSE_MAIN(int argc, char* argv[])
     {
       WriteDummyClass(fp, data, options->OutputFileName);
       fclose(fp);
-      exit(0);
+      vtkWrap_WarnEmpty(options);
+      return vtkParse_FinalizeMain(0);
     }
 
     /* resolve using declarations within the header files */
@@ -1147,8 +1152,8 @@ int VTK_PARSE_MAIN(int argc, char* argv[])
     size_t cc;
     size_t len;
     char* dir;
-    char* fname;
-    /*const */ char javaDone[] = "VTKJavaWrapped";
+    const char* fname;
+    const char javaDone[] = "VTKJavaWrapped";
     FILE* tfp;
     fname = options->OutputFileName;
     size_t dirlen = strlen(fname) + strlen(javaDone) + 2;
@@ -1180,5 +1185,5 @@ int VTK_PARSE_MAIN(int argc, char* argv[])
 
   vtkParse_Free(file_info);
 
-  return 0;
+  return vtkParse_FinalizeMain(0);
 }
